function [labels,format] = bestscale(ax,xmin,xmax,dateform,dateChoice)
%BESTSCALE Returns ticks for "best" scale.
%   [TICKS,FORMAT] = BESTSCALE(XMIN,XMAX) returns the tick
%   locations in the vector TICKS that span the interval (XMIN,XMAX) 
%   with "nice" tick spacing.  The dateform FORMAT is also returned.

if nargin<5, dateChoice = 'yqmwdHMS'; end
if nargin<4, dateform = []; end
penalty = 0.03;
formlen = [20 12 8 3 1 1 5 1 3 1 4 2 5 8 11 5 8 5 2];

% Compute xmin, xmax if matrices passed.
if length(xmin) > 1, xmin = min(xmin(:)); end
if length(xmax) > 1, xmax = max(xmax(:)); end

% "Good" spacing between dates
if xmin==xmax, 
    xmin = xmin-1;
    xmax = xmax+1;
end
yearDelta = 10.^(max(0,round(log10(xmax-xmin)-3)))* ...
                 [ .1 .2 .25 .5 1 2 2.5 5 10 20 25 50];
yearDelta(yearDelta<1)= []; % Make sure we use integer years.
quarterDelta = [3];
monthDelta = [1];
weekDelta = 1;
dayDelta = [1 2];
hourDelta = [1 3 6];
minuteDelta = [1 5 10 15 30 60];
secondDelta = min(1,10.^(round(log10(xmax-xmin)-1))* ...
                  [ .1 .2 .25 .5 1 2 2.5 5 10 20 25 50 ]);
secondDelta = [secondDelta 1 5 10 15 30 60];
    
x = [xmin xmax];
[y,m,d] = datevec(x);

% Compute continuous variables for the various time scales.
year = y + (m-1)/12 + (d-1)/12/32;
qtr = (y-y(1))*12 + m + d/32 - 1;
mon = (y-y(1))*12 + m + d/32; 
day = x;
week = (x-2)/7;
hour = (x-floor(x(1)))*24;
minute = (x-floor(x(1)))*24*60;
second = (x-floor(x(1)))*24*3600;

% Compute possible low, high and ticks
if any(dateChoice=='y')
    yearHigh = yearDelta.*ceil(year(2)./yearDelta);
    yearLow = yearDelta.*floor(year(1)./yearDelta);
    yrTicks = round((yearHigh-yearLow)./yearDelta);
    yrHigh = datenum(yearHigh,1,1);
    yrLow = datenum(yearLow,1,1);
    % Encode location of year tick locations in format
    yrFormat = 10 + (1:length(yearDelta))/10;
else
    yrHigh=[]; yrLow=[]; yrTicks=[]; yrFormat = 10;
end 

if any(dateChoice=='q'),
    quarterHigh = quarterDelta.*ceil(qtr(2)./quarterDelta);
    quarterLow = quarterDelta.*floor(qtr(1)./quarterDelta);
    qtrTicks = round((quarterHigh-quarterLow)./quarterDelta);
    qtrHigh = datenum(y(1),quarterHigh+1,1);
    qtrLow = datenum(y(1),quarterLow+1,1);
    % Encode location of qtr tick locations in format
    qtrFormat = 17 + (1:length(quarterDelta))/10;
else
    qtrHigh=[]; qtrLow=[]; qtrTicks=[]; qtrFormat = [];
end

if any(dateChoice=='m'),
    monthHigh = monthDelta.*ceil(mon(2)./monthDelta);
    monthLow = monthDelta.*floor(mon(1)./monthDelta);
    monTicks = round((monthHigh-monthLow)./monthDelta);
    monHigh = datenum(y(1),monthHigh,1);
    monLow = datenum(y(1),monthLow,1);
    % Encode location of month tick locations in format
    monFormat = 3 + (1:length(monthDelta))/10;
else
    monHigh=[]; monLow=[]; monTicks=[]; monFormat = [];
end

if any(dateChoice=='w')
    weekHigh = weekDelta.*ceil(week(2)./weekDelta);
    weekLow = weekDelta.*floor(week(1)./weekDelta);
    weekTicks = round((weekHigh-weekLow)./weekDelta);
    weekHigh = weekHigh*7+2;
    weekLow = weekLow*7+2;
    weekFormat = 6*ones(size(weekDelta));
else
    weekHigh=[]; weekLow=[]; weekTicks=[]; weekFormat=[];
end

if any(dateChoice=='d'),
    dayHigh = dayDelta.*ceil(day(2)./dayDelta);
    dayLow = dayDelta.*floor(day(1)./dayDelta);
    dayTicks = round((dayHigh-dayLow)./dayDelta);
    dayFormat = 6*ones(size(dayDelta));
else
    dayHigh=[]; dayLow=[]; dayTicks=[]; dayFormat = [];
end

if any(dateChoice=='H'),
    hourHigh = hourDelta.*ceil(hour(2)./hourDelta);
    hourLow = hourDelta.*floor(hour(1)./hourDelta);
    hourTicks = round((hourHigh-hourLow)./hourDelta);
    hourHigh = datenum(y(1),m(1),d(1),hourHigh,0,0);
    hourLow = datenum(y(1),m(1),d(1),hourLow,0,0);
    hourFormat = 15*ones(size(hourDelta));
else
    hourHigh=[]; hourLow=[]; hourTicks=[]; hourFormat=[];
end

if any(dateChoice=='M')
    minHigh = minuteDelta.*ceil(minute(2)./minuteDelta);
    minLow = minuteDelta.*floor(minute(1)./minuteDelta);
    minTicks = round((minHigh-minLow)./minuteDelta);
    minHigh = datenum(y(1),m(1),d(1),0,minHigh,0);
    minLow = datenum(y(1),m(1),d(1),0,minLow,0);
    minFormat = 15*ones(size(minuteDelta));
else
    minHigh=[]; minLow=[]; minTicks=[]; minFormat=[];
end

if any(dateChoice=='S'),
    secHigh = secondDelta.*ceil(second(2)./secondDelta);
    secLow = secondDelta.*floor(second(1)./secondDelta);
    secTicks = round((secHigh-secLow)./secondDelta);
    secHigh = datenum(y(1),m(1),d(1),0,0,secHigh);
    secLow = datenum(y(1),m(1),d(1),0,0,secLow);
    secFormat = 13*ones(size(secondDelta));
else
    secHigh=[]; secLow=[]; secTicks=[]; secFormat=[];
end

% Concatenate all the date formats together to determine
% the best spacing.
high =  [yrHigh   qtrHigh   monHigh   dayHigh   weekHigh   hourHigh   minHigh   secHigh];
low =   [yrLow    qtrLow    monLow    dayLow    weekLow    hourLow    minLow    secLow];
ticks = [yrTicks  qtrTicks  monTicks  dayTicks  weekTicks  hourTicks  minTicks  secTicks];
format =[yrFormat qtrFormat monFormat dayFormat weekFormat hourFormat minFormat secFormat];

% sort the formats by number of ticks.
[ticks,ndx] = sort(ticks);
high = high(ndx);
low = low(ndx);
format = format(ndx);

% Get axis width/heigth in pixels
units = get(gca,'units');
set(gca,'units','pixels');
pos = get(gca,'position');
set(gca,'units',units);

% Determine the extent of each format in pixels
htemp = text('units','pixels',...
             'fontname',get(gca,'fontname'), ...
             'fontangle',get(gca,'fontangle'),...
             'fontsize',get(gca,'fontsize'),...
             'fontunits',get(gca,'fontunits'),...
             'fontweight',get(gca,'fontweight'),'visible','on');
if strcmp(ax,'x')
  s = repmat('W',1,length(formlen));
  set(htemp,'string',s)
  ext = get(htemp,'extent');
  % fractional width taken up by string
  if isempty(dateform)
    len = formlen(floor(format)+1);
  else
    len = formlen(dateform+1)+zeros(size(format));
  end
  extent = ext(3)/length(formlen)*len/pos(3); 
else
  set(htemp,'string',('WW')')
  ext = get(htemp,'extent');
  % fractional height taken up by string
  extent = repmat(ext(4),size(format))/pos(4); 
end
delete(htemp)

% Chose the best fit. The best fit has the least slop without overlap and
% the most ticks.
fit = (abs(xmin-low) + abs(high-xmax))./(high-low) + max(0,extent.*ticks-1);
i = find(fit == min(fit));
[dum,j] = max(ticks(i));
i = i(j);
low = low(i); high = high(i); ticks = ticks(i); format = format(i);

if floor(format) == 3, % Month format
  i = round(rem(format,1)*10); % Retrieve encoded value
  labels = datenum(y(1),linspace(monthLow(i),monthHigh(i),ticks+1),1);
  format = floor(format);
elseif floor(format) == 17, % Quarter format
  i = round(rem(format,1)*10); % Retrieve encoded value
  labels = datenum(y(1),linspace(quarterLow(i)+1,quarterHigh(i)+1,ticks+1),1);
  format = floor(format);
elseif floor(format) == 10, % Year format
  i = round(rem(format,1)*10); % Retrieve encoded value
  labels = datenum(linspace(yearLow(i),yearHigh(i),ticks+1),1,1);
  format = floor(format);
else
  labels = linspace(low,high,ticks+1);
end
