function [calibrated_efm_data, cal_time, Nprime] = cal_efm_data(efm_data, time, mill_calibration, start_string, delta_seconds);
%	function [calibrated_efm_data, cal_time, Nprime] = cal_efm_data(efm_data, time, mill_calibration, start_string, delta_seconds)
%
%	This routine produces a calibrated (V/m) output of the mill data handed to it.  The
%	advantage is you can specify a time window for the calibrated data (for ease of use)
%
%	Inputs:
%		efm_data = matrix of mill data (2,6,N)
%		time = the time array (in datetick format) (N)
%		mill_calibration = the conversion from V to E at the mills (12,2) (default: assume no calibration)
%		start_string = where the calibrated data is to start (default: start of data)
%		delta_seconds = how much of the data to calibrate (default: all data)
%
%	Outputs:
%		calibrated_efm_data = matrix of mill data (2,6,Nprime)
%		time = the time array (in datetick format) (Nprime)
%		Nprime = # of data points calibrated
%

%
%	Fixing any information that was left out
%
if ~exist('start_string','var')
   first_time = time(1);
else
   first_time = datenum(start_string);
end
if ~exist('delta_seconds','var')
   last_time = time(length(time));
else
   last_time = first_time + delta_seconds*1.1574e-5;
end
max_index = length(time);
%
%	Determine where to start the calibration
%
i=1;
while time(i) < first_time
   i = i + 1;
   if i > max_index
      error('Ran off end of time array before hitting start time');
   end
end
first_efm_index = i
%
%	Determine where to stop the calibration
%
i=1;
while time(i) < last_time
   i = i + 1;
   if i > max_index
      i = max_index;
      break;
   end
end
last_efm_index = i
%
%	Pre-size the data
%
Nprime = last_efm_index - first_efm_index + 1;
calibrated_efm_data(2,6,Nprime) = 0;
cal_time(Nprime) = 0;
%
%	Calibrate the mills
%
for point_index=first_efm_index:last_efm_index
   inter_index = point_index-first_efm_index+1;
	calibrated_efm_data(1,1,inter_index) = efm_data(1,1,point_index)*mill_calibration(1,1) + mill_calibration(1,2);
	calibrated_efm_data(1,2,inter_index) = efm_data(1,2,point_index)*mill_calibration(2,1) + mill_calibration(2,2);
	calibrated_efm_data(1,3,inter_index) = efm_data(1,3,point_index)*mill_calibration(3,1) + mill_calibration(3,2);
	calibrated_efm_data(1,4,inter_index) = efm_data(1,4,point_index)*mill_calibration(4,1) + mill_calibration(4,2);
	calibrated_efm_data(1,5,inter_index) = efm_data(1,5,point_index)*mill_calibration(5,1) + mill_calibration(5,2);
	calibrated_efm_data(1,6,inter_index) = efm_data(1,6,point_index)*mill_calibration(6,1) + mill_calibration(6,2);
	calibrated_efm_data(2,1,inter_index) = efm_data(2,1,point_index)*mill_calibration(7,1) + mill_calibration(7,2);
	calibrated_efm_data(2,2,inter_index) = efm_data(2,2,point_index)*mill_calibration(8,1) + mill_calibration(8,2);
	calibrated_efm_data(2,3,inter_index) = efm_data(2,3,point_index)*mill_calibration(9,1) + mill_calibration(9,2);
	calibrated_efm_data(2,4,inter_index) = efm_data(2,4,point_index)*mill_calibration(10,1) + mill_calibration(10,2);
	calibrated_efm_data(2,5,inter_index) = efm_data(2,5,point_index)*mill_calibration(11,1) + mill_calibration(11,2);
   calibrated_efm_data(2,6,inter_index) = efm_data(2,6,point_index)*mill_calibration(12,1) + mill_calibration(12,2);
   cal_time(inter_index) = time(point_index);
end
