function [plot_handles] = compare_best_efm_data(plot_titles, efm_data, time, s_dev_factor, plot_components, start_string, delta_seconds, window_width, orientation);
%   function [plot_handles] = compare_best_efm_data(plot_titles, efm_data, time, scale_factor, plot_components, 
%      start_string, total_seconds, window_width, orientation);
%
%   This routine plots the calibrated (in kV/m) electric field mills data.
%
%   Input:
%      plot_titles = cell array of titles for data
%      efm_data = cell array of matrix of mill data (in V/m) (6,N)
%      time = the time array (in datetick format) (N)
%      scale_factor = What fraction of data you want to plot (0-1.0).  This is to keep infrequent
%         spikes from dominating the plots (default, or set to 0: plot ALL data)
%      plot_components = character string of which components to plot as a series of x's, X's, e's, or E's 
%         (x, X, e or E means plot that component, space means don't, order is for mill and gain is the same as
%        in the global variable AIRCRAFT(WHICH_AIRCRAFT)
%         uppercase means plot with grid, lowercase without grid
%         X's mean plot as a voltage (uncalibrated) and E's mean plot as Volts/Meter (calibrated)
%      start_string = time (in datestr format or index #) where the data is to start (default or 0: start of data)
%      total_seconds = how much of the data to plot (default or 0: all data)
%            Note: if start_string is a char string, total_seconds units are seconds,
%            if start_string is an index, then total_seconds is in index #'s
%      window_width = how many seconds per plot window (default or 0: 30 minutes)
%            Note: if start_string is a char string, window_width units are seconds,
%            if start_string is an index, then window_width is in index #'s
%     orientation = is one of 'landscape', 'portrait', 'rotated', or 'tall' (default 'tall').
%
%   Output:
%      plot_handles = the handles to all of the plots
%

%
%  Load global aircraft ID
%
global AIRCRAFT WHICH_AIRCRAFT
%
%  Now see if they are defined
%
if isempty(AIRCRAFT) == 1
   error('Need to load aircraft_flags for this to work');
end
if isempty(WHICH_AIRCRAFT) == 1
   error('Need to define you aircraft (in aircraft_flags) for this to work');
end
%
%   Fixing any information that was left out
%
if ~exist('orientation','var')
   orientation = 'tall';
end
if ~exist('start_string','var')
   first_time = time(1);
else
   if ischar(start_string) == 0
      if first_time < 1
         first_time = 1;
      end
      first_time = time(start_string);
   else
      first_time = datenum(start_string);
   end
end
if ~exist('delta_seconds','var')
   last_time = time(length(time));
else
   if delta_seconds == 0
      last_time = time(length(time));
   else
      if ischar(start_string) == 0
         last_time = time(delta_seconds+start_string);
      else
         last_time = first_time + delta_seconds*1.1574e-5;
      end
   end
end
if ~exist('window_width','var')
   window_width = 30*60;
else
   if window_width == 0
      window_width = 30*60;
   end
end
if window_width > 120
   dateform = 15;
else
   dateform = 13;
end
if ~exist('s_dev_factor','var')
   s_dev_factor = 0;
else
   if s_dev_factor ~= 0
      s_dev_factor = (1.0 - s_dev_factor)*0.5*100;
      if s_dev_factor > 100
         s_dev_factor = 0;
      end
      if s_dev_factor < 0
         s_dev_factor = 0;
      end
   end
end
%
%  Determine the # of plots per graph
%
total_size = size(efm_data);
overlay_number = total_size(2);
mill_count = AIRCRAFT(WHICH_AIRCRAFT).mill_count
max_index = length(time);
if ~exist('plot_components','var')
   max_plots = mill_count;
   for i=1:max_plots
      plot_components(i) = 'X';
   end
end
%
%   Set up which components will be plotted
%
max_plots = length(plot_components)
plot_count = 0;
for index=1:max_plots
   if plot_components(index) ~= ' '
      plot_count = plot_count + 1;
   end
end
if max_plots ~= mill_count
   for index=max_plots+1:mill_count
      plot_components(index) = ' ';
   end
end
%
%   Determine where to start the plots
%
i=1;
while time(i) < first_time
   i = i + 1;
   if i > max_index
      error('Ran off end of time array before hitting start time');
   end
end
first_efm_index = i
window_start_time = first_time;
window_width_index = round(window_width/((time(2)-time(1))*86400))
i=1;
while time(i) < last_time
   i = i + 1;
   if i > max_index
      i = max_index;
      break;
   end
end
last_efm_index = i
%
%   Pre-size the data
%
presize = last_efm_index - first_efm_index + 1;
window_start_index = first_efm_index;
window_index = 1;
while window_start_index < last_efm_index
   window_end_time = window_start_time + (window_width*1.157407e-5);
   time_end = window_start_index;
   while time(time_end) <= window_end_time
      time_end = time_end + 1;
      if time_end == last_efm_index+1
         break;
      end
   end
   time_end = time_end - 1;
   if time_end > last_efm_index
      time_end = last_efm_index;
   end
   %
   %   Make sure we don't plot any small windows
   %
   if last_time - window_end_time < 0.1*window_width*1.157407e-5
      window_end_time = last_time;
      time_end = last_efm_index;
   end
   %
   %   See if we need to even print the first page
   %
  	dateChoice = 'yqmwdHMS';
	ax = 'x';
   [ticks,dateform] = bestscale(ax,window_start_time,window_end_time,dateform,dateChoice);
   ax = 'x';
   s_index = 1;
   e_index = s_index - 1 + mill_count;
   %
   %   Plot data in window
   %
   plot_handles(window_index) = figure;
   orient(plot_handles(window_index),orientation);
   plot_number = 1;
   for component_index=s_index:e_index
      if plot_components(component_index) ~= ' '
         data_component_index = component_index - s_index + 1;
         the_efm_data = efm_data{1};
         subplot(plot_count,1,plot_number),plot(time(window_start_index:time_end),0.001*squeeze(the_efm_data(data_component_index,window_start_index:time_end)));
         if plot_number == 1
            title(AIRCRAFT(WHICH_AIRCRAFT).name,'Interpreter','none');
         end
         %
         %  Now plot the rest
         %
         hold;
         for overlay_index=2:overlay_number
            if plot_components(component_index) ~= ' '
               switch overlay_index
               case 7
                  the_char = 'b';
               case {2,8}
                  the_char = 'r';
               case {3,9}
                  the_char = 'g';
               case {4,10}
                  the_char = 'c';
               case {5,11}
                  the_char = 'm';
               case {6,12}
                  the_char = 'k';
               end
               data_component_index = component_index - s_index + 1;
               the_efm_data = efm_data{overlay_index};
               subplot(plot_count,1,plot_number),plot(time(window_start_index:time_end),0.001*squeeze(the_efm_data(data_component_index,window_start_index:time_end)),the_char);
            end
         end
         if plot_number == 1
            legend(plot_titles(1:overlay_number),0);
         end
         axis tight;
         YY = axis;
         YY(1) = window_start_time;
         YY(2) = window_end_time;
         axis(YY);
         ax = 'x';
         %
         % Set axis tick labels
         %
         labels = datestr(ticks,dateform);
         set(gca,[ax,'tick'],ticks,[ax,'ticklabel'],labels, ...
            [ax,'lim'],[min(ticks) max(ticks)])
         date_strings = get(gca,'xticklabel');
         axis(YY);
         set(gca,'xticklabel',[]);
         ylabel('kV/m');
         text(1,0.5,AIRCRAFT(WHICH_AIRCRAFT).position_ID(data_component_index,:),'Units','normalized');
         if s_dev_factor ~= 0.0
            for overlay_index=2:overlay_number
               the_efm_data = efm_data{overlay_index};
               y_maxx(overlay_index) = prctile(0.001*squeeze(the_efm_data(data_component_index,window_start_index:time_end)),100-s_dev_factor);
               y_minn(overlay_index) = prctile(0.001*squeeze(efm_data(data_component_index,window_start_index:time_end)),s_dev_factor);
            end
            y_max = max(y_maxx);
            y_min = min(y_minn);
            if y_max ~= y_min
               axis_value = axis;
               if isnan(y_max)
                  the_efm_data = efm_data{1};
                  y_max = max(0.001*squeeze(the_efm_data(data_component_index,window_start_index:time_end)));
               end
               if isnan(y_min)
                  the_efm_data = efm_data{1};
                  y_min = min(0.001*squeeze(the_efm_data(data_component_index,window_start_index:time_end)));
               end
               axis_value(3) = y_min;
               axis_value(4) = y_max;
               axis(axis_value);
            end
         end
         plot_number = plot_number + 1;
         if lower(plot_components(component_index)) == plot_components(component_index)
            grid off;
         else
            grid on;
         end
      end
   end
   set(gca, 'xticklabel', date_strings);
   xlabel(datestr(time(window_start_index),0));
   window_index = window_index + 1;
   window_start_index = time_end;
   window_start_time = window_end_time;
end
