function [plot_handles] = compare_field_data_plot(plot_titles,field_data_matrix, time, s_dev_factor, plot_components, start_string, delta_seconds, window_width,orientation);
% function [plot_handles] = compare_field_data_plot(plot_titles, field_data_matrix, time, scale_factor, plot_components,
%  start_string, total_seconds, window_width, orientation)
%
% This routine plots the electric field vectors based on the options
%   and makes png files with names based on the xlabels
%
% Inputs:
%     plot_titles = 1 dimensional cell array of labels for the each component of the field_data_matrix
%  field_data_matrix = (A,6,N) matrix of electric field data where A is the index of the
%        different data sets to compare (either X,Y,Z or N,W,U)
%   note: the last three components are the Eq, Emag, and Qfactor
%  time = the (1,N) time array (in datetick format)
%  scale_factor = What fraction of data you want to plot (0-1.0).  This is to keep infrequent
%   spikes from dominating the plots (default, or set to 0: plot ALL data)
%  plot_components = character string of which components to plot as a series of x's, n's,
%   X's, N's or spaces (x, X, N, or n means plot that component, space means don't)
%   if you use x's then program assumes aircraft fields, if you use n's then program
%   assumes Earth fields (default: all, aircraft fields)
%   If you use upper case letters, a grid will be printed
%  start_string = time (in datestr format or index #) where the data is to start (default or 0: start of data)
%  total_seconds = how much of the data to plot (default or 0: all data)
%    Note: if start_string is a char string, total_seconds units are seconds,
%    if start_string is an index, then total_seconds is in index #'s
%  window_width = how many seconds per plot window (default or 0: 30 minutes)
%    Note: if start_string is a char string, window_width units are seconds,
%    if start_string is an index, then window_width is in index #'s
%     orientation = is one of 'landscape', 'portrait', 'rotated', or 'tall' (default 'tall').
%
% Output:
%  plot_handles = the handles to all of the plots
%
   
%
%  Load global aircraft ID
%
   global AIRCRAFT WHICH_AIRCRAFT
   %
   %  Now see if they are defined
   %
   if isempty(AIRCRAFT) == 1
      warning('Need to load aircraft_flags for this to work');
      WHICH_AIRCRAFT = 0;
   end
   if isempty(WHICH_AIRCRAFT) == 1
      warning('Need to define you aircraft (in aircraft_flags) for this to work');
      WHICH_AIRCRAFT = 0;
   end
   %
   % Set defaults
   %
   if ~exist('orientation','var')
      orientation = 'tall';
   end
   if ~exist('s_dev_factor','var')
      s_dev_factor = 0;
   else
      if s_dev_factor ~= 0
         s_dev_factor = (1.0 - s_dev_factor)*0.5*100;
         if s_dev_factor > 100
            s_dev_factor = 0;
         end
         if s_dev_factor < 0
            s_dev_factor = 0;
         end
      end
   end
   if ~exist('plot_components','var')
      plot_components = 'xxxxxx';
   end
   if ~exist('start_string','var')
      first_time = time(1);
   else
      first_time = time(1);
      if ischar(start_string) == 0
         if first_time < 1
            first_time = 1;
         end
         first_time = time(start_string);
      else
         first_time = datenum(start_string);
      end
   end
   if ~exist('delta_seconds','var')
      last_time = time(length(time));
   else
      if delta_seconds == 0
         last_time = time(length(time));
      else
         if ischar(start_string) == 0
            last_time = time(delta_seconds+start_string);
         else
            last_time = first_time + delta_seconds*1.1574e-5;
         end
      end
   end
   if ~exist('window_width','var')
      window_width = 30*60;
   else
      if window_width == 0
         window_width = 30*60;
      else
         if ischar(start_string) == 0
            window_width = (time(window_width) - time(1))*86400;
         end
      end
   end
   %legend_text = [' 1';' 2';' 3';' 4';' 5';' 6';' 7';' 8';' 9';'10';'11';'12'];
   max_index = length(time);
   max_plots = length(plot_components);
   plot_count = 0;
   for index=1:max_plots
      switch lower(plot_components(index))
       case 'x'
         plot_count = plot_count + 1;
       case 'n'
         plot_count = plot_count + 1;
      end
   end
   if max_plots ~= 6
      for index=max_plots+1:6
         plot_components(index) = ' ';
      end
   end
   %
   % Determine where to start/stop the plots
   %
   i=1;
   while time(i) < first_time
      i = i + 1;
      if i > max_index
         error('Ran off end of time array before hitting start time');
      end
   end
   first_index = i
   window_width_index = round(window_width/((time(2)-time(1))*86400));
   i=1;
   while time(i) < last_time
      i = i + 1;
      if i > max_index
         i = max_index;
         break;
      end
   end
   last_index = i
   window_start_time = first_time;
   window_start_index = first_index;
   window_index = 1;
   if window_width > 120
      dateform = 15;
   else
      dateform = 13;
   end
   while window_start_index < last_index
      %
      % Set the window edges
      %
      time_end = window_start_index;
      window_end_time = window_start_time + (window_width*1.157407e-5);
      %
      % Make sure we don't plot any small windows
      %
      if last_time - window_end_time < 0.1*window_width*1.157407e-5
         window_end_time = last_time;
      end
      while time(time_end) <= window_end_time
         time_end = time_end + 1;
         if time_end == max_index
            break;
         end
      end
      time_end = time_end - 1;
      %
      %    Make sure we have data within the window
      %
      if time_end > window_start_index
         %
         % Plot field data in window
         %
         if window_start_index < time_end
            plot_handles(window_index) = figure;
            orient(plot_handles(window_index),orientation);
         end
         plot_number = 1;
         %
         %  Determine how many plots on a screen
         %
         total_size = size(field_data_matrix);
         plot_counter = total_size(1);
         %
         % Now do the plots
         %
         window_start_index
         time_end
         %
         %  Set time tick basis
         %
         dateChoice = 'yqmwdHMS';
         ax = 'x';
         [ticks,dateform] = bestscale(ax,window_start_time,window_end_time,dateform,dateChoice);
         for plotting_index=1:6
            if plot_components(plotting_index) ~= ' '
               if plotting_index ~= 6
                  subplot(plot_count,1,plot_number),plot(time(window_start_index:time_end),0.001*squeeze(field_data_matrix(1,plotting_index,window_start_index:time_end)),'b');
               else
                  subplot(plot_count,1,plot_number),plot(time(window_start_index:time_end),squeeze(field_data_matrix(1,6,window_start_index:time_end)),'b');
               end
               %
               %  Now plot other data on top
               %
               hold on;
               for plot_index=2:plot_counter
                  switch plot_index
                   case 7
                     the_char = 'b';
                   case {2,8}
                     the_char = 'r';
                   case {3,9}
                     the_char = 'g';
                   case {4,10}
                     the_char = 'c';
                   case {5,11}
                     the_char = 'm';
                   case {6,12}
                     the_char = 'k';
                  end
                  if plotting_index ~= 6
                     subplot(plot_count,1,plot_number),plot(time(window_start_index:time_end),0.001*squeeze(field_data_matrix(plot_index,plotting_index,window_start_index:time_end)),the_char);
                  else
                     subplot(plot_count,1,plot_number),plot(time(window_start_index:time_end),squeeze(field_data_matrix(plot_index,6,window_start_index:time_end)),the_char);
                  end
               end
               if plot_number == 1
                  if WHICH_AIRCRAFT ~= 0
                     title([AIRCRAFT(WHICH_AIRCRAFT).name,' ',strcat(inputname(1),' Electric Field')],'Interpreter','none');
                  else
                     title(['Unknown Aircraft ',strcat(inputname(1),' Electric Field')],'Interpreter','none');
                  end
                  legend(plot_titles(1:plot_counter),0);
               end
               axis tight;
               YY = axis;
               YY(1) = window_start_time;
               YY(2) = window_end_time;
               axis(YY);
               % Set axis tick labels
               labels = datestr(ticks,dateform);
               set(gca,[ax,'tick'],ticks,[ax,'ticklabel'],labels, ...
                    [ax,'lim'],[min(ticks) max(ticks)])
               date_strings = get(gca,'xticklabel');
               axis(YY);
               set(gca,'xticklabel',[]);
               if plotting_index ~= 6
                  ylabel('kV/m');
               end
               if lower(plot_components(plotting_index)) == 'n'
                  switch plotting_index
                   case 1
                     text(1,0.5,'En','Units','normalized');
                   case 2
                     text(1,0.5,'Ew','Units','normalized');
                   case 3
                     text(1,0.5,'Eu','Units','normalized');
                   case 4
                     text(1,0.5,'Eq','Units','normalized');
                   case 5
                     text(1,0.5,'Emag','Units','normalized');
                   case 6
                     text(1,0.5,'Quality/Slack','Units','normalized');
                  end
               else
                  switch plotting_index
                   case 3
                     text(1,0.5,'Ez','Units','normalized');
                   case 2
                     text(1,0.5,'Ey','Units','normalized');
                   case 1
                     text(1,0.5,'Ex','Units','normalized');
                   case 4
                     text(1,0.5,'Eq','Units','normalized');
                   case 5
                     text(1,0.5,'Emag','Units','normalized');
                   case 6
                     text(1,0.5,'Quality/Slack','Units','normalized');
                  end
               end
               if plotting_index ~= 6
                  if s_dev_factor ~= 0.0
                     for plot_index=1:plot_counter
                        y_ma(plot_index) = prctile(squeeze(0.001*field_data_matrix(plot_index,plotting_index,window_start_index:time_end)),100-s_dev_factor);
                        y_mi(plot_index) = prctile(squeeze(0.001*field_data_matrix(plot_index,plotting_index,window_start_index:time_end)),s_dev_factor);
                     end
                     y_max = max(y_ma);
                     y_min = min(y_mi);
                     axis_value = axis;
                     if ~isempty(y_min)
                        axis_value(3) = y_min;
                     end
                     if ~isempty(y_max);
                        axis_value(4) = y_max;
                     end
                     if y_max ~= y_min
                        %              if isnan(y_max)
                        %                 y_max = max(0.001*field_data_matrix(plotting_index,window_start_index:time_end));
                        %              end
                        %              if isnan(y_min)
                        %                 y_min = min(0.001*field_data_matrix(plotting_index,window_start_index:time_end));
                        %              end
                        axis_value(3) = y_min;
                        axis_value(4) = y_max;
                        if y_max ~= y_min
                           axis(axis_value);
                        end
                     end
                  end
               else
                  V4 = axis;
                  if s_dev_factor ~= 0.0
                     y_max = prctile(squeeze(field_data_matrix(plot_index,plotting_index,window_start_index:time_end)),100-s_dev_factor);
                     y_min = prctile(squeeze(field_data_matrix(plot_index,plotting_index,window_start_index:time_end)),s_dev_factor);
                     if ~isempty(y_min)
                        V4(3) = min([y_min 1]);
                     else
                        V4(3) = 0;
                     end
                     if ~isempty(y_max)
                        V4(4) = max([y_max 1]);
                     else
                        V4(4) = 0;
                     end
                  else
                     %                  plot_index
                     %                  plotting_index
                     %                  window_start_index
                     %                  time_end
                     %                  size(field_data_matrix)
                     %                  min(plot_index,field_data_matrix(plotting_index,window_start_index:time_end));
                     y_min = min(field_data_matrix(plot_index,plotting_index,window_start_index:time_end));
                     V4(3) = min([0 y_min]);
                     y_max = max(field_data_matrix(plot_index,plotting_index,window_start_index:time_end));
                     V4(4) = max([1 y_max]);
                  end
                  axis(V4);
               end
               plot_number = plot_number + 1;
               if lower(plot_components(plotting_index)) == plot_components(plotting_index)
                  grid off;
               else
                  grid on;
                  %              set(gca,'GridLineStyle','--');
               end
            end
         end
         if window_start_index < time_end
            set(gca, 'xticklabel', date_strings);
            xlabel(datestr(time(window_start_index),0));
         end
         %
         %    Now plot the figure
         %
         figure_title = sprintf('%s.png',datestr(time(window_start_index),0));
         figure_title = strrep(figure_title,' ','_');
         figure_title = strrep(figure_title,'-','_');
         figure_title = strrep(figure_title,':','_')
         print('-dpng',figure_title);
         %
         % Prepare for next group
         %
         window_start_index = time_end + 1;
         window_index = window_index + 1;
     end
     window_start_time = window_end_time;
 end
 