function [resampled_pos_orientation_matrix, resampled_pos_location_matrix, resampled_pos_data_matrix, resampled_nav_data, pos_time] = convert_ICATS_2_pos_data(nav_data_matrix, efm_time);
%	function [pos_orientation_matrix, pos_location_matrix, resampled_pos_location_matrix, resampled_nav_matrix, data_time] = 
%		convert_ICATS_2_pos_data(nav_data_matrix, efm_time)
%
%	This routine resamples the pos data to lock with the efm data using the Matlab
%		function interp1 and cubic interp.
%
%	Inputs:
%		nav_data+matrix = input aircraft NAV data matrix
%		efm_time = efm time base
%
%	Outputs:
%		pos_orientation_matrix = aircraft orientation matrix sampled to match efm data
%		pos_location_matrix = aircraft location matrix sampled to match efm data
%		pos_data_matrix = aircraft "data" matrix sampled to match efm data (note: the
%        variables in this "data" DO NOT match the ones in the POS/ABFM set, they
%        are just created to allow the use of plot_pos_data)
%     data_time = time vector at the nav_data_matrix rate
%

%
%	Preset sizes
%
new_size = length(efm_time);
resampled_pos_orientation_matrix(3,new_size) = 0;
resampled_pos_location_matrix(5,new_size) = 0;
resampled_pos_data_matrix(6,new_size) = 0;
resampled_nav_data = nav_data_matrix;
old_size = length(nav_data_matrix);
pos_time(old_size) = 0;
pos_orientation_matrix(3,old_size) = 0;
pos_location_matrix(5,old_size) = 0;
%
%  Dump the orientation & location data into the "old" matrix
%  along with the "data" part
%
for old_index=1:old_size
   if nav_data_matrix(old_index).day ~= 200
      file_stuff = datevec(yearday(nav_data_matrix(old_index).year,nav_data_matrix(old_index).day));
      pos_time(old_index) = datenum(nav_data_matrix(old_index).year,file_stuff(2),file_stuff(3),nav_data_matrix(old_index).hour,nav_data_matrix(old_index).min,nav_data_matrix(old_index).sec);
      pos_location_matrix(1,old_index) = nav_data_matrix(old_index).latitude;
      pos_location_matrix(2,old_index) = nav_data_matrix(old_index).longitude;
      pos_location_matrix(3,old_index) = nav_data_matrix(old_index).radar_alt*3.04e-1;
      pos_location_matrix(4,old_index) = nav_data_matrix(old_index).drift_angle;
      pos_location_matrix(5,old_index) = nav_data_matrix(old_index).gnd_speed;
      pos_orientation_matrix(1,old_index) = nav_data_matrix(old_index).roll;
      pos_orientation_matrix(2,old_index) = nav_data_matrix(old_index).pitch;
      pos_orientation_matrix(3,old_index) = nav_data_matrix(old_index).true_head;
      pos_data_matrix(1,old_index) = nav_data_matrix(old_index).egi_x_accel;
      pos_data_matrix(2,old_index) = nav_data_matrix(old_index).egi_y_accel;
      pos_data_matrix(3,old_index) = nav_data_matrix(old_index).egi_z_accel;
      pos_data_matrix(4,old_index) = nav_data_matrix(old_index).RH_ice;
      pos_data_matrix(5,old_index) = nav_data_matrix(old_index).RH_wat;
      pos_data_matrix(6,old_index) = nav_data_matrix(old_index).par_press_h20;
   else
      %
      %  That is a bad data flag, fix things
      %
      file_stuff = datevec(yearday(nav_data_matrix(old_index+1).year,nav_data_matrix(old_index+1).day));
      pos_time(old_index) = datenum(nav_data_matrix(old_index+1).year,file_stuff(2),file_stuff(3),nav_data_matrix(old_index+1).hour,nav_data_matrix(old_index+1).min,(nav_data_matrix(old_index+1).sec-1));
      pos_location_matrix(1,old_index) = nav_data_matrix(old_index+1).latitude;
      pos_location_matrix(2,old_index) = nav_data_matrix(old_index+1).longitude;
      pos_location_matrix(3,old_index) = nav_data_matrix(old_index+1).radar_alt*3.04e-1;
      pos_location_matrix(4,old_index) = nav_data_matrix(old_index+1).drift_angle;
      pos_location_matrix(5,old_index) = nav_data_matrix(old_index+1).gnd_speed;
      pos_orientation_matrix(1,old_index) = nav_data_matrix(old_index+1).roll;
      pos_orientation_matrix(2,old_index) = nav_data_matrix(old_index+1).pitch;
      pos_orientation_matrix(3,old_index) = nav_data_matrix(old_index+1).true_head;
      pos_data_matrix(1,old_index) = nav_data_matrix(old_index+1).egi_x_accel;
      pos_data_matrix(2,old_index) = nav_data_matrix(old_index+1).egi_y_accel;
      pos_data_matrix(3,old_index) = nav_data_matrix(old_index+1).egi_z_accel;
      pos_data_matrix(4,old_index) = nav_data_matrix(old_index+1).RH_ice;
      pos_data_matrix(5,old_index) = nav_data_matrix(old_index+1).RH_wat;
      pos_data_matrix(6,old_index) = nav_data_matrix(old_index+1).par_press_h20;
   end   
end
%
%  Check increasing time
%
h = diff(pos_time)*86400;
if any(h <= 0)
   %
   %  We have a backwards time jump
   %
   bad_index = -99;
   bad_index_count = 0;
   index = 2;
   while index <= old_size
      change_index = 0;
      if pos_time(index) <= pos_time(index-1)
         if bad_index == index-1
            bad_index_count = bad_index_count+1;
         else
            bad_index = index;
            bad_index_count = 0;
         end
      end
      while pos_time(index) <= pos_time(index-1)
         %
         %  We have time reversal, try simple fix
         % 
         pos_time(index) = pos_time(index) + 1/86400;
         change_index = change_index + 1;
         %
         %  Now see if this is enough
         %
         if change_index > 20
            %
            %  Something weird is going on, delete the datapoint
            %
            warning('Problem with a single pos_time');
            index
            pos_time(index) = [];
            pos_orientation_matrix(:,index) = [];
            pos_location_matrix(:,index) = [];
            pos_data_matrix(:,index) = [];
            resampled_nav_data(index) = [];
            old_size = length(pos_time);
            index = index - 1;
            break;
         end
      end
      if bad_index_count > 20
         warning('Problem with a group of pos_times');
         index
         bad_index_count = 0;
      end
      index = index + 1;
   end
end
%
%	Now do the interp
%
for index=1:3
   resampled_pos_orientation_matrix(index,:) = interp1(pos_time, pos_orientation_matrix(index,:), efm_time);
end
for index=1:5
   resampled_pos_location_matrix(index,:) = interp1(pos_time, pos_location_matrix(index,:), efm_time);
end
for index=1:6
   resampled_pos_data_matrix(index,:) = interp1(pos_time, pos_data_matrix(index,:), efm_time);
end
