function [earth_E_matrix] = convert_aircraft_2_flatearth_E(aircraft_data_matrix,pos_orientation_matrix);
%	[earth_E_matrix] = convert_aircraft_2_flatearth_E(aircraft_data_matrix, pos_orientation_matrix)
%
%	This routine determines the flat earth frame (aircraft_direction,Up, 90 deg from heading) electric fields from the aircraft (X, Y, Z)
%		frame data.  Note that a positive roll and pitch angle is CCW while the heading is CW.  The 
%		transformations are in the following order:
%
%			Ee = R*P*Ea
%
%		If this is the wrong order or orientation, the output will be wrong.
%
%	Inputs:
%		aircraft_data_matrix = the (6,N) matrix of aircraft E data (Ex, Ey, Ez, Eq, Emag, Qfactor)
%		pos_orientation_matrix = the (3,N) matrix of aircraft orientation (roll, pitch, heading)
%			(note that the orientation matrix needs to be resampled to the aircraft data rate)
%
%	Outputs:
%		earth_E_matrix = the (6,N) matrix of the earth oriented (En, Ew, Eu, Q, Emag, Qfactor) electric fields
%

%
%	Size the data
%
Ntot = length(aircraft_data_matrix);
earth_E_matrix(6,Ntot) = 0;
%
%	Constant
%
deg_2_rad = pi/180.0;
%
%	Do loop
%
for data_index=1:Ntot
   roll_sin = sin(pos_orientation_matrix(1,data_index)*deg_2_rad);
   roll_cos = cos(pos_orientation_matrix(1,data_index)*deg_2_rad);
   Roll = [1 0 0 0 0 0; 0 roll_cos -roll_sin 0 0 0; 0 roll_sin roll_cos 0 0 0; 0 0 0 1 0 0; 0 0 0 0 1 0; 0 0 0 0 0 1];
   pitch_sin = sin(pos_orientation_matrix(2,data_index)*deg_2_rad);
   pitch_cos = cos(pos_orientation_matrix(2,data_index)*deg_2_rad);
   Pitch = [pitch_cos 0 -pitch_sin 0 0 0; 0 1 0 0 0 0; pitch_sin 0 pitch_cos 0 0 0; 0 0 0 1 0 0; 0 0 0 0 1 0; 0 0 0 0 0 1];
%   heading_sin = sin(pos_orientation_matrix(3,data_index)*deg_2_rad);
%   heading_cos = cos(pos_orientation_matrix(3,data_index)*deg_2_rad);
%   Heading = [heading_cos heading_sin 0 0 0 0; -heading_sin heading_cos 0 0 0 0; 0 0 1 0 0 0; 0 0 0 1 0 0; 0 0 0 0 1 0; 0 0 0 0 0 1];
   %
   %	Now do matrix math
   %
   earth_E_matrix(:,data_index) = Roll*Pitch*aircraft_data_matrix(:,data_index);
end

