function [aircraft_E_matrix,best_mill,gain] = convert_mill_2_aircraft_E(efm_data_matrix,conversion_matrix,offsets);
%	function [aircraft_E_matrix, best_mill, gain] = convert_mill_2_aircraft_E(mill_E_matrix, conversion_matrix, offsets)
%
%	This routine determines the aircraft frame electric fields from the mill electric fields
%
%	Inputs:
%		mill_E_matrix = the (2,6,N) matrix of mill electric field values
%		conversion_matrix = the (4,6) matrix to convert a mill set of E 
%        to an aircraft set of E
%     offsets = the (2,6) DC offset values for the mills (optional)
%
%	Outputs:
%		aircraft_E_matrix = the (6,N) matrix of the aircraft oriented electric fields
%			Ex, Ey, Ez, Eq, Emag, Qfactor (subjective quality of the vector E data based on relative
%			sizes of Emag and Eq data)
%       best_mill = (6,N) matrix of the mll values used in the aircraft E electric field calculations
%		gain = the (6,N) matrix of gains used in the calculations (1=sensitive, 2=insensitive)
%

%
%  See if the user entered offsets
%
if ~exist('offsets','var')
   offsets(1:2,1:6) = 0.0;
end
%
%  Now put in the offsets
%
how_big = length(efm_data_matrix);
for value_index=1:how_big
   for mill_index=1:6
      for gain_index=1:2
         efm_data_matrix(gain_index,mill_index,value_index) = efm_data_matrix(gain_index,mill_index,value_index) - offsets(gain_index,mill_index);
      end
   end
end
%
%	Build the best set of mill data
%	(use sensitive gain unless near saturation)
%
up_factor = 0.95;
down_factor = 0.25;
low_gain_max_E = 60000;
E_limit = low_gain_max_E*up_factor;
E_minit = low_gain_max_E*down_factor;
best_mill(6,how_big) = 0;
gain(6,how_big) = 0;
last_gain(1:6) = 1;
best_mill = squeeze(efm_data_matrix(1,:,:));
for value_index=1:how_big
   for mill_index=1:6
      if last_gain(mill_index) == 1
         if (best_mill(mill_index,value_index) > E_limit) | (best_mill(mill_index,value_index) < -E_limit)
            best_mill(mill_index,value_index) = efm_data_matrix(2,mill_index,value_index);
            gain(mill_index,value_index) = 2;
            last_gain(mill_index) = 2;
%            if (value_index > 36131) & (value_index < 39131) & (mill_index == 1)
%               efm_data_matrix(1,mill_index,value_index)
%               E_limit
%            end
         else
            gain(mill_index,value_index) = 1;
            last_gain(mill_index) = 1;
         end
      else
         if (best_mill(mill_index,value_index) > E_minit) | (best_mill(mill_index,value_index) < -E_minit)
	         best_mill(mill_index,value_index) = efm_data_matrix(2,mill_index,value_index);
	         gain(mill_index,value_index) = 2;
	         last_gain(mill_index) = 2;
         else
            gain(mill_index,value_index) = 1;
            last_gain(mill_index) = 1;
%            if (value_index > 36131) & (value_index < 39131) & (mill_index == 1)
%               efm_data_matrix(1,mill_index,value_index)
%               E_minit
%            end
         end
      end
   end
end
%
%	Now we have the best V/m, do the calibration
%
aircraft_E_matrix = conversion_matrix*best_mill;
%
%	Now calculate the "quality" and magnitude
%
quality(how_big) = 0;
factor_it = 2/pi;
magE = aircraft_E_matrix(1,:).*aircraft_E_matrix(1,:) + aircraft_E_matrix(2,:).*aircraft_E_matrix(2,:) + aircraft_E_matrix(3,:).*aircraft_E_matrix(3,:);
magQ = aircraft_E_matrix(4,:).*aircraft_E_matrix(4,:);
quality = atan2(magE,magQ)*factor_it;
aircraft_E_matrix(6,:) = quality;
aircraft_E_matrix(5,:) = sqrt(magE);
