function [aircraft_E_matrix,best_mill,gain] = convert_mill_2_dc8_E(efm_data_matrix,conversion_matrix);
%	function [aircraft_E_matrix, best_mill, gain] = convert_mill_2_dc8_E(mill_E_matrix, conversion_matrix)
%
%	This routine determines the aircraft frame electric fields from the mill electric fields
%
%	Inputs:
%		mill_E_matrix = the (4,6,N) matrix of mill electric field values from the DC-8
%		conversion_matrix = the (4,6) matrix to convert a mill set of E to an aircraft set of E
%
%	Outputs:
%		aircraft_E_matrix = the (6,N) matrix of the aircraft oriented electric fields
%			Ex, Ey, Ez, Eq, Emag, Qfactor (subjective quality of the vector E data based on relative
%			sizes of Emag and Eq data)
%       best_mill = (6,N) matrix of the mill values used in the aircraft E electric field calculations
%		gain = the (6,N) matrix of gains used in the calculations (1=x512, 2=x64, 3=x8, 4=x1)
%

%
%	First, build the best set of mill data
%	(use sensitive gain unless near saturation)
%
up_factor = 0.9;
down_factor = 0.5;
x512_max_E = 7.5e3;
x64_max_E = 6.2e4;
x8_max_E = 5.0e5;
x1_max_E = 4.0e6;
E_limit(1) = x512_max_E*up_factor;
E_minit(1) = x512_max_E*down_factor;
E_limit(2) = x64_max_E*up_factor;
E_minit(2) = x64_max_E*down_factor;
E_limit(3) = x8_max_E*up_factor;
E_minit(3) = x8_max_E*down_factor;
E_limit(4) = x1_max_E*up_factor;
E_minit(4) = x1_max_E*down_factor;
how_big = length(efm_data_matrix);
best_mill(6,how_big) = 0;
gain(6,how_big) = 0;
last_gain(1:6) = 1;
best_mill = squeeze(efm_data_matrix(1,:,:));
for value_index=1:how_big
   for mill_index=1:6
      gain(mill_index,value_index) = last_gain(mill_index);
      test_val = abs(efm_data_matrix(gain(mill_index,value_index),mill_index,value_index));
      %
      %  Test for near saturation
      %
      while test_val > E_limit(gain(mill_index,value_index))
         %
         %  gain needs to be increased
         %
         gain(mill_index,value_index) = gain(mill_index,value_index) + 1;
         if gain(mill_index,value_index) > 4
            the_string = sprintf('Gain x1 saturated on mill %1d at index %d',mill_index,value_index);
            warning(the_string);
            gain(mill_index,value_index) = 4;
            break;
         end
         test_val = abs(efm_data_matrix(gain(mill_index,value_index),mill_index,value_index));
      end
      %
      %  Now test to see if we need to come down on the gain
      %
      if gain(mill_index,value_index) > 1
         test_val = abs(efm_data_matrix(gain(mill_index,value_index)-1,mill_index,value_index));
         if test_val < E_minit(gain(mill_index,value_index)-1)
            %
            %  We need to lower the gain by one
            %
            gain(mill_index,value_index) = gain(mill_index,value_index) - 1;
         end
      end
      best_mill(mill_index,value_index) = efm_data_matrix(gain(mill_index,value_index),mill_index,value_index);
      gain(mill_index,value_index) = gain(mill_index,value_index);
      last_gain(mill_index) = gain(mill_index,value_index);
   end
%   if value_index*0.001 == floor(value_index*0.001)
%      value_index
%   end
end
%
%	Now we have the best V/m, do the calibration
%
aircraft_E_matrix = conversion_matrix*best_mill;
%
%	Now calculate the "quality" and magnitude
%
quality(how_big) = 0;
factor_it = 2/pi;
magE = aircraft_E_matrix(1,:).*aircraft_E_matrix(1,:) + aircraft_E_matrix(2,:).*aircraft_E_matrix(2,:) + aircraft_E_matrix(3,:).*aircraft_E_matrix(3,:);
magQ = aircraft_E_matrix(4,:).*aircraft_E_matrix(4,:);
quality = atan2(magE,magQ)*factor_it;
aircraft_E_matrix(6,:) = quality;
aircraft_E_matrix(5,:) = sqrt(magE);
