function [radar_value, max_radar_value, total_radar_value, total_radar_count] = get_radar_value(radar_matrix, latlon_origin, x_dim, y_dim, aircraft_lat, aircraft_lon, standoff);
%
%  function [radar_value, max_radar_value] = get_radar_value(radar_matrix, latlon_origin, 
%     grid_origin, aircraft_lat, aircraft_lon, standoff);
%
%  This routine will find the radar data at the aircraft locations and the max value 
%  within 'standoff' of the aircraft location
%
%  Input:
%     radar_matrix = the NxM grid of 1 km radar data
%     latlon_origin = the latitude/longitude of the radar (at x_dim, y_dim = 0)
%     x_dim, y_dim = the grid locations of the data
%     aircraft_lat, aircraft_lon = aircraft lat & lon locations
%     standoff = the range in km to find the max radar value
%
%  Outputs:
%     radar_value = 1xL array of radar values at the aircraft locations
%     max_radar_value = 1xL array of max radar values within 'standoff' of the aircraft locations
%     total_radar_value = 1xL array of total radar values within 'standoff' of the aircraft locations
%

%
%  First determine the # of aircraft points
%
how_big = size(aircraft_lon);
the_length = how_big(2);
how_big = size(radar_matrix);
for data_index=1:the_length
   data_index;
   %
   %  Aircraft location
   %
   [x, y, r] = GPS_PosnDiff(latlon_origin(1), latlon_origin(2), aircraft_lat(data_index), aircraft_lon(data_index));
   x_radar_index = interp1(x_dim,1:how_big(1),x,'nearest',NaN);
   y_radar_index = interp1(y_dim,1:how_big(2),y,'nearest',NaN);
   %
   %  First radar data at the point
   %
   if isnan(x_radar_index) | isnan(y_radar_index)
      %
      %  Its off the array
      %
      radar_value(data_index) = NaN;
   else
      %
      %  Its in the array, mark the point
      %
      radar_value(data_index) = radar_matrix(y_radar_index, x_radar_index);
   end
   %
   %  Now look in general area
   %
   max_radar_value(data_index) = radar_value(data_index);
   total_radar_value(data_index) = 0;
   total_radar_count(data_index) = 0;
   if ~isnan(x_radar_index) & ~isnan(y_radar_index)
      for search_x_index=x_radar_index-standoff:x_radar_index+standoff
         for search_y_index=y_radar_index-standoff:y_radar_index+standoff
            the_y_index = round(search_y_index);
            the_x_index = round(search_x_index);
            if (the_x_index > 0) & (the_x_index <= how_big(2)) & (the_y_index > 0) & (the_y_index <= how_big(1))
               %
               %  Its on the radar array, see if it is withing direct standoff of the aircraft location
               %
               the_distance = sqrt((search_x_index-x_radar_index)^2 + (search_y_index-y_radar_index)^2);
               if the_distance <= standoff
                  total_radar_value(data_index) = total_radar_value(data_index) + radar_matrix(the_y_index,the_x_index);
                  total_radar_count(data_index) = total_radar_count(data_index) + 1;
                  if (radar_matrix(the_y_index,the_x_index) > max_radar_value(data_index)) | isnan(max_radar_value(data_index))
                     max_radar_value(data_index) = radar_matrix(the_y_index,the_x_index);
                  end
               end
            end
         end
      end
   else
      max_radar_value(data_index) = NaN;
   end
end
%
%  that should be all!
%
return;

function [value] = the_nearest_index(the_dim)
%
%  This routine will find the closest index