function [year, month, day, hour, minute, second] = jday2jdate(jday)
%JDAY2JDATE Julian day number to Julian calendar date.
%
%   [YEAR, MONTH, DAY, HOUR, MINUTE, SECOND] = JDAY2JDATE(JDAY) returns the
%   Julian calendar date (year, month, day, hour, minute, and second)
%   corresponding to the Julian day number JDAY.
%
%   Start of the JD (Julian day) count is from 0 at 12 noon 1 JAN -4712
%   (4713 BC), Julian proleptic calendar.  Note that this day count conforms
%   with the astronomical convention starting the day at noon, in contrast
%   with the civil practice where the day starts with midnight.
%
%   Astronomers have used the Julian period to assign a unique number to
%   every day since 1 January 4713 BC.  This is the so-called Julian Day
%   (JD). JD 0 designates the 24 hours from noon UTC on 1 January 4713 BC
%   (Julian calendar) to noon UTC on 2 January 4713 BC.

%   Sources:  - http://tycho.usno.navy.mil/mjd.html
%             - The Calendar FAQ (http://www.faqs.org)

%   Author:      Peter J. Acklam
%   Time-stamp:  2001-02-16 15:27:17
%   E-mail:      jacklam@math.uio.no
%   URL:         http://www.math.uio.no/~jacklam

   nargsin = nargin;
   error(nargchk(1, 1, nargsin));

   ijday = floor(jday);                 % integer part
   fjday = jday - ijday;                % fraction part

   second = 86400 * fjday;
   hour   = fix(second/3600);           % get number of hours
   second = second - 3600*hour;         % remove the hours
   minute = fix(second/60);             % get number of minutes
   second = second - 60*minute;         % remove the minutes
   hour   = hour + 12;                  % Julian days start at noon

   % The following algorithm is from the Calendar FAQ.

   b = 0;
   c = ijday + 32082;

   d = fix((4*c + 3)/1461);
   e = c - fix((1461*d)/4);
   m = fix((5*e + 2)/153);

   day   = e - fix((153*m + 2)/5) + 1;
   month = m + 3 - 12*fix(m/10);
   year  = b*100 + d - 4800 + fix(m/10);
