function [earth_E_matrix, aircraft_E_matrix, mill_E_matrix, resampled_pos_orientation_matrix, resampled_pos_location_matrix, resampled_pos_data_matrix, time, N] = load_a_day(calibration_matrix, conversion_matrix, efm_directory, pps, pos_directory, start_string, seconds);
%	function [earth_E_matrix, aircraft_E_matrix, mill_E_matrix, pos_orientation_matrix, pos_location_matrix, 
%		pos_data_matrix, time, N] 
%		= load_a_day(calibration_matrix, conversion_matrix, efm_directory, pps, pos_directory, start_string, seconds);
%
%	This routine automates the loading of efm and pos data from a single day's worth of data.  Based on the
%	name of the EFM files found in the directory, both the EFM and POS data are loaded into the Matlab
%	environment.
%
%	Inputs:
%		calibration_matrix = the (2,12) matrix of V to E values for the two gains at each mill
%		conversion_matrix = the (4,6) matrix to convert a mill set of E to an aircraft set of E
%		efm_directory = char of base directory to find files (default: current directory)
%		pps = how many points per second in the output (default: all 50)
%		pos_directory = char of base directory to find files (default: current directory)
%		start_string = string of start time, format: 'dd-mmm-yyyy hh:mm:ss' (default: start of data)
%		seconds = # of seconds for data (default: all data)
%
%	Outputs:
%		earth_E_matrix = the (6,N) matrix of the earth oriented electric fields
%			index		variable
%			  1		  En
%			  2		  Ew
%			  3		  Eu
%			  4		  Eq
%			  5		  Emag
%			  5		  Qfactor
%		aircraft_E_matrix = the (6,N) matrix of the aircraft oriented (Ex, Ey, Ez, Q, Emag, Qfactor) electric fields
%			index		variable
%			  1		  Ex
%			  2		  Ey
%			  3		  Ez
%			  4		  Eq
%			  5		  Emag
%			  5		  Qfactor
%		mill_E_matrix = the (2,6,N) matrix of mill electric field values
%		pos_orientation_matrix = the (3,N) matrix of pos orientation data
%			index		variable
%			  1		  roll
%			  2		  pitch
%			  3		  heading
%		pos_location_matrix = the 5xN (depending on the skip & seconds values) matrix of pos location data
%			index		variable
%			  1		  latitude
%			  2		  longitude
%			  3		  altitude
%			  4		  track
%			  5		  ground speed
%		pos_data_matrix = the 6xN (depending on the skip & seconds values) matrix of pos data
%			index		variable
%			  1		  X_acc
%			  2		  Y_acc
%			  3		  Z_acc
%			  4		  Ice_LWC
%			  5		  FSSP_LWC
%			  6		  2D_conc
%		time = time array for the points (in dateform format)
%		N = # of points in the array of pos & time

%
%	Step one, find the EFM files
%
[file_list,file_count, directory] = load_file_names(efm_directory);
%
%	Step 2, load the EFM data
%
if ~exist('seconds','var')
	if ~exist('start_string','var')
      [efm_data_matrix, time, mill_array, N] = load_efm_data(file_count, file_list, directory, pps);
   else
      [efm_data_matrix, time, mill_array, N] = load_efm_data(file_count, file_list, directory, pps,start_string);
   end
else
   [efm_data_matrix, time, mill_array, N] = load_efm_data(file_count, file_list, directory, pps, start_string, seconds);
end
%
%	Calibrate it
%
[cal_mill_E_matrix] = convert_V_2_E(efm_data_matrix, calibration_matrix);
%
%	Delete those pesky cal pulses
%
[mill_E_matrix] = remove_calibration_pulse(cal_mill_E_matrix,time);
%
%	Extract the date so that we may load the POS data
%
file_time = sscanf(file_list(1,:),'EFM_LZ_V%f_%d-%d-%dT%d-%d-%d');
pos_file_base = datenum(sprintf('%2d-%2d-%2d',file_time(3),file_time(4),file_time(2)));
pos_file_name = strcat(datestr(pos_file_base,7), datestr(pos_file_base,3),datestr(pos_file_base,10),'.A.asc')
%
%	Now load the POS data
%
if ~exist('seconds','var')
	if ~exist('start_string','var')
      [pos_orientation_matrix, pos_location_matrix, pos_data_matrix, pos_time, N_POS] = load_pos_data(pos_file_name, pos_directory);
   else
      [pos_orientation_matrix, pos_location_matrix, pos_data_matrix, pos_time, N_POS] = load_pos_data(pos_file_name, pos_directory, start_string);
   end
else
   [pos_orientation_matrix, pos_location_matrix, pos_data_matrix, pos_time, N_POS] = load_pos_data(pos_file_name, pos_directory, start_string, seconds);
end
%
%	Now reformat the POS data to fit the EFM data
%
[resampled_pos_orientation_matrix, resampled_pos_location_matrix, resampled_pos_data_matrix] = resample_pos_data(pos_orientation_matrix, pos_location_matrix, pos_data_matrix, pos_time, time);
%
%	Now make the earth and aircraft electric field values
%
[earth_E_matrix,aircraft_E_matrix] = convert_mill_2_earth_E(mill_E_matrix,conversion_matrix,resampled_pos_orientation_matrix);
%
%	That should be all
%
