function [efm_data_matrix, efm_status_matrix, time_array, mill_array, N, summary_data, summary_count, Nav_data, CP_data] = load_er2_data(file_name, base_directory, pps, cut_off, order);
%  [efm_data_matrix, time_array, mill_array, N, summary_data, summary_count, Nav_data, CP_data] = 
%  load_er2_data(file_name, base_directory, pps, cut_off, order);
%
%  This routine loads a single file worth of efm data into two arrays, one for the data
%  and one for time.  It will use "resample" to take the data from 50 samples per second to the
%  value set in pps.  Note that "resample" is set to NOT filter the data.
%  It will also load the navigation data and the CP data.
%
%  Inputs:
%     file_name = array of input file name
%     directory = char of base directory to find files (default: current directory)
%     pps = how many points per second in the output (default: all 50)
%     cut_off = cut off frequency for filtering (default: no filtering)
%     order = filter order (default: 2)
%  Outputs:
%     efm_data_matrix = the 2 x 8 x N (depending on the skip & seconds values) array of efm data
%     time = time array for the points (in dateform format)
%     mill_array = array of mill ID's
%     N = # of points in the array of efm & time
%     summary_data = struct of summary data (once per block/second of data, optional)
%        .mill_ID = [6] array of mill ID#'s
%        .mill_time = [6] array of actual sec of mill data
%        .mill_state = [6] array of mill cal status
%        .mill_freq = [6] array of mill modulator frequecies
%        .timeGPS = nominal GPS time of data block
%        .timePC = nominal PC time of data block
%        .file_time = nominal file name derived time of data block
%        .subseconds = subsecond value from data request
%     summary_count = # of summary_data points
%     nav_data = struct of nav data
%        .latitude
%        .longitude
%        .roll
%        .pitch
%        .heading
%     CP_data = array of CP data
%
%  There are a max of 50 points per second
%

%%% Global variables
global Current_File;
global Mill_Count;
global Gain_Count;
global StartTime;
global EndTime;
global PCtime;
global IRIGtime;
global Mill;
global Milltime;
global MillIdx;
global MillSpeed;
global MillSpeedIdx;
global FF;
global CP;
global CPIdx;
global header;
global MillSN;
global HDR_version;
global thresh;
global plot_insens;
global NavLeftover;
global Navidx;
global Navtime;
global GPSAlt;
global BarAlt;
global Pitch;
global Roll;
global Hdg;
global INSLat;
global INSLon;
global GPSLat;
global GPSLon;
global GPSStat;
global Time;
global MillStatus;

Mill_Count = 8;
Gain_Count = 2;
MillIdx = 1;
CPIdx = 1;
Navidx = 1;
HDR_version = 1;
T0 = clock;
%
%  first, make the file name and open it
%
Current_File = strcat(base_directory,'\',file_name)
fid = fopen(Current_File,'r');
if fid == -1
   error('Unable to open file');
end
disp('Allocating arrays...')
Mill = NaN * ones(Gain_Count, Mill_Count, 90000);
Time = NaN * ones(1, 90000);
MillStatus = NaN * ones(Mill_Count, 90000);
MillSpeed = NaN * ones(8, 1800);
CP = NaN * ones(3, 18000);
GPSAlt = NaN * ones(1, 1800);
BarAlt = NaN * ones(1, 1800);
Pitch = NaN * ones(1, 1800);
Roll = NaN * ones(1, 1800);
Hdg = NaN * ones(1, 1800);
INSLat = NaN * ones(1, 1800);
INSLon = NaN * ones(1, 1800);
GPSLat = NaN * ones(1, 1800);
GPSLon = NaN * ones(1, 1800);
GPSStat = NaN * ones(1, 1800);
Navtime = NaN * ones(1, 1800);
%
%  read the first block header, error if not there
%
buf = fread(fid,32);
if length(buf) == 0
   error('Unable to read open file');
end
summary_count = 1;
%
%  Main read loop
%
while length(buf) == 32
   decode_time(buf);
   %
   %  Now get mill data
   %
   [s_data, the_size] = sget_mill_data(fid);
   if the_size == 214
      summary_data(summary_count).millhdr = s_data.millhdr;
      summary_data(summary_count).header = s_data.header;
      summary_data(summary_count).id = s_data.id;
      summary_data(summary_count).CRC = s_data.CRC;
      summary_data(summary_count).speed = s_data.speed;
      summary_data(summary_count).PCtime = PCtime;
      summary_data(summary_count).IRIGtime = IRIGtime;
      summary_data(summary_count).FM_count = MillIdx;
      summary_data(summary_count).mill_time = Milltime;
   else
      summary_data(summary_count).millhdr = zeros(8,10);
      summary_data(summary_count).header = zeros(8,12);
      summary_data(summary_count).id = [0 0 0 0 0 0 0 0];
      summary_data(summary_count).CRC = [0 0 0 0 0 0 0 0];
      summary_data(summary_count).speed = [0 0 0 0 0 0 0 0];
      summary_data(summary_count).PCtime = PCtime;
      summary_data(summary_count).IRIGtime = IRIGtime;
      summary_data(summary_count).FM_count = MillIdx;
      summary_data(summary_count).mill_time = [0 0 0 0 0 0 0 0];
   end
   %
   %  Get CP data
   %
   sget_CP_data(fid);
   summary_data(summary_count).CP_count = CPIdx;
   %
   %  get NAV data
   %
   sget_Nav_data(fid);
   if Navidx > 1
      summary_data(summary_count).Nav_time = Navtime(Navidx-1);
   else
      summary_data(summary_count).Nav_time = 0;
   end
   summary_data(summary_count).Nav_count = Navidx;
   %
   %  get next block of data
   %
   buf = fread(fid,32);
   summary_count = summary_count + 1;
end
%
%  Now resize and reformat Monte ER-2 data into Doug format
%
mill_array = MillSN;
%
%  Now resample data
%
disp('Resampling Mill Data');
d = gcd(pps,50);
p = pps/d;
q = 50/d;
N = ceil((MillIdx-1)*p/q);
if pps ~= 50
   efm_data_matrix(2,6,N) = 0;
   efm_status_matrix(6,N) = 0;
   for mill_index=1:Mill_Count
      for gain_index=1:Gain_Count
         dummy_array = resample(squeeze(Mill(gain_index,mill_index,1:MillIdx-1)),p,q,0);
         efm_data_matrix(gain_index,mill_index,:) = dummy_array;
      end
      dummy_array = resample(MillStatus(mill_index,1:MillIdx-1),p,q,0);
      efm_status_matrix(mill_index,:) = dummy_array;
   end
   dummy_array = resample(Time(1:MillIdx-1),p,q,0);
   time_array = dummy_array;
else
   efm_data_matrix = Mill(:,:,1:MillIdx-1);
   time_array = Time(1:MillIdx-1);
   efm_status_matrix = MillStatus(:,1:MillIdx-1);
end
disp('Resampling CP Data');
d = gcd(pps,10);
p = pps/d;
q = 10/d;
CP_N = ceil((CPIdx-1)*p/q);
if pps ~= 10
   CP_data(3,CP_N) = 0;
   for gain_index=1:3
      dummy_array = resample(squeeze(CP(gain_index,1:CPIdx-1)),p,q,0);
      CP_data(gain_index,:) = dummy_array;
   end
else
   CP_data = CP(:,1:CPIdx-1);
end
disp('Resampling Nav Data');
%
%  First check for NaN's in the data (interp1 won't work on NaN's)
%
if any(isnan(Navtime(1:Navidx-1))) == 1
   %
   %  We have NaN's
   %
   bad_index_list = find(isnan(Navtime(1:Navidx-1)) == 1)
   Navtime(bad_index_list) = [];
   GPSAlt(bad_index_list) = [];
   BarAlt(bad_index_list) = [];
   Hdg(bad_index_list) = [];
   Pitch(bad_index_list) = [];
   Roll(bad_index_list) = [];
   INSLat(bad_index_list) = [];
   INSLon(bad_index_list) = [];
   GPSLat(bad_index_list) = [];
   GPSLon(bad_index_list) = [];
   Navidx = Navidx - length(bad_index_list)
end
%Nav_data(1,:) = interp1(Navtime(1:Navidx-1),GPSAlt(1:Navidx-1),time_array);
%Nav_data(2,:) = interp1(Navtime(1:Navidx-1),BarAlt(1:Navidx-1),time_array);
%Nav_data(3,:) = interp1(Navtime(1:Navidx-1),Hdg(1:Navidx-1),time_array);
%Nav_data(4,:) = interp1(Navtime(1:Navidx-1),Pitch(1:Navidx-1),time_array);
%Nav_data(5,:) = interp1(Navtime(1:Navidx-1),Roll(1:Navidx-1),time_array);
%Nav_data(7,:) = interp1(Navtime(1:Navidx-1),INSLat(1:Navidx-1),time_array);
%Nav_data(8,:) = interp1(Navtime(1:Navidx-1),INSLon(1:Navidx-1),time_array);
%Nav_data(9,:) = interp1(Navtime(1:Navidx-1),GPSLat(1:Navidx-1),time_array);
%Nav_data(10,:) = interp1(Navtime(1:Navidx-1),GPSLon(1:Navidx-1),time_array);
%Nav_data(6,:) = interp1(Navtime(1:Navidx-1),Navtime(1:Navidx-1),time_array);
%
%Nav_data(1,:) = GPSAlt(1:Navidx-1);
%Nav_data(2,:) = BarAlt(1:Navidx-1);
%Nav_data(3,:) = Hdg(1:Navidx-1);
%Nav_data(4,:) = Pitch(1:Navidx-1);
%Nav_data(5,:) = Roll(1:Navidx-1);
%Nav_data(7,:) = INSLat(1:Navidx-1);
%Nav_data(8,:) = INSLon(1:Navidx-1);
%Nav_data(9,:) = GPSLat(1:Navidx-1);
%Nav_data(10,:) = GPSLon(1:Navidx-1);
%Nav_data(6,:) = Navtime(1:Navidx-1);
%
Nav_data(1).GPSAlt = NaN;
Nav_data(1).BarAlt = NaN;
Nav_data(1).Hdg = NaN;
Nav_data(1).Pitch = NaN;
Nav_data(1).Roll = NaN;
Nav_data(1).INSLat = NaN;
Nav_data(1).INSLon = NaN;
Nav_data(1).GPSLat = NaN;
Nav_data(1).GPSLon = NaN;
Nav_data(1).Navtime = NaN;
for stupid_index=1:Navidx-1
   Nav_data(stupid_index).GPSAlt = GPSAlt(stupid_index);
   Nav_data(stupid_index).BarAlt = BarAlt(stupid_index);
   Nav_data(stupid_index).Hdg = Hdg(stupid_index);
   Nav_data(stupid_index).Pitch = Pitch(stupid_index);
   Nav_data(stupid_index).Roll = Roll(stupid_index);
   Nav_data(stupid_index).INSLat = INSLat(stupid_index);
   Nav_data(stupid_index).INSLon = INSLon(stupid_index);
   Nav_data(stupid_index).GPSLat = GPSLat(stupid_index);
   Nav_data(stupid_index).GPSLon = GPSLon(stupid_index);
   Nav_data(stupid_index).Navtime = Navtime(stupid_index);
end
