function [gbfm_matrix,time,mill_array,N,summary_data,summary_count] = load_gbfm_data(file_count, file_list, base_directory, pps, start_string, seconds);
%        [ gbfm_matrix, time, mill_array, N, summary_data, summary_count] = 
%        load_gbfm_data(file_count, file_list, base_directory, pps, start_string, seconds);
%
%
%	This routine loads a boatload of gbfm data into two arrays, one for the data
%	and one for time.  It will use "resample" to take the data from 50 samples per second to the
%	value set in pps.  Note that "resample" is set to NOT filter the data.
%
%	Inputs:
%		file_count = # input files
%		file_list(file_count,?) = char string array of input files
%		directory = char of base directory to find files (default: current directory)
%		pps = how many points per second in the output (default: all 50)
%		start_string = string of start time, format: 'dd-mmm-yyyy hh:mm:ss' (default: start of data)
%		seconds = # of seconds for data (default: all data)
%	Outputs:
%		gbfm_matrix = the 64 x N (depending on the skip & seconds values) array of gbfm data
%		time = time array for the points (in dateform format)
%		mill_array = array of mill ID's
%		N = # of points in the array of efm & time
%		summary_data = struct of summary data (optional)
%			status = status array 7 x 64 
%			rain = rain value array 64
%			crc = crc value 64
%		summary_count = # of the summary data structures (optional)
%
%		There are a max of 50 points per second
%


%
%	Set any defaults
%
mill_count = 40;
T0 = clock;
format compact;
'Setting defaults'
default_size = 91000;
if ~exist('seconds','var')
   seconds = 0;
end
if ~exist('pps','var')
   pps = 50;
end
if ~exist('cut_off','var')
   cut_off = 0;
end
if ~exist('order','var')
   order = 2;
end
if exist('start_string','var')
   first_time = datenum(start_string);
else
   first_time = 0;
end
%
%	Init the data
%
'Init data'
summary_count = 0;
Ntot = seconds*50;
time_base = 'XXX';
if Ntot ~= 0
   gbfm_raw(Ntot,mill_count) = 0;
   raw_time(Ntot) = 0;
   default_size = Ntot;
else
   gbfm_raw(default_size,mill_count) = 0;
   raw_time(default_size) = 0;
end
summary_default = ceil(default_size*2e-2);
summary_data1(summary_default).status(mill_count,7) = int8(0);
summary_data1(summary_default).rain(mill_count) = int8(0);
summary_data1(summary_default).crc(mill_count) = int16(0);
[gbfm_status_block,gbfm_data] = init_gbfm_block;
%
%  Start work on files
%
next_point = 1;
next_summary = 1;
for file_index=1:file_count
   base_directory
   file_list
   file_index
   if file_count > 1
      fid1 = fopen(strcat(base_directory,'\',file_list(file_index,:)),'r','l');
   else
      fid1 = fopen(strcat(base_directory,'\',file_list),'r','l');
   end
   strcat(base_directory,'\',file_list)
   %
   %  Now read all blocks of data
   %
   [gbfm_status_block,gbfm_data] = read_gbfm_block(fid1,gbfm_status_block,gbfm_data);
   while gbfm_status_block.sync(1) ~= -1
      %
      %  Determine the base time in matlab units
      %
      if gbfm_status_block.UTC.year > 50
         base_time = datenum(double(gbfm_status_block.UTC.year)+1900,double(gbfm_status_block.UTC.month),double(gbfm_status_block.UTC.day),double(gbfm_status_block.UTC.hour),double(gbfm_status_block.UTC.min),double(gbfm_status_block.UTC.sec));
      else
         base_time = datenum(double(gbfm_status_block.UTC.year)+2000,double(gbfm_status_block.UTC.month),double(gbfm_status_block.UTC.day),double(gbfm_status_block.UTC.hour),double(gbfm_status_block.UTC.min),double(gbfm_status_block.UTC.sec));
      end
      datestr(base_time)
      if base_time < first_time
         [gbfm_status_block,gbfm_data] = read_gbfm_block(fid1,gbfm_status_block, gbfm_data);
         datestr(base_time)
         datestr(first_time)
         continue;
      end
      if next_point+50 > default_size
         'Increasing default size'
         default_size = default_size*2
         gbfm_raw(default_size,mill_count) = 0;
         raw_time(default_size) = 0;
      end
      if next_summary + 1 > summary_default
         'Increase summary default size'
         summary_default = summary_default*2;
         summary_data1(summary_default).status(mill_count,7) = int8(0);
         summary_data1(summary_default).rain(mill_count) = int8(0);
         summary_data1(summary_default).crc(mill_count) = int16(0);
      end
      for mill_index=1:mill_count
         %
         %  Read Summary Data
         %
         summary_data1(next_summary).rain(mill_index) = gbfm_status_block.mill(mill_index).rain;
         summary_data1(next_summary).crc(mill_index) = gbfm_status_block.mill(mill_index).crc;
         summary_data1(next_summary).status(mill_index,:) = gbfm_status_block.mill(mill_index).status;
         mill_array(mill_index) = gbfm_status_block.mill(mill_index).address;
      end
      next_summary = next_summary + 1;
      for block_index=1:50
         raw_index = next_point - 1 + block_index;
         for mill_index=1:mill_count
            gbfm_raw(raw_index,mill_index) = gbfm_data(block_index,mill_index);
         end
         raw_time(raw_index) = base_time + (block_index-1)*2.314814e-7;
      end
      next_point = raw_index+1;
      %
      %  Read next block
      %
      [gbfm_status_block,gbfm_data] = read_gbfm_block(fid1,gbfm_status_block, gbfm_data);
   end
   %
   %  Close file
   %
   fclose(fid1);
end
%
%  Now set output the summary data
%
summary_count = next_summary - 1;
for index=1:summary_count
   summary_data(index).status = summary_data1(index).status;
   summary_data(index).rain = summary_data1(index).rain;
   summary_data(index).crc = summary_data1(index).crc;
end
%
%  Now rescale the mill data
%
size(gbfm_raw)
pps
gbfm_matrix = resample(gbfm_raw(1:next_point-1,:),pps,50,0);
time = resample(raw_time(1:next_point-1),pps,50,0);
N = length(gbfm_matrix)
%
%  That should be all
%
return;
