function [pos_orientation_matrix, pos_location_matrix, pos_data_matrix, time_array, N] = load_pos_data(file_name, base_directory, start_string, seconds);
%        [pos_orientation_matrix, pos_location_matrix, pos_data_matrix, time_array, N] = 
%				load_pos_data(file_name, directory, start_string, seconds)
%
%	This routine loads a boatload of pos data into three arrays, one for the orientation data,
%	one for the position data, and one for time
%
%	Inputs:
%		file_name = char string input file
%		directory = char of base directory to find files (default: current directory)
%		start_string = string of start time, format: 'dd-mmm-yyyy hh:mm:ss' (default: start of data in file)
%		seconds = # of seconds of data wanted from the file (default: all data in file)
%	Outputs:
%		pos_orientation_matrix = the 3xN (depending on the skip & seconds values) matrix of pos orientation data
%			index		variable
%			  1		  roll
%			  2		  pitch
%			  3		  heading
%		pos_location_matrix = the 5xN (depending on the skip & seconds values) matrix of pos location data
%			index		variable
%			  1		  latitude
%			  2		  longitude
%			  3		  altitude
%			  4		  track
%			  5		  ground speed
%		pos_data_matrix = the 6xN (depending on the skip & seconds values) matrix of pos data
%			index		variable
%			  1		  X_acc
%			  2		  Y_acc
%			  3		  Z_acc
%			  4		  Ice_LWC
%			  5		  FSSP_LWC
%			  6		  2D_conc
%		time = time array for the points (in dateform format)
%		N = # of points in the array of pos & time
%

%
%	Set to default any values not entered
%
if ~exist('start_string','var')
   first_time = 0;
else
   first_time = datenum(start_string);
end
if ~exist('seconds','var')
   seconds = 0;
end
%
%	Open file
%
strcat(base_directory,'\',file_name)
fid1 = fopen(strcat(base_directory,'\',file_name),'r');
if fid1 == -1
   error('Error in file open');
else
   %
   %	Dump the first two lines (header data)
   %
   dummy_string = fgets(fid1);
   dummy_string = fgets(fid1);
end
%
%	Determine the base date/time
%
base_date = sscanf(file_name,'%2d%3s%4d');
day = base_date(1)
month = char(base_date(2:4))
year = base_date(5)
%
%	Now convert to the matlab format
%
base_date_string = sprintf('%2d-%3s-%4d',day, month, year)
base_time = datenum(base_date_string);
%
%	Read the rest of the file
%
block_data = fscanf(fid1,'%f',[16,inf]);
%
%	Convert time to Matlab format
%
S = size(block_data);
Nfull = S(2);
%
%	Note that the SECOND time variable is the GPS which is what our data is
%	based on.  If this is WRONG, then the times will be WRONG
%
GPS_time = (block_data(2,:)*1.157407e-5) + base_time;
%
%	Find first index
%
start_index = 1;
while GPS_time(start_index) < first_time
   start_index = start_index + 1;
   if start_index > Nfull
      error('Dropped off end of data before reaching start time');
   end
end
first_time = GPS_time(start_index);
%
%	Find last index
%
if seconds == 0
   end_index = Nfull;
else
   end_time = first_time + seconds*1.157407e-5;
   end_index = start_index+1;
   while end_time > GPS_time(end_index)
      end_index = end_index+1;
	   if end_index > Nfull
   	   warning('Requested more data than what is in the file');
         end_index = Nfull;
         break;
      end
   end
end
delta_index = end_index - start_index + 1;
end_time = GPS_time(end_index);
%
%	Pre-size the output variables
%
N = delta_index;
pos_orientation_matrix(3,N) = 0;
pos_location_matrix(5,N) = 0;
pos_data_matrix(6,N) = 0;
time_array(N) = 0;
%
%	Now do the transfer
%
index = start_index;
out_index = index - start_index + 1;
bad_times = 0;
day_offset = 0.0;
%
%  Read first block
%
time_array(out_index) = block_data(2,index) + day_offset;
pos_orientation_matrix(1,out_index) = block_data(7,index);
pos_orientation_matrix(2,out_index) = block_data(8,index);
pos_orientation_matrix(3,out_index) = block_data(9,index);
pos_location_matrix(1,out_index) = block_data(3,index);
pos_location_matrix(2,out_index) = block_data(4,index);
pos_location_matrix(3,out_index) = block_data(10,index);
pos_location_matrix(4,out_index) = block_data(6,index);
pos_location_matrix(5,out_index) = block_data(5,index);
pos_data_matrix(1,out_index) = block_data(11,index);
pos_data_matrix(2,out_index) = block_data(12,index);
pos_data_matrix(3,out_index) = block_data(13,index);
pos_data_matrix(4,out_index) = block_data(14,index);
pos_data_matrix(5,out_index) = block_data(15,index);
pos_data_matrix(6,out_index) = block_data(16,index);
out_index = out_index + 1;
index = index + 1;
while index<=end_index
   time_array(out_index) = block_data(2,index) + day_offset;
   %
   %	Only output data if the time is increasing
   %
   if time_array(out_index-1) > time_array(out_index)
      %
      %	The day has overlapped.
      %	Need to add 24 hours to the data
      %
      time_array(out_index-1)
      time_array(out_index)
      time_array(out_index) = time_array(out_index) + 86400;
      day_offset = day_offset + 86400;
      'Hit Day offset'
   end
   if time_array(out_index-1) < time_array(out_index)
      pos_orientation_matrix(1,out_index) = block_data(7,index);
      pos_orientation_matrix(2,out_index) = block_data(8,index);
      pos_orientation_matrix(3,out_index) = block_data(9,index);
      pos_location_matrix(1,out_index) = block_data(3,index);
      pos_location_matrix(2,out_index) = block_data(4,index);
      pos_location_matrix(3,out_index) = block_data(10,index);
      pos_location_matrix(4,out_index) = block_data(6,index);
      pos_location_matrix(5,out_index) = block_data(5,index);
      pos_data_matrix(1,out_index) = block_data(11,index);
      pos_data_matrix(2,out_index) = block_data(12,index);
      pos_data_matrix(3,out_index) = block_data(13,index);
      pos_data_matrix(4,out_index) = block_data(14,index);
      pos_data_matrix(5,out_index) = block_data(15,index);
      pos_data_matrix(6,out_index) = block_data(16,index);
      out_index = out_index + 1;
   end
   index = index + 1;
end
%
%	Now reformat time into datetick
%
time_array = time_array(1:out_index-1)*1.1574e-5;
time_array = time_array + base_time;
%
%  Reformat the data also
%
pos_orientation_matrix = pos_orientation_matrix(:,1:out_index-1);
pos_location_matrix = pos_location_matrix(:,1:out_index-1);
pos_data_matrix = pos_data_matrix(:,1:out_index-1);

