function [pos_structure, time_array, N] = load_pos_data_struct(file_name, base_directory, start_string, seconds);
%        [pos_structure, time_array, N] = load_pos_data_struct(file_name, directory, start_string, seconds);
%
%   This routine loads a boatload of pos data into a structure, and one for time
%
%   Inputs:
%      file_name = char string input file
%      directory = char of base directory to find files (default: current directory)
%      start_string = string of start time, format: 'dd-mmm-yyyy hh:mm:ss' (default: start of data in file)
%      seconds = # of seconds of data wanted from the file (default: all data in file)
%  Outputs:
%      pos_structure = the N (depending on the skip & seconds values) structure of pos data
%         variable
%         .roll
%         .pitch
%         .heading
%         .lat
%         .lon
%         .alt
%         .track
%         .gs (ground speed)
%         .X_acc
%         .Y_acc
%         .Z_acc
%         .Ice_LWC
%         .FSSP_LWC
%         .twoD_conc
%      time = time array for the points (in dateform format)
%      N = # of points in the array of pos & time
%

%
%   Set to default any values not entered
%
if ~exist('start_string','var')
   first_time = 0;
else
   first_time = datenum(start_string);
end
if ~exist('seconds','var')
   seconds = 0;
end
%
%   Open file
%
strcat(base_directory,'\',file_name)
fid1 = fopen(strcat(base_directory,'\',file_name),'r');
if fid1 == -1
   error('Error in file open');
else
   %
   %   Dump the first two lines (header data)
   %
   dummy_string = fgets(fid1);
   dummy_string = fgets(fid1);
end
%
%   Determine the base date/time
%
base_date = sscanf(file_name,'%2d%3s%4d');
day = base_date(1)
month = char(base_date(2:4))
year = base_date(5)
%
%   Now convert to the matlab format
%
base_date_string = sprintf('%2d-%3s-%4d',day, month, year)
base_time = datenum(base_date_string);
%
%   Read the rest of the file
%
block_data = fscanf(fid1,'%f',[16,inf]);
%
%   Convert time to Matlab format
%
S = size(block_data);
Nfull = S(2);
%
%   Note that the SECOND time variable is the GPS which is what our data is
%   based on.  If this is WRONG, then the times will be WRONG
%
GPS_time = (block_data(2,:)*1.157407e-5) + base_time;
%
%   Find first index
%
start_index = 1;
while GPS_time(start_index) < first_time
   start_index = start_index + 1;
   if start_index > Nfull
      error('Dropped off end of data before reaching start time');
   end
end
first_time = GPS_time(start_index);
%
%   Find last index
%
if seconds == 0
   end_index = Nfull;
else
   end_time = first_time + seconds*1.157407e-5;
   end_index = start_index+1;
   while end_time > GPS_time(end_index)
      end_index = end_index+1;
      if end_index > Nfull
         warning('Requested more data than what is in the file');
         end_index = Nfull;
         break;
      end
   end
end
delta_index = end_index - start_index + 1;
end_time = GPS_time(end_index);
%
%   Pre-size the output variables
%
N = delta_index;
pos_structure = repmat(struct('roll',0,'pitch',0,'heading',0,'lat',0,'lon',0,'alt',0,'track',0,'gs',0,'X_acc',0,'Y_acc',0,'Z_acc',0,'Ice_LWC',0,'FSSP_LWC',0,'twoD_conc',0),1,N);
pos_orientation_matrix(3,N) = 0;
pos_location_matrix(5,N) = 0;
pos_data_matrix(6,N) = 0;
time_array(N) = 0;
%
%   Now do the transfer
%
index = start_index;
out_index = index - start_index + 1;
bad_times = 0;
day_offset = 0.0;
%
%  Read first block
%
time_array(out_index) = block_data(2,index) + day_offset;
pos_structure(out_index).roll = block_data(7,index);
pos_structure(out_index).pitch = block_data(8,index);
pos_structure(out_index).heading = block_data(9,index);
pos_structure(out_index).lat = block_data(3,index);
pos_structure(out_index).lon = block_data(4,index);
pos_structure(out_index).alt = block_data(10,index);
pos_structure(out_index).track = block_data(6,index);
pos_structure(out_index).gs = block_data(5,index);
pos_structure(out_index).X_acc = block_data(11,index);
pos_structure(out_index).Y_acc = block_data(12,index);
pos_structure(out_index).Z_acc = block_data(13,index);
pos_structure(out_index).Ice_LWC = block_data(14,index);
pos_structure(out_index).FSSP_LWC = block_data(15,index);
pos_structure(out_index).twoD_conc = block_data(16,index);
out_index = out_index + 1;
index = index + 1;
while index<=end_index
   time_array(out_index) = block_data(2,index) + day_offset;
   %
   %   Only output data if the time is increasing
   %
   if time_array(out_index-1) > time_array(out_index)
      %
      %   The day has overlapped.
      %   Need to add 24 hours to the data
      %
      time_array(out_index-1)
      time_array(out_index)
      time_array(out_index) = time_array(out_index) + 86400;
      day_offset = day_offset + 86400;
      'Hit Day offset'
   end
   if time_array(out_index-1) < time_array(out_index)
      pos_structure(out_index).roll = block_data(7,index);
      pos_structure(out_index).pitch = block_data(8,index);
      pos_structure(out_index).heading = block_data(9,index);
      pos_structure(out_index).lat = block_data(3,index);
      pos_structure(out_index).lon = block_data(4,index);
      pos_structure(out_index).alt = block_data(10,index);
      pos_structure(out_index).track = block_data(6,index);
      pos_structure(out_index).gs = block_data(5,index);
      pos_structure(out_index).X_acc = block_data(11,index);
      pos_structure(out_index).Y_acc = block_data(12,index);
      pos_structure(out_index).Z_acc = block_data(13,index);
      pos_structure(out_index).Ice_LWC = block_data(14,index);
      pos_structure(out_index).FSSP_LWC = block_data(15,index);
      pos_structure(out_index).twoD_conc = block_data(16,index);
      out_index = out_index + 1;
   end
   index = index + 1;
end
%
%   Now reformat time into datetick
%
time_array = time_array(1:out_index-1)*1.1574e-5;
time_array = time_array + base_time;
%
%  Reformat the data also
%
pos_structure = pos_structure(1:out_index-1);


