function [plot_handles] = plot_any_data(output_file_type,mill_E_matrix,gain_matrix,aircraft_E_matrix, earth_E_matrix, pos_data_matrix, pos_location_matrix, pos_orientation_matrix, time, plot_components, start_string, delta_seconds, window_width, base_file_name,max_plots);
%	[plot_handles] = plot_any_data(output_file_type,mill_E_matrix,gain,aircraft_E_matrix, earth_E_matrix, 
%     pos_data_matrix, pos_location_matrix, pos_orientation_matrix, time, plot_components, 
%     orientation, start_string, delta_seconds, window_width, base_file_name,max_plots);
%
%	This routine plots the earth/aircraft fields (in V/m), and all the various POS data to the screen.
%
%	Input:
%     output_file_type = the character extention of the figure output file type
%        i.e., "png", "gif", etc.
%		mill_E_matrix = matrix of mill V/m data (2,6,N) (PD, PU, SD, SU, AD, AU)x(S,I)
%     gain_matrix = (6,N) matrix of gain used to determine mill E
%        to stop frequent gain changes near the limits, a hystereses was added so that
%        when data is between 0 and 95% of the low gain fullscale, gain 1 is used.  gain(i)
%        is then set to 1.  When data is above 95%, gain 2 is used.  gain(i) is then set to
%        2.  Gain 2 is used untill data is below 50% of the low gain fullscale. gain for this
%        case is set to 1.5.
%		aircraft_E_matrix = (6,N) matrix of electric field data (X,Y,Z,Q,M,F)
%		earth_E_matrix = (6,N) matrix of electric field data (N,W,U,Q,M,F)
%		pos_data_matrix = (6,N) matrix of pos data (Ax,Ay,Az,ICE,FSSP,2D)
%		pos_location_matrix = (5,N) matrix of pos location data (La,Lo,A,T,S)
%		pos_orientation_matrix = the (3,N) matrix of pos orientation data (R,P,H)
%		time = the time array (in datetick format) (N)
%		plot_components = 6x6 character matrix of which components to plot as a series of characters
%			for the first row, field mill sensitive outputs (V/m) 
%			for the second row, field mill insensitive outputs (V/m) 
%			for the third row, aircraft_E_matrix, aircraft (Ex, Ey, Ez) oriented fields
%			for the fourth row, earth_E_matrix, earth (Ew, En, Eu) oriented fields
%			the fith row indicate you want the pos_data_matrix plotted
%			the sixth row mean you want POS location data plotted including the XYZ plot for the 6th slot
%			the sixth row mean you want POS orientation data plotted
%			If you use upper case letters, a grid will be printed
%		start_string = time (in datestr format or index #) where the data is to start (default or 0: start of data)
%		delta_seconds = how much of the data to plot (default or 0: all data)
%				Note: if start_string is a char string, delta_seconds units are seconds,
%				if start_string is an index, then delta_seconds is in index #'s
%		window_width = how many seconds per plot window (default or 0: 30 minutes)
%				Note: if start_string is a char string, window_width units are seconds,
%				if start_string is an index, then window_width is in index #'s
%     base_file_name = character string of the output file name base (i.e., 'jun04')
%     max_plots = max plots before the program clears all the plots already sent to disk (to
%           keep system from crashing)
%
%	Output:
%		plot_handles = the handles to all of the plots
%

%
%	Fixing any information that was left out
%
if ~exist('plot_components','var')
   plot_components(1,:) = 'EEEEEE';
   plot_components(2,:) = 'EEEEEE';
   plot_components(3,:) = 'GGGGGG';
   plot_components(4,:) = 'XXXXXX';
   plot_components(5,:) = 'NNNNNN';
   plot_components(6,:) = 'OOO   ';
   plot_components(7,:) = 'LLLLLL';
   plot_components(8,:) = 'DDDDDD';
else
   pc_size = size(plot_components);
   if (pc_size(1) < 8) | (pc_size(2) < 6)
      %
      %  Fill in the blanks
      %
      for i=pc_size(1)+1:8
         for j=pc_size(2)+1:6
            plot_components(i,j) = ' ';
         end
      end
      for i=1:pc_size(1)
         for j=pc_size(2)+1:6
            plot_components(i,j) = ' ';
         end
      end
      for i=pc_size(1)+1:8
         for j=1:pc_size(2)
            plot_components(i,j) = ' ';
         end
      end
   end
end
%
%  Determine which data will be plotted
%
plot_count(8) = 0;
for index1=1:8
   for index2=1:6
      if plot_components(index1,index2) ~= ' '
         plot_count(index1) = plot_count(index1) + 1;
      end
   end
end
if ~exist('base_file_name','var')
   base_file_name = 'figure';
end
if ~exist('start_string','var')
   first_time = time(1);
else
   if ischar(start_string) == 0
      if first_time < 1
         first_time = 1;
      end
      first_time = time(start_string);
   else
      first_time = datenum(start_string);
   end
end
if ~exist('delta_seconds','var')
   last_time = time(length(time));
else
   if delta_seconds == 0
      last_time = time(length(time));
   else
      if ischar(start_string) == 0
         last_time = time(delta_seconds+start_string);
      else
         last_time = first_time + delta_seconds*1.1574e-5;
      end
   end
end
if ~exist('max_plots','var')
   max_plots = 0;
end
if ~exist('window_width','var')
   window_width = 30*60;
else
   if window_width == 0
      window_width = 30*60;
   end
end
max_index = length(time);
%
%	Determine where to start the plots
%
i=1;
while time(i) < first_time
   i = i + 1;
   if i > max_index
      error('Ran off end of time array before hitting start time');
   end
end
first_index = i
window_start_index = first_index;
window_start_time = first_time;
i = first_index;
while time(i) < last_time
   i = i + 1;
   if i > max_index
      i = max_index;
      break;
   end
end
last_index = i
window_index = 1;
while window_start_time < last_time
   window_end_time = window_start_time + window_width*1.1574e-5;
   %
   %  Make sure we don't print any small pages
   %
   if window_end_time > last_time
      window_end_time = last_time;
      window_width = (window_end_time - window_start_time)*86400;
   else
      leftover_fraction = ((last_time - window_end_time)*86400)/window_width;
      if leftover_fraction < 0.1
         window_end_time = last_time;
         window_width = (window_end_time - window_start_time)*86400;
      end
   end
   %
   %  Determine the designator (time) for the plots
   %
   dater = datestr(window_start_time,15);
   the_date = sscanf(dater,'%d:%d');
   %
   %  Plot the mill data
   %
   if plot_count(1) + plot_count(2) > 0
      the_mill_plots = plot_efm_data(mill_E_matrix, time, 0.99, [plot_components(1,1:6),plot_components(2,1:6)], datestr(window_start_time), window_width, window_width);
      %
      %  Now format the plots
      %
      if ~isempty(the_mill_plots)
         for i=1:length(the_mill_plots)
            orient(the_mill_plots(i), 'tall');
         end
         if ~isempty(output_file_type)
            %
            %  If we put in a file base name, save the plots in the format asked for
            %
            if plot_count(1) > 0
               divider = sprintf('S%02d%02d',the_date(1), the_date(2));
               file_name = strcat(base_file_name,divider,'.',output_file_type);
               saveas(the_mill_plots(1),file_name);
            end
            if plot_count(2) > 0
               divider = sprintf('I%02d%02d',the_date(1), the_date(2));
               file_name = strcat(base_file_name,divider,'.',output_file_type);
               saveas(the_mill_plots(length(the_mill_plots)),file_name);
            end
         end
         %
         %  Delete any plots we have already printed if asked to do so
         %  This is so that Windows does not crash due to lack of resources
         %
         if (max(the_mill_plots) > max_plots) & (max_plots > 0)
            'Awaiting permission to delete figures'
            pause
            for i=1:max(the_mill_plots)
               delete(i);
            end
         end
      end
   end
   %
   %  Plot gain data
   %
   if plot_count(3) > 0
      the_gain_plot = plot_gain_data(gain_matrix, time, plot_components(3,1:6), datestr(window_start_time), window_width, window_width);
      %
      %  Now format the plot
      %
      if ~isempty(the_gain_plot)
         orient(the_gain_plot, 'portrait');
         if ~isempty(output_file_type)
            divider = sprintf('G%02d%02d',the_date(1), the_date(2));
            file_name = strcat(base_file_name,divider,'.',output_file_type);
            saveas(the_gain_plot,file_name);
         end
         %
         %  Delete any plots we have already printed if asked to do so
         %  This is so that Windows does not crash due to lack of resources
         %
         if (the_gain_plot > max_plots) & (max_plots > 0)
            'Awaiting permission to delete figures'
            pause
            for i=1:the_gain_plot
               delete(i);
            end
         end
      end
   end
   %
   %  Plot aircraft oriented field data
   %
   if plot_count(4) > 0
      the_air_plot = plot_field_data(aircraft_E_matrix, time, 0.99, plot_components(4,1:6), datestr(window_start_time), window_width, window_width);
      %
      %  Now format the plot
      %
      if ~isempty(the_air_plot)
         orient(the_air_plot, 'tall');
         if ~isempty(output_file_type)
            divider = sprintf('A%02d%02d',the_date(1), the_date(2));
            file_name = strcat(base_file_name,divider,'.',output_file_type);
            saveas(the_air_plot,file_name);
         end
         if (the_air_plot > max_plots) & (max_plots > 0)
            'Awaiting permission to delete figures'
            pause
            for i=1:the_air_plot
               delete(i);
            end
         end
      end
   end
   %
   %  Plot earth oriented field data
   %
   if plot_count(5) > 0
      the_earth_plot = plot_field_data(earth_E_matrix, time, 0.99, plot_components(5,1:6), datestr(window_start_time), window_width, window_width);
      %
      %  Now format the plot
      %
      if ~isempty(the_earth_plot)
         orient(the_earth_plot, 'tall');
         if ~isempty(output_file_type)
            divider = sprintf('E%02d%02d',the_date(1), the_date(2));
            file_name = strcat(base_file_name,divider,'.',output_file_type);
            saveas(the_earth_plot,file_name);
         end
         if (the_earth_plot > max_plots) & (max_plots > 0)
            'Awaiting permission to delete figures'
            pause
            for i=1:the_earth_plot
               delete(i);
            end
         end
      end
   end
   %
   %  Plot POS data
   %
   if (plot_count(6)+plot_count(7)+plot_count(8)) > 0
      the_pos_plots = plot_pos_data(pos_orientation_matrix, pos_location_matrix, pos_data_matrix, time, [plot_components(6,1:3),plot_components(7,1:6),plot_components(8,1:6)], datestr(window_start_time), window_width, window_width);
      %
      %  Now format the plots
      %
      if ~isempty(the_pos_plots)
         pre_plot = 1;
         if ~isempty(output_file_type)
            if plot_count(6) > 0
               divider = sprintf('O%02d%02d',the_date(1), the_date(2));
               file_name = strcat(base_file_name,divider,'.',output_file_type);
               orient(the_pos_plots(pre_plot), 'portrait');
               saveas(the_pos_plots(pre_plot),file_name);
               pre_plot = pre_plot + 1;
            end
            if plot_count(7) > 0
               divider = sprintf('L%02d%02d',the_date(1), the_date(2));
               file_name = strcat(base_file_name,divider,'.',output_file_type);
               orient(the_pos_plots(pre_plot), 'tall');
               saveas(the_pos_plots(pre_plot),file_name);
               pre_plot = pre_plot + 1;
               if plot_components(7,6) ~= ' '
                  divider = sprintf('X%02d%02d',the_date(1), the_date(2));
                  file_name = strcat(base_file_name,divider,'.',output_file_type);
                  %
                  %  Note that for the XYZ plot, we need it in portrait mode to scale correctly
                  %
                  orient(the_pos_plots(pre_plot),'portrait');
                  saveas(the_pos_plots(pre_plot),file_name);
                  pre_plot = pre_plot + 1;
               end   
            end
            if plot_count(8) > 0
               divider = sprintf('P%02d%02d',the_date(1), the_date(2));
               file_name = strcat(base_file_name,divider,'.',output_file_type);
               orient(the_pos_plots(pre_plot), 'tall');
               saveas(the_pos_plots(pre_plot),file_name);
            end
         end
         if (max(the_pos_plots) > max_plots) & (max_plots > 0)
            'Awaiting permission to delete figures'
            pause
            for i=1:max(the_pos_plots)
               delete(i);
            end
         end
      end
   end
   window_start_time = window_end_time;
   window_index = window_index + 1;
end

   
   
