function [plot_handles] = plot_efmdc8_data(efm_data, time, s_dev_factor, plot_components, start_string, delta_seconds, window_width, orientation);
% function [plot_handles] = plot_efmdc8_data(efm_data, time, scale_factor, plot_components,
%  start_string, total_seconds, window_width, orientation);
%
% This routine plots the calibrated (in kV/m) or raw (in V) electric field mills data.
%
% Input:
%  efm_data = matrix of mill data (in either V/m or V) (2,6,N)
%  time = the time array (in datetick format) (N)
%  scale_factor = What fraction of data you want to plot (0-1.0).  This is to keep infrequent
%   spikes from dominating the plots (default, or set to 0: plot ALL data)
%  plot_components = character string of which components to plot as a series of x's, X's, e's, or E's
%   (x, X, e or E means plot that component, space means don't, order is sensitive PD, PU, SD, SU, AD, AU, then
%   the same order insensitive)
%   uppercase means plot with grid, lowercase without grid
%   X's mean plot as a voltage (uncalibrated) and E's mean plot as Volts/Meter (calibrated)
%  start_string = time (in datestr format or index #) where the data is to start (default or 0: start of data)
%  total_seconds = how much of the data to plot (default or 0: all data)
%    Note: if start_string is a char string, total_seconds units are seconds,
%    if start_string is an index, then total_seconds is in index #'s
%  window_width = how many seconds per plot window (default or 0: 30 minutes)
%    Note: if start_string is a char string, window_width units are seconds,
%    if start_string is an index, then window_width is in index #'s
%     orientation = is one of 'landscape', 'portrait', 'rotated', or 'tall' (default 'tall').
%
% Output:
%  plot_handles = the handles to all of the plots
%
   
%
% Fixing any information that was left out
%
   if ~exist('orientation','var')
      orientation = 'tall';
   end
   if ~exist('start_string','var')
      first_time = time(1);
   else
      if ischar(start_string) == 0
         if first_time < 1
            first_time = 1;
         end
         first_time = time(start_string);
      else
         first_time = datenum(start_string);
      end
   end
   if ~exist('delta_seconds','var')
      last_time = time(length(time));
   else
      if delta_seconds == 0
         last_time = time(length(time));
      else
         if ischar(start_string) == 0
            last_time = time(delta_seconds+start_string);
         else
            last_time = first_time + delta_seconds*1.1574e-5;
         end
      end
   end
   if ~exist('window_width','var')
      window_width = 30*60;
   else
      if window_width == 0
         window_width = 30*60;
      end
   end
   if window_width > 120
      dateform = 15;
   else
      dateform = 13;
   end
   if ~exist('s_dev_factor','var')
      s_dev_factor = 0;
   else
      if s_dev_factor ~= 0
         s_dev_factor = (1.0 - s_dev_factor)*0.5*100;
         if s_dev_factor > 100
            s_dev_factor = 0;
         end
         if s_dev_factor < 0
            s_dev_factor = 0;
         end
      end
   end
   max_index = length(time);
   if ~exist('plot_components','var')
      plot_components = 'XXXXXXXXXXXXXXXXXXXXXXXX';
   end
   %
   % Set up which components will be plotted
   %
   max_plots = length(plot_components);
   plot_count(1) = 0;
   plot_count(2) = 0;
   plot_count(3) = 0;
   plot_count(4) = 0;
   for index=1:max_plots
      if plot_components(index) ~= ' '
         if index < 7
            plot_count(1) = plot_count(1) + 1;
         else
            if index < 13
               plot_count(2) = plot_count(2) + 1;
            else
               if index < 19
                  plot_count(3) = plot_count(3) + 1;
               else
                  plot_count(4) = plot_count(4) + 1;
               end
            end
         end
      end
   end
   plot_count
   for index=1:max_plots
      if (plot_components(index) == 'e') | (plot_components(index) == 'E')
         efm_data = efm_data*0.001;
         break;
      end
   end
   if max_plots ~= 24
      for index=max_plots+1:24
         plot_components(index) = ' ';
      end
   end
   %
   % Determine where to start the plots
   %
   i=1;
   while time(i) < first_time
      i = i + 1;
      if i > max_index
         error('Ran off end of time array before hitting start time');
      end
   end
   first_efm_index = i
   window_start_time = first_time;
   window_width_index = round(window_width/((time(2)-time(1))*86400))
   i=1;
   while time(i) < last_time
      i = i + 1;
      if i > max_index
         i = max_index;
         break;
      end
   end
   last_efm_index = i
   %
   % Pre-size the data
   %
   presize = last_efm_index - first_efm_index + 1;
   window_start_index = first_efm_index;
   window_index = 1;
   while window_start_index < last_efm_index
      window_end_time = window_start_time + (window_width*1.157407e-5);
      datestr(window_start_time);
      datestr(window_end_time);
      time_end = window_start_index;
      while time(time_end) <= window_end_time
         time_end = time_end + 1;
         if time_end == last_efm_index+1
            break;
         end
      end
      time_end = time_end - 1;
      if time_end > last_efm_index
         time_end = last_efm_index;
      end
      %
      % Make sure we don't plot any small windows
      %
      if last_time - window_end_time < 0.1*window_width*1.157407e-5
         window_end_time = last_time;
         time_end = last_efm_index;
      end
      %
      %  Make sure we don't plot any blank windows
      %
      if time_end == window_start_index
         window_start_time = window_end_time;
         continue;
      end
      %
      % See if we need to even print the first page
      %
      dateChoice = 'yqmwdHMS';
      ax = 'x';
      [ticks,dateform] = bestscale(ax,window_start_time,window_end_time,dateform,dateChoice);
      for gain_index=1:4
         st_plot_comp = (gain_index-1)*6+1;
         ed_plot_comp = (gain_index-1)*6+6;
         if ~strcmp(plot_components(st_plot_comp:ed_plot_comp),'      ')
            gain_index;
            %
            % Plot data in window
            %
            plot_handles(window_index) = figure;
            orient(plot_handles(window_index),orientation);
            plot_number = 1;
            for component_index=1:6
               if plot_components(st_plot_comp+component_index-1) ~= ' '
                  subplot(plot_count(gain_index),1,plot_number),plot(time(window_start_index:time_end),squeeze(efm_data(gain_index,component_index,window_start_index:time_end)));
                  if plot_number == 1
                     switch gain_index
                      case 1
                        title('Gain x512');
                      case 2
                        title('Gain x64');
                      case 3
                        title('Gain x8');
                      case 4
                        title('Gain x1');
                     end
                  end
                  axis tight;
                  YY = axis;
                  YY(1) = window_start_time;
                  YY(2) = window_end_time;
                  axis(YY);
                  ax = 'x';
                  %
                  % Set axis tick labels
                  %
                  labels = datestr(ticks,dateform);
                  set(gca,[ax,'tick'],ticks,[ax,'ticklabel'],labels, ...
                       [ax,'lim'],[min(ticks) max(ticks)])
                  date_strings = get(gca,'xticklabel');
                  axis(YY);
                  set(gca,'xticklabel',[]);
                  switch plot_components(st_plot_comp+component_index-1)
                   case {'x', 'X'}
                     ylabel('V');
                   case {'E', 'e'}
                     ylabel('kV/m');
                  end
                  switch component_index
                   case 1
                     text(1,0.5,'TF','Units','normalized');
                   case 2
                     text(1,0.5,'TM','Units','normalized');
                   case 3
                     text(1,0.5,'RM','Units','normalized');
                   case 4
                     text(1,0.5,'LM','Units','normalized');
                   case 5
                     text(1,0.5,'BM','Units','normalized');
                   case 6
                     text(1,0.5,'BA','Units','normalized');
                  end
                  if s_dev_factor ~= 0.0
                     y_max = prctile(squeeze(efm_data(gain_index,component_index,window_start_index:time_end)),100-s_dev_factor);
                     y_min = prctile(squeeze(efm_data(gain_index,component_index,window_start_index:time_end)),s_dev_factor);
                     if y_max ~= y_min
                        axis_value = axis;
                        if isnan(y_max)
                           y_max = max(squeeze(efm_data(gain_index,component_index,window_start_index:time_end)));
                        end
                        if isnan(y_min)
                           y_min = min(squeeze(efm_data(gain_index,component_index,window_start_index:time_end)));
                        end
                        axis_value(3) = y_min;
                        axis_value(4) = y_max;
                        axis(axis_value);
                     end
                  end
                  plot_number = plot_number + 1;
                  if lower(plot_components(st_plot_comp+component_index-1)) == plot_components(st_plot_comp+component_index-1)
                     grid off;
                  else
                     grid on;
                  end
               end
            end
            set(gca, 'xticklabel', date_strings);
            xlabel(datestr(time(window_start_index),0));
            window_index = window_index + 1;
         end
      end
      window_start_index = time_end;
      window_start_time = window_end_time;
   end
