function [plot_handles] = plot_fast_data(m_trig_data_matrix, m_trig_time, trigger_summary, plot_components, start_string, delta_seconds, window_width,orientation);
%	function [plot_handles] = plot_fast_data(fast_data_matrix, trig_time, trigger_summary, plot_components, 
%     start_string, delta_seconds, window_width,orientation);
%
%	Input:
%		trig_data_matrix = T x 16 x N matrix of trig data, where T is the # of triggers and N is the # of points
%           per channel
%		trig_time = T x N time array (in seconds from trigger time)
%     trigger_summary = T size structure of trigger information
%		plot_components = array of variables to print (default, channels 1-8)
%		start_string = time (in datestr format or index #) where the data is to start (default or 0: start of data)
%		total_seconds = how much of the data to plot (default or 0: all data)
%				Note: if start_string is a char string, total_seconds units are seconds,
%				if start_string is an index, then total_seconds is in index #'s
%		window_width = how many seconds per plot window (default or 0: 30 seconds for low res data or 0.33 for hi res)
%				Note: if high res data and window width is less than the full trigger, the second index of
%           window_width tells where to center the plot (0 and default = trigger time)
%     orientation = is one of 'landscape', 'portrait', 'rotated', or 'tall' (default 'tall').
%
%	Output:
%		plot_handles = the handles to all of the plots
%

%
%	Set any defaults that were not entered by the user
%
global g_time g_data_matrix g_name_matrix window_start_index time_end plot_count plot_number plot_count_2 plot_number_2 window_start_time window_end_time g_plot_components date_strings dateform
if ~exist('plot_components','var')
   plot_components = [1 2 3 4 5 6 7 8];
end
g_plot_components = plot_components;
trig_name_matrix = {'OPS  Gain 1 Sig.', 'OPS  Gain 2 Sig.', 'Slo Ant - Ch-1', 'Slo Ant - Ch-2', 'Slo Ant - Ch-3', 'AC E Field  GSFC - X', 'AC E Field  GSFC - Y','AC E Field  GSFC - Z','DOPS - Ch-1','DOPS - Ch-2','Search Coil - X Sig.','Search Coil - Y Sig.','Search Coil - Z Sig.','Accel  - X Sig','Accel  - Y Sig','Accel  - Z Sig'};
trig_unit_matrix = ['volts';'volts';'volts';'volts';'volts';'volts';'volts';'volts';'volts';'volts';'volts';'volts';'volts';'volts';'volts';'volts'];
%
%  Determine which time was sent (which will determine how to plot the data
%
if max(max(m_trig_time)) < 0.5
   %
   %  We will plot high resolution triggered data
   %
   max_size = length(trigger_summary);
   if ~exist('start_string','var')
      first_time = trigger_summary(1).m_time;
   else
      if ischar(start_string) == 0
         first_time = start_string;
         if first_time < 1
            first_time = 1;
         end
         first_time = trigger_summary(first_time);
      else
         first_time = datenum(start_string);
      end
   end
   if ~exist('delta_seconds','var')
      last_time = trigger_summary(end).m_time;
   else
      if delta_seconds == 0
         last_time = trigger_summary(end).m_time;
      else
         if ischar(start_string) == 0
            last_time = trigger_summary(delta_seconds+start_string).m_time;
         else
            last_time = first_time + delta_seconds*1.1574e-5;
         end
      end
   end
   if ~exist('window_width','var')
      window_width(1) = 0.32768;
      window_width(2) = 0;
   else
      if window_width(1) == 0
         window_width(1) = 0.32768;
         window_width(2) = 0;
      end
      if length(window_width) == 1
         window_width(1) = window_width;
         window_width(2) = 0;
      end
   end
   %
   %  determine the begin:end times of each plot
   %
   beg_time = window_width(2) - 0.5*window_width(1)
   end_time = window_width(2) + 0.5*window_width(1)
   if ~exist('orientation','var')
      orientation = 'tall';
   end
   %
   %	Set up which components will be plotted
   %
   max_plots = max(size(plot_components));
   for i=1:11
      plot_count(i) = 0;
   end
   window_count = ceil(max_plots/8);
   windows_left = max_plots;
   for i=1:window_count
      plot_count(i) = ceil(windows_left/(window_count-i+1));
      windows_left = windows_left - plot_count(i);
   end
   plot_count
   %
   %	Determine where to start & end the plots
   %
   i=1;
   while trigger_summary(i).m_time < first_time
      i = i + 1;
      if i > max_size
         error('Fell off end of A/C data before hitting first time');
      end
   end
   first_pos_index = i;
   i=first_pos_index;
   while trigger_summary(i).m_time < last_time
      i = i + 1;
      if i > max_size
         i = max_size;
         break;
      end
   end
   last_pos_index = i;
   window_start_time = first_time;
   window_start_index = first_pos_index;
   window_index = 1;
   while window_start_index <= last_pos_index
      %
      %	Plot triggered data vs. time in window
      %
      plot_number = 1;
      %
      %  Build the time base for this plot
      %
      time_base = sscanf(trigger_summary(window_start_index).s_time,'%d:%d:%d:%f')
      time_base_string = sprintf('%03d %02d:%02d',time_base(1),time_base(2),time_base(3));
      time_base_string2 = sprintf('%03d %02d:%02d:%02d',time_base(1),time_base(2),time_base(3),floor(time_base(4)));
      %
      %  Set the window edges in time variable
      %
      delta_time = m_trig_time(window_start_index,2) - m_trig_time(window_start_index,1);
      if m_trig_time(window_start_index,1) > beg_time
         time_start_index = 1;
      else
         time_start_index = round(1 + (beg_time - m_trig_time(window_start_index,1))/delta_time);
      end
      time_end_index = round((end_time - beg_time)/delta_time + time_start_index);
      if time_end_index > length(m_trig_time(window_start_index,:))
         time_end_index = length(m_trig_time(window_start_index,:));
      end
      time_start_index;
      time_end_index;
      %
      %  Now set up plots
      %
      for plot_counter=1:window_count
         plot_handles(window_index) = figure;
         orient(plot_handles(window_index), orientation);
         window_start_index;
         if window_width(1) > 0.001
            the_title = sprintf('Trigger Time (delta sec from):%s Plot #:%d',trigger_summary(window_start_index).s_time,plot_counter);
            the_xlabel = sprintf('Time (sec) after %s',time_base_string);
         else
            the_title = sprintf('Trigger Time (delta msec from):%s Plot #:%d',trigger_summary(window_start_index).s_time,plot_counter);
            the_xlabel = sprintf('Time (msec) after %s',time_base_string2);
         end
         for plot_index=1:plot_count(plot_counter);
            if window_width(1) > 0.001
               squeeze(m_trig_data_matrix(window_start_index,plot_components(plot_number),time_start_index:time_end_index));
               subplot(plot_count(plot_counter),1,plot_index),line(time_base(4)+m_trig_time(window_start_index,time_start_index:time_end_index), squeeze(m_trig_data_matrix(window_start_index,plot_components(plot_number),time_start_index:time_end_index)));
            else
               time_base4 = time_base(4) - floor(time_base(4));
               subplot(plot_count(plot_counter),1,plot_index),line(1000*(time_base4+m_trig_time(window_start_index,time_start_index:time_end_index)), squeeze(m_trig_data_matrix(window_start_index,plot_components(plot_number),time_start_index:time_end_index)));
            end
            axis tight;
            ylabel(trig_unit_matrix(plot_components(plot_number),:));
            text(1.01,0.95,trig_name_matrix(plot_components(plot_number)),'Units','normalized','FontSize',7,'Rotation',-90);
            if plot_index == plot_count(plot_counter)
               xlabel(the_xlabel);
            end
            if plot_index ~= plot_count(plot_counter)
               set(gca,'xticklabel',[]);
            end
            ax1 = gca;
            set(gca,'XAxisLocation','bottom');
            ax2 = axes('Position',get(ax1,'Position'),'XAxisLocation','top','Color','none','XColor','k','YColor','k');
            if window_width(1) > 0.001
               hl2 = line(m_trig_time(window_start_index,time_start_index:time_end_index), squeeze(m_trig_data_matrix(window_start_index,plot_components(plot_number),time_start_index:time_end_index)),'Parent',ax2);
            else
               hl2 = line(1000*m_trig_time(window_start_index,time_start_index:time_end_index), squeeze(m_trig_data_matrix(window_start_index,plot_components(plot_number),time_start_index:time_end_index)),'Parent',ax2);
            end
            axis tight
            if plot_index ~= 1
               set(gca,'xticklabel',[]);
            end
            if plot_index == 1
               title(the_title);
            end
            plot_number = plot_number + 1;
         end
         window_index = window_index + 1;
      end
      window_start_index = window_start_index + 1;
   end
else
   %
   %  We will plot lo resolution data (to mark where triggers are)
   %
   the_size = size(m_trig_data_matrix)
   trig_data_matrix(the_size(2),the_size(3)*the_size(1)) = 0;
   time(the_size(3)*the_size(1)) = 0;
   for trig_index=1:the_size(1)
      for channel_index=1:16
         trig_data_matrix(channel_index,(trig_index-1)*the_size(3)+1:(trig_index-1)*the_size(3)+the_size(3)) = m_trig_data_matrix(trig_index,channel_index,1:the_size(3));
         trig_data_matrix(channel_index,(trig_index-1)*the_size(3)+1) = NaN;
      end
      time((trig_index-1)*the_size(3)+1:(trig_index-1)*the_size(3)+the_size(3)) = m_trig_time(trig_index,1:the_size(3));
   end
   size(trig_data_matrix);
   g_time = time;
   g_data_matrix = trig_data_matrix;
   g_name_matrix = trig_name_matrix;
   max_size = length(time);
   if ~exist('start_string','var')
      first_time = time(1);
   else
      if ischar(start_string) == 0
         if first_time < 1
            first_time = 1;
         end
         first_time = time(start_string);
      else
         first_time = datenum(start_string);
      end
   end
   if ~exist('delta_seconds','var')
      last_time = time(length(time));
   else
      if delta_seconds == 0
         last_time = time(length(time));
      else
         if ischar(start_string) == 0
            last_time = time(delta_seconds+start_string);
         else
            last_time = first_time + delta_seconds*1.1574e-5;
         end
      end
   end
   if ~exist('window_width','var')
      window_width = 30*60;
   else
      if window_width == 0
         window_width = 30*60;
      else
         if ischar(start_string) == 0
            window_width = (time(window_width) - time(1))*86400;
         end
      end
   end
   if ~exist('plot_components','var')
      plot_components = [1 2 3 4 5 6];
   end
   if ~exist('orientation','var')
      orientation = 'tall';
   end
   %
   %	Set up which components will be plotted
   %
   max_plots = max(size(plot_components));
   for i=1:11
      plot_count(i) = 0;
   end
   window_count = ceil(max_plots/8);
   windows_left = max_plots;
   for i=1:window_count
      plot_count(i) = ceil(windows_left/(window_count-i+1));
      windows_left = windows_left - plot_count(i);
   end
   plot_count
   %
   %	Determine where to start & end the plots
   %
   i=1;
   while time(i) < first_time
      i = i + 1;
      if i > max_size
         error('Fell off end of A/C data before hitting first time');
      end
   end
   first_pos_index = i;
   i=first_pos_index;
   while time(i) < last_time
      i = i + 1;
      if i > max_size
         i = max_size;
         break;
      end
   end
   last_pos_index = i
   window_start_time = first_time;
   window_start_index = first_pos_index;
   window_index = 0;
   if window_width > 120
      dateform = 15;
   else
      dateform = 13;
   end
   while window_start_time < last_time
      %
      %	Plot aircraft data vs. time in window
      %
      time_end = window_start_index;
      window_end_time = window_start_time + (window_width*1.157407e-5);
      %
      %	Make sure we don't plot any small windows
      %
      if last_time - window_end_time < 0.1*window_width*1.157407e-5
         window_end_time = last_time;
      end
      while time(time_end) <= window_end_time
         time_end = time_end + 1;
         if time_end >= max_size
            time_end = max_size;
            break;
         end
      end
      time_end = time_end - 1;
      %
      %	Now do the plots
      %
      if time_end > window_start_index
         total_plots_done = 0;
         for plot_counter=1:window_count
            window_index = window_index + 1;
            plot_handles(window_index) = figure;
            orient(plot_handles(window_index), orientation);
            plot_number = 1;
            window_start_index
            time_end
            the_title = sprintf('trig Data #%d',plot_counter);
            for plot_index=1:plot_count(plot_counter);
               the_plot_index = plot_components(plot_index + total_plots_done);
               plot_count(plot_counter);
               trig_name_matrix(the_plot_index);
               trig_unit_matrix(the_plot_index,:);
               subsubplot(plot_index,plot_count(plot_counter),the_plot_index,trig_name_matrix(the_plot_index),trig_unit_matrix(the_plot_index,:),trig_data_matrix, the_title);
            end
	         set(gca, 'xticklabel', date_strings);
		      xlabel(datestr(time(window_start_index),0));
            total_plots_done = total_plots_done + plot_count(plot_counter);
         end
      end
      %
      %	Prepare for next group
      %
      window_start_index = time_end + 1;
      window_start_time = window_end_time;
   end
   return
end

function subsubplot(the_index, total_components,the_component,text_label,y_label,data_matrix,the_title)
global g_time g_data_matrix g_name_matrix window_start_index time_end plot_count plot_number plot_count_2 plot_number_2 window_start_time window_end_time g_plot_components date_strings dateform
%
subplot(total_components,1,the_index),plot(g_time(window_start_index:time_end),data_matrix(the_component,window_start_index:time_end));
if the_index == 1
	title(the_title);
end
axis tight;
YY = axis;
YY(1) = window_start_time;
YY(2) = window_end_time;
axis(YY);
%datetick('x',dateform);
dateChoice = 'yqmwdHMS';
ax = 'x';
[ticks,dateform] = bestscale(ax,window_start_time,window_end_time,dateform,dateChoice);
%ticks = bestscale(ax,window_start_time,window_end_time,dateform,dateChoice);
% Set axis tick labels
labels = datestr(ticks,dateform);
set(gca,[ax,'tick'],ticks,[ax,'ticklabel'],labels, ...
        [ax,'lim'],[min(ticks) max(ticks)])
date_strings = get(gca,'xticklabel');
axis(YY);
set(gca,'xticklabel',[]);
ylabel(y_label);
text(1,0.5,text_label,'Units','normalized');
plot_number = plot_number + 1;
grid on;
return

