function [plot_handles] = plot_gain_data(gain_data, time, plot_components, start_string, delta_seconds, window_width);
%	function [plot_handles] = plot_gain_data(gain_data, time, plot_components, start_string, delta_seconds, window_width);
%
%	This routine plots the gain used to determine the calibrated electric field mills data.
%
%	Input:
%		gain_data = matrix of mill gain (6,N)
%        to stop frequent gain changes near the limits, a hystereses was added so that
%        when data is between 0 and 95% of the low gain fullscale, gain 1 is used.  gain(i)
%        is then set to 1.  When data is above 95%, gain 2 is used.  gain(i) is then set to
%        2.  Gain 2 is used untill data is below 70% of the low gain fullscale. gain for this
%        case is set to 1.5.
%		time = the time array (in datetick format) (N)
%		plot_components = 2x6 character matrix of which components to plot as a series of characters
%		start_string = time (in datestr format or index #) where the data is to start (default or 0: start of data)
%		delta_seconds = how much of the data to plot (default or 0: all data)
%				Note: if start_string is a char string, delta_seconds units are seconds,
%				if start_string is an index, then delta_seconds is in index #'s
%		window_width = how many seconds per plot window (default or 0: 30 minutes)
%				Note: if start_string is a char string, window_width units are seconds,
%				if start_string is an index, then window_width is in index #'s
%
%	Output:
%		plot_handles = the handles to all of the plots
%

%
%	Fixing any information that was left out
%
if ~exist('plot_components','var')
   plot_components = 'XXXXXXXXXXXX';
end
if ~exist('start_string','var')
   first_time = time(1);
else
   if ischar(start_string) == 0
      if first_time < 1
         first_time = 1;
      end
      first_time = time(start_string);
   else
      first_time = datenum(start_string);
   end
end
if ~exist('delta_seconds','var')
   last_time = time(length(time));
else
   if delta_seconds == 0
      last_time = time(length(time));
   else
      if ischar(start_string) == 0
         last_time = time(delta_seconds+start_string);
      else
         last_time = first_time + delta_seconds*1.1574e-5;
      end
   end
end
if ~exist('window_width','var')
   window_width = 30*60;
else
   if window_width == 0
      window_width = 30*60;
   end
end
if window_width > 120
   dateform = 15;
else
   dateform = 13;
end
max_index = length(time);
max_plots = length(plot_components);
plot_count = 0;
for index=1:max_plots
   if plot_components(index) ~= ' '
      plot_count = plot_count + 1;
   end
end
if max_plots ~= 6
   for index=max_plots+1:6
 	  plot_components(index) = ' ';
   end
end
%
%	Determine where to start the plots
%
i=1;
while time(i) < first_time
   i = i + 1;
   if i > max_index
      error('Ran off end of time array before hitting start time');
   end
end
first_gain_index = i
window_start_time = first_time;
window_width_index = round(window_width/((time(2)-time(1))*86400))
i=1;
while time(i) < last_time
   i = i + 1;
   if i > max_index
      i = max_index;
      break;
   end
end
last_gain_index = i;
datestr(last_time);
window_start_index = first_gain_index;
window_index = 1;
while window_start_time < last_time
   window_end_time = window_start_time + (window_width*1.157407e-5);
   time_end = window_start_index;
   while time(time_end) <= window_end_time
      time_end = time_end + 1;
      if time_end == last_gain_index+1
         break;
      end
   end
   time_end = time_end - 1;
   if time_end > last_gain_index
      time_end = last_gain_index;
   end
   %
   %	Make sure we don't plot any small windows
   %
   if last_time - window_end_time < 0.1*window_width*1.157407e-5
      window_end_time = last_time;
      time_end = last_gain_index;
   end
   %
   %	Plot gain data in window
   %
   plot_handles(window_index) = figure;
   plot_index = 1;
   datestr(window_start_time)
   datestr(window_end_time)
   datestr(time(time_end))
   for plotting_index=1:6
      if ~isempty(plot_components(plotting_index))
   	   subplot(plot_count,1,plotting_index),plot(time(window_start_index:time_end),gain_data(plotting_index,window_start_index:time_end));
         if plotting_index == 1
            title('Gain');
         end
         plot_index = plot_index + 1;
         axis tight;
		   YY = axis;
		   YY(1) = window_start_time;
		   YY(2) = window_end_time;
		   axis(YY);
		   dateChoice = 'yqmwdHMS';
	      ax = 'x';
	      ticks = bestscale(ax,window_start_time,window_end_time,dateform,dateChoice);
         % Set axis tick labels
         labels = datestr(ticks,dateform);
		   set(gca,[ax,'tick'],ticks,[ax,'ticklabel'],labels, ...
     			  [ax,'lim'],[min(ticks) max(ticks)])
   	   date_strings = get(gca,'xticklabel');
		   axis(YY);
         set(gca,'xticklabel',[]);
%         ylabel('Gain');
         set(gca,'yticklabel',['  sensitive';'insensitive']);
		   axis_value = axis;
		   axis_value(3) = 0.5;
         axis_value(4) = 2.5;
         axis(axis_value);
         switch plotting_index
         	case 1
               text(1,0.5,'PD','Units','normalized');
            case 2
               text(1,0.5,'PU','Units','normalized');
            case 3
               text(1,0.5,'SD','Units','normalized');
            case 4
               text(1,0.5,'SU','Units','normalized');
            case 5
               text(1,0.5,'AD','Units','normalized');
            case 6
               text(1,0.5,'AU','Units','normalized');
         end
      end
   end
   %
   %	Prepare for next group
   %
   set(gca, 'xticklabel', date_strings);
   xlabel(datestr(time(window_start_index),0));
   window_start_index = time_end;
   window_index = window_index + 1;
   window_start_time = window_end_time;
end
