function [plot_handles] = plot_gbfm_data(gbfm_data_matrix, time, s_dev_factor, plot_components, start_string, delta_seconds, window_width,orientation);
%	function [plot_handles] = plot_gbfm_data(gbfm_data_matrix, time, scale_factor, plot_components, 
%		start_string, total_seconds, window_width, orientation)
%
%	This routine plots the GBFM electric field data based on the options
%
%	Inputs:
%		gbfm_data_matrix = (40,N) matrix of surface electric field data
%		time = the (1,N) time array (in datetick format)
%		scale_factor = What fraction of data you want to plot (0-1.0).  This is to keep infrequent
%			spikes from dominating the plots (default, or set to 0: plot ALL data)
%		plot_components = character string of which components to plot as a series of x's, n's, 
%			X's, N's or spaces (x, X, N, or n means plot that component, space means don't) 
%			If you use upper case letters, a grid will be printed
%		start_string = time (in datestr format or index #) where the data is to start (default or 0: start of data)
%		total_seconds = how much of the data to plot (default or 0: all data)
%				Note: if start_string is a char string, total_seconds units are seconds,
%				if start_string is an index, then total_seconds is in index #'s
%		window_width = how many seconds per plot window (default or 0: 30 minutes)
%				Note: if start_string is a char string, window_width units are seconds,
%				if start_string is an index, then window_width is in index #'s
%     orientation = is one of 'landscape', 'portrait', 'rotated', or 'tall' (default 'tall').
%
%	Output:
%		plot_handles = the handles to all of the plots
%

%
%	Set defaults
%
if ~exist('orientation','var')
   orientation = 'tall';
end
if ~exist('s_dev_factor','var')
   s_dev_factor = 0;
else
   if s_dev_factor ~= 0
	   s_dev_factor = (1.0 - s_dev_factor)*0.5*100;
	   if s_dev_factor > 100
	      s_dev_factor = 0;
	   end
	   if s_dev_factor < 0
	      s_dev_factor = 0;
	   end
   end
end
if ~exist('plot_components','var')
   plot_components = 'xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx';
end
if ~exist('start_string','var')
   first_time = time(1);
else
   if ischar(start_string) == 0
      if first_time < 1
         first_time = 1;
      end
      first_time = time(start_string);
   else
      first_time = datenum(start_string);
   end
end
if ~exist('delta_seconds','var')
   last_time = time(length(time));
else
   if delta_seconds == 0
      last_time = time(length(time));
   else
      if ischar(start_string) == 0
         last_time = time(delta_seconds+start_string);
      else
         last_time = first_time + delta_seconds*1.1574e-5;
      end
   end
end
if ~exist('window_width','var')
   window_width = 30*60;
else
   if window_width == 0
      window_width = 30*60;
   else
      if ischar(start_string) == 0
         window_width = (time(window_width) - time(1))*86400;
      end
   end
end
max_index = length(time);
max_plots = length(plot_components);
plot_count = 0;
for index=1:max_plots
   switch lower(plot_components(index))
   case 'x'
      plot_count = plot_count + 1;
   case 'n'
      plot_count = plot_count + 1;
   end
end
%
%  Need to determine the # of pages to plot
%
page_count = ceil(plot_count/8);
leftover_plots = plot_count;
for index=1:page_count
   plot_count_array(index) = ceil(leftover_plots/(page_count+1-index));
   leftover_plots = leftover_plots - plot_count_array(index);
end
plot_count_array
plot_count_max = max(plot_count_array)
if max_plots ~= 40
   for index=max_plots+1:40
 	  plot_components(index) = ' ';
   end
end
%
%	Determine where to start/stop the plots
%
i=1;
while time(i) < first_time
   i = i + 1;
   if i > max_index
      error('Ran off end of time array before hitting start time');
   end
end
first_index = i
window_width_index = round(window_width/((time(2)-time(1))*86400));
i=1;
while time(i) < last_time
   i = i + 1;
   if i > max_index
      i = max_index;
      break;
   end
end
last_index = i
window_start_time = first_time;
window_start_index = first_index;
window_index = 1;
if window_width > 120
   dateform = 15;
else
   dateform = 13;
end
while window_start_index < last_index
   %
   %	Set the window edges
   %
   time_end = window_start_index;
   window_end_time = window_start_time + (window_width*1.157407e-5);
   %
   %	Make sure we don't plot any small windows
   %
   if last_time - window_end_time < 0.1*window_width*1.157407e-5
      window_end_time = last_time;
   end
   while time(time_end) <= window_end_time
      time_end = time_end + 1;
      if time_end == max_index
         break;
      end
   end
   time_end = time_end - 1;
   %
   %	Plot field data in window
   %
   if window_start_index < time_end
	   plot_handles(window_index) = figure;
      orient(plot_handles(window_index),orientation);
   end
   plot_number = 1;
   %
   %	Now do the plots
   %
   window_start_index
   time_end
   dateChoice = 'yqmwdHMS';
   ax = 'x';
   [ticks,dateform] = bestscale(ax,window_start_time,window_end_time,dateform,dateChoice);
   plot_index = 1;
   for page_index=1:page_count
      figure;
      for plotting_index=1:plot_count_array(page_index)
         while plot_components(plot_index) == ' '
            plot_index = plot_index+1;
         end
         subplot(plot_count_max,1,plotting_index),plot(time(window_start_index:time_end),0.001*gbfm_data_matrix(window_start_index:time_end,plot_index));
		   if plotting_index == 1
 		      title('Electric Field','Interpreter','none');
		   end
			axis tight;
			YY = axis;
			YY(1) = window_start_time;
			YY(2) = window_end_time;
			axis(YY);
			% Set axis tick labels
			labels = datestr(ticks,dateform);
			set(gca,[ax,'tick'],ticks,[ax,'ticklabel'],labels, ...
      			  [ax,'lim'],[min(ticks) max(ticks)])
			date_strings = get(gca,'xticklabel');
			axis(YY);
			set(gca,'xticklabel',[]);
         if plotting_index ~= 6
            ylabel('kV/m');
         end
         text(1,0.5,sprintf('%d',plot_index),'Units','normalized');
		   if s_dev_factor ~= 0.0
		      y_max = prctile(0.001*gbfm_data_matrix(window_start_index:time_end,plotting_index),100-s_dev_factor);
		      y_min = prctile(0.001*gbfm_data_matrix(window_start_index:time_end,plotting_index),s_dev_factor);
		      axis_value = axis;
            if ~isempty(y_min)
               axis_value(3) = y_min;
            end
            if ~isempty(y_max);
               axis_value(4) = y_max;
            end
            if y_max ~= y_min
	            if isnan(y_max)
	               y_max = max(0.001*gbfm_data_matrix(window_start_index:time_end,plotting_index));
	            end
	            if isnan(y_min)
	               y_min = min(0.001*gbfm_data_matrix(window_start_index:time_end,plotting_index));
		         end
				   axis_value(3) = y_min;
				   axis_value(4) = y_max;
			      if y_max ~= y_min
		            axis(axis_value);
		         end
		      end
         end
	      plot_index = plot_index + 1;
		   if lower(plot_components(plotting_index)) == plot_components(plotting_index)
		      grid off;
		   else
		      grid on;
%              set(gca,'GridLineStyle','--');
		   end
      end
   end
   if window_start_index < time_end
	   set(gca, 'xticklabel', date_strings);
      xlabel(datestr(time(window_start_index),0));
   end
   %
   %	Prepare for next group
   %
   window_start_index = time_end + 1;
   window_index = window_index + 1;
   window_start_time = window_end_time;
end
