function [plot_handles] = plot_raw_efm_data(efm_data, time, s_dev_factor, plot_components, start_string, delta_seconds, window_width);
%	function [plot_handles] = plot_raw_efm_data(efm_data, time, scale_factor, plot_components, 
%		start_string, total_seconds, window_width);
%
%	This routine plots the raw (in volts) electric field mill data in either volts or V/m (if the
%		mill_calibration matrix (V to V/m) is present. 
%
%	Input:
%		efm_data = matrix of mill data (2,6,N)
%		time = the time array (in datetick format) (N)
%		scale_factor = What fraction of data you want to plot (0-1.0).  This is to keep infrequent
%			spikes from dominating the plots (default, or set to 0: plot ALL data)
%		plot_components = character string of which components to plot as a series of x's or X's, 
%			(x or X means plot that component, space means don't, order is sensitive PD, PU, SD, SU, AD, AU, then
%			the same order insensitive)
%			uppercase means plot with grid, lowercase without grid
%		start_string = time (in datestr format or index #) where the data is to start (default or 0: start of data)
%		total_seconds = how much of the data to plot (default or 0: all data)
%				Note: if start_string is a char string, total_seconds units are seconds,
%				if start_string is an index, then total_seconds is in index #'s
%		window_width = how many seconds per plot window (default or 0: 30 minutes)
%				Note: if start_string is a char string, window_width units are seconds,
%				if start_string is an index, then window_width is in index #'s
%
%	Output:
%		plot_handles = the handles to all of the plots
%

%
%	Fixing any information that was left out
%
if ~exist('start_string','var')
   first_time = time(1);
else
   if ischar(start_string) == 0
      if first_time < 1
         first_time = 1;
      end
      first_time = time(start_string);
   else
      first_time = datenum(start_string);
   end
end
if ~exist('delta_seconds','var')
   last_time = time(length(time));
else
   if delta_seconds == 0
      last_time = time(length(time));
   else
      if ischar(start_string) == 0
         last_time = time(delta_seconds+start_string);
      else
         last_time = first_time + delta_seconds*1.1574e-5;
      end
   end
end
if ~exist('window_width','var')
   window_width = 30*60;
else
   if window_width == 0
      window_width = 30*60;
   else
      if ischar(start_string) == 0
         window_width = (time(window_width) - time(1))*86400;
      end
   end
end
if ~exist('s_dev_factor','var')
   s_dev_factor = 0;
else
   if s_dev_factor ~= 0
	   s_dev_factor = (1.0 - s_dev_factor)*0.5*100;
	   if s_dev_factor > 100
	      s_dev_factor = 0;
	   end
	   if s_dev_factor < 0
	      s_dev_factor = 0;
	   end
   end
end
max_index = length(time);
if ~exist('plot_components','var')
   plot_components = 'xxxxxxxxxxxx';
end
%
%	Set up which components will be plotted
%
max_plots = length(plot_components);
plot_count_1 = 0;
plot_count_2 = 0;
for index=1:max_plots
   if plot_components(index) ~= ' '
      if index < 7
         plot_count_1 = plot_count_1 + 1;
      else
         plot_count_2 = plot_count_2 + 1;
      end
   end
end
if max_plots ~= 12
   for index=max_plots+1:12
 	  plot_components(index) = ' ';
   end
end
%
%	Determine where to start the plots
%
i=1;
while time(i) < first_time
   i = i + 1;
   if i > max_index
      error('Ran off end of time array before hitting start time');
   end
end
first_efm_index = i
window_width_index = round(window_width/((time(2)-time(1))*86400))
i=1;
while time(i) < last_time
   i = i + 1;
   if i > max_index
      i = max_index;
      break;
   end
end
last_efm_index = i
%
%	Pre-size the data
%
presize = last_efm_index - first_efm_index + 1;
window_start_index = first_efm_index;
window_index = 1;
while window_start_index < last_efm_index
   time_end = window_start_index + window_width_index;
   if time_end > last_efm_index
      time_end = last_efm_index;
   end
   %
   %	Make sure we don't plot any small windows
   %
   if (last_efm_index-time_end) < 0.1*window_width_index
      time_end = last_efm_index;
   end
   %
   %	Now do the plots
   %
   data_start = window_start_index - first_efm_index + 1;
   data_end = time_end - first_efm_index + 1;
   if ~strcmp(plot_components(1:6),'      ')
	   %
	   %	Plot sensitive data in window
	   %
	   plot_handles(window_index) = figure;
	   plot_number = 1;
      for component_index=1:6
		   if plot_components(component_index) ~= ' '
		      subplot(plot_count_1,component_index,plot_number),plot(time(window_start_index:time_end),efm_data(1,component_index,window_start_index:time_end));
			   if plot_number == 1
			      title('Sensitive');
			   end
		      datetick;
		      set(gca,'xticklabel',[]);
		      axis tight;
            ylabel('V');
            switch(component_index)
            case 1
               text(1,0.5,'PD','Units','normalized');
            case 2
               text(1,0.5,'PU','Units','normalized');
            case 3
               text(1,0.5,'SD','Units','normalized');
            case 4
               text(1,0.5,'SU','Units','normalized');
            case 5
               text(1,0.5,'AD','Units','normalized');
            case 6
               text(1,0.5,'AU','Units','normalized');
            end
			   if s_dev_factor ~= 0.0
			      y_max = prctile(efm_data(1,component_index,window_start_index:time_end),100-s_dev_factor);
			      y_min = prctile(efm_data(1,component_index,window_start_index:time_end),s_dev_factor);
		         if y_max ~= y_min
				      axis_value = axis;
		            if isnan(ymax)
		               y_max = max(efm_data(1,component_index,window_start_index:time_end));
		            end
		            if isnan(ymin)
		               y_min = min(efm_data(1,component_index,window_start_index:time_end));
		            end
				      axis_value(3) = y_min;
				      axis_value(4) = y_max;
		            axis(axis_value);
		         end
			   end
		      plot_number = plot_number + 1;
		      if lower(plot_components(component_index)) == plot_components(component_index)
		         grid off;
		      else
		         grid on;
		      end
         end
      end
	   xlabel(datestr(time(window_start_index),0));
      window_index = window_index + 1;
   end
   if ~strcmp(plot_components(7:12),'      ')
	   %
	   %	Now plot insensitive
	   %
	   plot_handles(window_index) = figure;
	   plot_number = 1;
	   if plot_components(7) ~= ' '
		   subplot(plot_count_2,1,plot_number),plot(time(window_start_index:time_end),mill_1_i(data_start:data_end));
		   if plot_number == 1
		      title('Insensitive');
		   end
		   datetick;
		   set(gca,'xticklabel',[]);
		   axis tight;
			if exist('mill_calibration','var')
		      ylabel('V/m');
		   else
		      ylabel('V');
		   end
		   text(1,0.5,'PD','Units','normalized');
		   if s_dev_factor ~= 0.0
		      mid_point = trimmean(mill_1_i(data_start:data_end),5);
		      s_dev = std(mill_1_i(data_start:data_end));
		      y_max = mid_point + s_dev_factor*s_dev;
		      y_min = mid_point - s_dev_factor*s_dev;
		      axis_value = axis;
		      axis_value(3) = y_min;
		      axis_value(4) = y_max;
		      axis(axis_value);
		   end
	      plot_number = plot_number + 1;
	      if lower(plot_components(7)) == plot_components(7)
	  	      grid off;
	      else
	         grid on;
	      end
	   end
	   if plot_components(8) ~= ' '
		   subplot(plot_count_2,1,plot_number),plot(time(window_start_index:time_end),mill_2_i(data_start:data_end));
		   if plot_number == 1
		      title('Insensitive');
		   end
		   datetick;
		   set(gca,'xticklabel',[]);
		   axis tight;
			if exist('mill_calibration','var')
		      ylabel('V/m');
		   else
		      ylabel('V');
		   end
		   text(1,0.5,'PU','Units','normalized');
		   if s_dev_factor ~= 0.0
		      mid_point = trimmean(mill_2_i(data_start:data_end),5);
		      s_dev = std(mill_2_i(data_start:data_end));
		      y_max = mid_point + s_dev_factor*s_dev;
		      y_min = mid_point - s_dev_factor*s_dev;
		      axis_value = axis;
		      axis_value(3) = y_min;
		      axis_value(4) = y_max;
		      axis(axis_value);
		   end
	      plot_number = plot_number + 1;
	      if lower(plot_components(8)) == plot_components(8)
	         grid off;
	      else
	         grid on;
	      end
	   end
	   if plot_components(9) ~= ' '
		   subplot(plot_count_2,1,plot_number),plot(time(window_start_index:time_end),mill_3_i(data_start:data_end));
		   if plot_number == 1
		      title('Insensitive');
		   end
		   datetick;
		   set(gca,'xticklabel',[]);
		   axis tight;
			if exist('mill_calibration','var')
		      ylabel('V/m');
		   else
		      ylabel('V');
		   end
		   text(1,0.5,'SD','Units','normalized');
		   if s_dev_factor ~= 0.0
		      mid_point = trimmean(mill_3_i(data_start:data_end),5);
		      s_dev = std(mill_3_i(data_start:data_end));
		      y_max = mid_point + s_dev_factor*s_dev;
		      y_min = mid_point - s_dev_factor*s_dev;
		      axis_value = axis;
		      axis_value(3) = y_min;
		      axis_value(4) = y_max;
		      axis(axis_value);
		   end
	      plot_number = plot_number + 1;
	      if lower(plot_components(9)) == plot_components(9)
	         grid off;
	      else
	         grid on;
	      end
	   end
	   if plot_components(10) ~= ' '
		   subplot(plot_count_2,1,plot_number),plot(time(window_start_index:time_end),mill_4_i(data_start:data_end));
		   if plot_number == 1
		      title('Insensitive');
		   end
		   datetick;
		   set(gca,'xticklabel',[]);
		   axis tight;
			if exist('mill_calibration','var')
		      ylabel('V/m');
		   else
		      ylabel('V');
			end
		   text(1,0.5,'SU','Units','normalized');
		   if s_dev_factor ~= 0.0
		      mid_point = trimmean(mill_4_i(data_start:data_end),5);
		      s_dev = std(mill_4_i(data_start:data_end));
		      y_max = mid_point + s_dev_factor*s_dev;
		      y_min = mid_point - s_dev_factor*s_dev;
		      axis_value = axis;
		      axis_value(3) = y_min;
		      axis_value(4) = y_max;
		      axis(axis_value);
		   end
	      plot_number = plot_number + 1;
	      if lower(plot_components(10)) == plot_components(10)
	         grid off;
	      else
	         grid on;
	      end
	   end
	   if plot_components(11) ~= ' '
		   subplot(plot_count_2,1,plot_number),plot(time(window_start_index:time_end),mill_5_i(data_start:data_end));
		   if plot_number == 1
		      title('Insensitive');
		   end
		   datetick;
		   set(gca,'xticklabel',[]);
		   axis tight;
			if exist('mill_calibration','var')
		      ylabel('V/m');
		   else
		      ylabel('V');
		   end
		   text(1,0.5,'AD','Units','normalized');
		   if s_dev_factor ~= 0.0
		      mid_point = trimmean(mill_5_i(data_start:data_end),5);
		      s_dev = std(mill_5_i(data_start:data_end));
		      y_max = mid_point + s_dev_factor*s_dev;
		      y_min = mid_point - s_dev_factor*s_dev;
		      axis_value = axis;
		      axis_value(3) = y_min;
		      axis_value(4) = y_max;
		      axis(axis_value);
		   end
	      plot_number = plot_number + 1;
	      if lower(plot_components(11)) == plot_components(11)
	         grid off;
	      else
	         grid on;
	      end
	   end
	   if plot_components(12) ~= ' '
		   subplot(plot_count_2,1,plot_number),plot(time(window_start_index:time_end),mill_6_i(data_start:data_end));
		   if plot_number == 1
		      title('Insensitive');
		   end
		   datetick;
		   axis tight;
			if exist('mill_calibration','var')
		      ylabel('V/m');
		   else
		      ylabel('V');
		   end
		   text(1,0.5,'AU','Units','normalized');
		   if s_dev_factor ~= 0.0
		      mid_point = trimmean(mill_6_i(data_start:data_end),5);
		      s_dev = std(mill_6_i(data_start:data_end));
		      y_max = mid_point + s_dev_factor*s_dev;
		      y_min = mid_point - s_dev_factor*s_dev;
		      axis_value = axis;
		      axis_value(3) = y_min;
		      axis_value(4) = y_max;
		      axis(axis_value);
	      end
	      if lower(plot_components(12)) == plot_components(12)
	         grid off;
	      else
	         grid on;
	      end
	   end
	   xlabel(datestr(time(window_start_index),0));
	   window_index = window_index + 1;
	   %
	   %	Prepare for next group
      %
   end
   window_start_index = last_efm_index;
end
