function [plot_handles] = plot_status_data(status_data, plot_components, start_string, delta_seconds, window_width, orientation);
% function [plot_handles] = plot_status_data(status_data, plot_components,
%  start_string, total_seconds, window_width, orientation);
%
% This routine plots the status data.
%
% Input:
%  status_data = structure/matrix of mill status data
%  plot_components = character string of which mill's status to plot as a series of x's, X's
%   (x, X means plot that status data, space means don't, order is GPS, PC, file, subseconds, ID, delta t, mill state, freq)
%   uppercase means plot with grid, lowercase without grid
%  start_string = time (in datestr format or index #) where the data is to start (default or 0: start of data)
%  total_seconds = how much of the data to plot (default or 0: all data)
%    Note: if start_string is a char string, total_seconds units are seconds,
%    if start_string is an index, then total_seconds is in index #'s
%  window_width = how many seconds per plot window (default or 0: 30 minutes)
%    Note: if start_string is a char string, window_width units are seconds,
%    if start_string is an index, then window_width is in index #'s
%     orientation = is one of 'landscape', 'portrait', 'rotated', or 'tall' (default 'tall').
%
% Output:
%  plot_handles = the handles to all of the plots
%
   
%
%  Setup time base variables
%
   time(length(status_data)) = 0;
   status(4,length(status_data)) = 0;
   mill_data(6,4,length(status_data)) = 0;
   for i=1:length(status_data)
      time(i) = status_data(i).best_time;
      status(1,i) = (status_data(i).timeGPS-status_data(i).best_time)*86400;
      status(2,i) = (status_data(i).timePC-status_data(i).best_time)*86400;
      status(3,i) = (status_data(i).file_time-status_data(i).best_time)*86400;
      status(4,i) = status_data(i).subseconds;
      for j=1:6
         mill_data(j,1,i) = status_data(i).mill_ID(j);
         mill_data(j,2,i) = status_data(i).mill_delta_time(j);
         mill_data(j,3,i) = status_data(i).mill_state(j);
         mill_data(j,4,i) = status_data(i).mill_freq(j);
      end
   end
   %
   % Fixing any information that was left out
   %
   if ~exist('orientation','var')
      orientation = 'tall';
   end
   if ~exist('start_string','var')
      first_time = time(1);
   else
      if ischar(start_string) == 0
         if first_time < 1
            first_time = 1;
         end
         first_time = time(start_string);
      else
         first_time = datenum(start_string);
      end
   end
   if ~exist('delta_seconds','var')
      last_time = time(length(time));
   else
      if delta_seconds == 0
         last_time = time(length(time));
      else
         if ischar(start_string) == 0
            last_time = time(delta_seconds+start_string);
         else
            last_time = first_time + delta_seconds*1.1574e-5;
         end
      end
   end
   if ~exist('window_width','var')
      window_width = 30*60;
   else
      if window_width == 0
         window_width = 30*60;
      end
   end
   if window_width > 120
      dateform = 15;
   else
      dateform = 13;
   end
   max_index = length(time);
   if ~exist('plot_components','var')
      plot_components = 'XXXXXXXX';
   end
   %
   % Set up which components will be plotted
   %
   max_plots = length(plot_components);
   plot_count_1 = 0;
   plot_count_2 = 0;
   for index=1:max_plots
      if plot_components(index) ~= ' '
         if index < 5
            plot_count_1 = plot_count_1 + 1;
         else
            plot_count_2 = plot_count_2 + 1;
         end
      end
   end
   if max_plots ~= 10
      for index=max_plots+1:10
         plot_components(index) = ' ';
      end
   end
   %
   % Determine where to start the plots
   %
   i=1;
   while time(i) < first_time
      i = i + 1;
      if i > max_index
         error('Ran off end of time array before hitting start time');
      end
   end
   first_status_index = i
   window_start_time = first_time;
   window_width_index = round(window_width/((time(2)-time(1))*86400))
   i=1;
   while time(i) < last_time
      i = i + 1;
      if i > max_index
         i = max_index;
         break;
      end
   end
   last_status_index = i
   %
   % Pre-size the data
   %
   presize = last_status_index - first_status_index + 1;
   window_start_index = first_status_index;
   window_index = 1;
   while window_start_index < last_status_index
      window_end_time = window_start_time + (window_width*1.157407e-5);
      time_end = window_start_index;
      while time(time_end) <= window_end_time
         time_end = time_end + 1;
         if time_end == last_status_index+1
            break;
         end
      end
      time_end = time_end - 1;
      if time_end > last_status_index
         time_end = last_status_index;
      end
      %
      % Make sure we don't plot any small windows
      %
      if last_time - window_end_time < 0.1*window_width*1.157407e-5
         window_end_time = last_time;
         time_end = last_status_index;
      end
      %
      % See if we need to even print the first page
      %
      dateChoice = 'yqmwdHMS';
      ax = 'x';
      [ticks,dateform] = bestscale(ax,window_start_time,window_end_time,dateform,dateChoice);
      if ~strcmp(plot_components(1:4),'    ')
         %
         % Plot general status data in window
         %
         plot_handles(window_index) = figure;
         orient(plot_handles(window_index),orientation);
         plot_number = 1;
         for component_index=1:4
            if plot_components(component_index) ~= ' '
               subplot(plot_count_1,1,plot_number),plot(time(window_start_index:time_end),squeeze(status(component_index,window_start_index:time_end)));
               if plot_number == 1
                  title('General Status');
               end
               %         axis tight;
               YY = axis;
               YY(1) = window_start_time;
               YY(2) = window_end_time;
               axis(YY);
               % Set axis tick labels
               labels = datestr(ticks,dateform);
               set(gca,[ax,'tick'],ticks,[ax,'ticklabel'],labels, ...
                    [ax,'lim'],[min(ticks) max(ticks)])
               date_strings = get(gca,'xticklabel');
               axis(YY);
               set(gca,'xticklabel',[]);
               ylabel('s');
               plot_number = plot_number + 1;
               if lower(plot_components(component_index)) == plot_components(component_index)
                  grid off;
               else
                  grid on;
               end
               switch component_index
                case 1
                  text(1,0.5,'\DeltaGPS','Units','normalized');
                case 2
                  text(1,0.5,'\DeltaPC','Units','normalized');
                case 3
                  text(1,0.5,'\Deltafile','Units','normalized');
                case 4
                  text(1,0.5,'subseconds','Units','normalized');
               end
            end
         end
         set(gca, 'xticklabel', date_strings);
         xlabel(datestr(time(window_start_index),0));
         window_index = window_index + 1;
      end
      %
      % See if we need to even print the second page
      %
      if ~strcmp(plot_components(5:8),'    ')
         %
         % Plot insensitive data in window
         %
         for component_index=1:4
            if plot_components(component_index+4) ~= ' '
               plot_handles(window_index) = figure;
               orient(plot_handles(window_index),orientation);
               plot_number = 1;
               for mill_index=1:6
                  subplot(6,1,mill_index),plot(time(window_start_index:time_end),squeeze(mill_data(mill_index,component_index,window_start_index:time_end)));
                  if plot_number == 1
                     switch component_index
                      case 1
                        title('Mill ID');
                      case 2
                        title('\Deltat');
                      case 3
                        title('Mill State');
                      case 4
                        title('Osc Freq');
                     end
                  end
                  %
                  %  Do the first one
                  %
                  YY = axis;
                  YY(1) = window_start_time;
                  YY(2) = window_end_time;
                  axis(YY);
                  % Set axis tick labels
                  labels = datestr(ticks,dateform);
                  set(gca,[ax,'tick'],ticks,[ax,'ticklabel'],labels, ...
                       [ax,'lim'],[min(ticks) max(ticks)])
                  date_strings = get(gca,'xticklabel');
                  axis(YY);
                  set(gca,'xticklabel',[]);
                  %
                  %  Now label
                  %
                  switch mill_index
                   case 1
                     ylabel('PD');
                   case 2
                     ylabel('PU');
                   case 3
                     ylabel('SD');
                   case 4
                     ylabel('SU');
                   case 5
                     ylabel('AD');
                   case 6
                     ylabel('AU');
                  end
                  plot_number = plot_number + 1;
                  if lower(plot_components(component_index+4)) == plot_components(component_index+4)
                     grid off;
                  else
                     grid on;
                  end
               end
               window_index = window_index + 1;
               set(gca, 'xticklabel', date_strings);
               xlabel(datestr(time(window_start_index),0));
            end
         end
      end
      window_start_index = time_end;
      window_start_time = window_end_time;
   end
