function [plot_handles] = plot_vector_fields_plus(scale_structure,field_vector,time,location_matrix,temporal_structure,gridded_structure)
%
%  plot_vector_fields_plus(scale_structure, field_vector, time, location_matrix, temporal_structure, gridded_structure)
%
%  This routine will plot lightning vectors on the xyz plots found in
%  routines such as plot_Altus_data along with gridded data (like AMPR or radar)
%
%  Inputs:
%     scale_structure = structure containing the scales of the various data.  Has at least these fields:
%        scale_E = 3 vector for each of the three plots (lat/lon, lat/alt, lon/alt). E value (kV/m) that 
%           will be equal to 0.1 of scale of the main plot. Note if only one value entered, all 3 plots 
%           will have same scale. Note that if the 'scale_E' element is missing, the vectors will autoscaled,
%           if it is 0, then vectors will not be displayed on xyz plot
%        v_skip = how often to put in vectors (i.e.,  skip = 1, do all points, skip = 10, do one in 10 points)
%        gridded_colormap = the (X,3) colormap to use for gridded data.  If this element is missing, the color
%           map will be hsv
%        gridded_data_limits = the [min max] limits of the gridded_data (for color determination)
%           Note, if this element is missing, the scale will be the maximum limits of the data
%        map_data = 6 vector of map limits (lat_min lat_max lon_min lon_max alt_min alt_max) in degrees & km
%           note that if the 'map_data' element is missing, the plot will autoscale
%     field_vector = (6,N) matrix of earth oriented field values (in V/m), Ew, En, Eu, Eq, Em, Q
%     time = (N) array of time values (in Matlab time) for the E an location data
%     location_matrix = (3,N) matrix of location data (lat, lon, alt)
%     temporal_structure = structure containing temporal values for the plot, including fields:
%        window_width = time width of individual plot windows in minutes
%           Note that if the window_width is 0, then the window width will be set to total_time
%        start_string = start time of first plot
%        stop_string = stop time of all plots
%           Note that if there is a stop_string, the program will use the time as
%           start/stop strings and ignore the total_time variable
%        total_time = total time of all windows in minutes
%     gridded_structure = (M) length structure of gridded data containing the following fields:
%        gridded_time = gridded data time
%        gridded_lat_lon_data = (3,NN) matrix of lat (1), lon (2), and data (3) at gridded_time (for lat/lon plot)
%        gridded_lat_alt_data = (3,NN) matrix of lat (1), alt (2), and data (3) at gridded_time (for lat/alt plot)
%        gridded_lon_alt_data = (3,NN) matrix of lon (1), alt (2), and data (3) at gridded_time (for lon/alt plot)
%           Note that if the whole structure or part of it is missing, the program will not plot that set of gridded
%           data
%

%
%  First check for aircraft
%
global AIRCRAFT WHICH_AIRCRAFT
%
%  Now see if they are defined
%
if isempty(AIRCRAFT) == 1
   warning('Need to load aircraft_flags for this to work');
   WHICH_AIRCRAFT = 0;
end
if isempty(WHICH_AIRCRAFT) == 1
   warning('Need to define you aircraft (in aircraft_flags) for this to work');
   WHICH_AIRCRAFT = 0;
end
%
%  Now set universal items
%
global g_time g_data_matrix window_start_index time_end plot_count plot_number plot_count_2 plot_number_2 window_start_time window_end_time g_plot_components date_strings dateform
g_time = time;
g_plot_components = [1 2 3 4 7 8 9];
plot_components = [1 2 3 4 7 8 9];
max_size = length(time);
plot_count = 7;
plot_names = ['En '; 'Ew ';'Eu ';'Eq ';'Mag';'???';'Lat';'Lon';'Alt'];
plot_units = ['V/m ';'V/m ';'V/m ';'V/m ';'V/m ';'????';'Degs';'Degs';'km  '];
%
%  Set values not entered by user
%
%  First, did the user input the scale_structure and temporal_structure
%
if ~isstruct(scale_structure)
   error('Need to define your scales in scale_structure before this will work');
   return;
end
if ~isstruct(temporal_structure)
   error('Need to define your time data in temporal_structure before this will work');
   return;
end
if ~isfield(temporal_structure,'start_string')
   first_time = time(1)
   start_string = datestr(time(1));
else
   start_string = temporal_structure.start_string;
   if ischar(start_string) == 0
      if first_time < 1
         first_time = 1;
      end
      first_time = time(start_string);
   else
      if min(size(start_string)) == 1
         first_time = datenum(start_string);
      else
         first_time = datenum(start_string(1,:));
         delta_seconds = (datenum(start_string(2,:)) - datenum(start_string(1,:)))*1440;
      end
   end
end
if ~isfield(temporal_structure,'delta_seconds')
   last_time = time(length(time))
   delta_seconds = 0;
else
   delta_seconds = temporal_structure.delta_seconds*60;
   if delta_seconds == 0
      last_time = time(length(time));
   else
      if ischar(start_string) == 0
         last_time = time(delta_seconds+start_string);
      else
         last_time = first_time + delta_seconds*1.1574e-5;
      end
   end
end
if ~isfield(temporal_structure,'window_width')
   window_width = 60*60;
else
   window_width = temporal_structure.window_width*60;
   if window_width == 0
      window_width = delta_seconds;
   else
      if ischar(start_string) == 0
         window_width = (time(window_width) - time(1))*86400;
      end
   end
end
if isfield(temporal_structure,'stop_string')
   stop_string = temporal_structure.stop_string;
   delta_seconds = (datenum(stop_string) - datenum(start_string))*1440*60;
   last_time = datenum(stop_string);
   window_width = delta_seconds;
end
if ~isfield(scale_structure,'v_skip')
   v_skip = 0;
else
   v_skip = scale_structure.v_skip;
end
%
%  See if the user wants some sort of gridded data plotted also
%
if exist('gridded_structure')
   gridded_time_length = length(gridded_structure);
   gridded_time = [gridded_structure.gridded_time];
else
   gridded_time_length = 0;
end
if ~exist('orientation','var')
   orientation = 'tall';
end
latitude = location_matrix(1,:);
longitude = location_matrix(2,:);
altitude = location_matrix(3,:);
%
%  See if the user wants different scales in the three plots
%
if isfield(scale_structure,'scale_E')
   if max(size(scale_structure.scale_E)) ~= 3
      scale_E(1) = scale_structure.scale_E(1);
      scale_E(2) = scale_structure.scale_E(1);
      scale_E(3) = scale_structure.scale_E(1);
   else
      scale_E(1) = scale_structure.scale_E(1);
      scale_E(2) = scale_structure.scale_E(2);
      scale_E(3) = scale_structure.scale_E(3);
   end
else
   scale_E(1) = 0;
   scale_E(2) = 0;
   scale_E(3) = 0;
end
%
%  First "fix" any Lat/Lon/Alt errors in aircraft data
%
if all(altitude) == 0
   for i=1:length(altitude)
      if altitude(i) == 0
         altitude(i) = NaN;
      end
   end
end
if all(latitude) == 0
   for i=1:length(latitude)
      if latitude(i) == 0
         latitude(i) = NaN;
      end
   end
end
if all(longitude) == 0
   for i=1:length(longitude)
      if longitude(i) == 0
         longitude(i) = NaN;
      end
   end
end
g_data_matrix = [field_vector; latitude; longitude; altitude];
%
%   Determine where to start & end the plots
%
i=1;
while time(i) < first_time
   i = i + 1;
   if i > max_size
      error('Fell off end of A/C data before hitting first time');
   end
end
first_pos_index = i
i=first_pos_index;
while time(i) < last_time
   i = i + 1;
   if i > max_size
      i = max_size;
      break;
   end
end
last_pos_index = i
window_start_time = first_time;
window_start_index = first_pos_index;
window_index = 0;
window_count = 1;
while window_start_time < last_time
   %
   %   Plot aircraft data vs. time in window
   %
   time_end = window_start_index
   window_end_time = window_start_time + (window_width*1.157407e-5);
   %
   %   Make sure we don't plot any small windows
   %
   if last_time - window_end_time < 0.1*window_width*1.157407e-5
      window_end_time = last_time;
   end
   while time(time_end) <= window_end_time
      time_end = time_end + 1;
      if time_end >= max_size
         time_end = max_size;
         break;
      end
   end
   %
   %  Also setup gridded data, if wanted
   %
   if gridded_time_length > 0
      gridded_index = 1;
      while gridded_time(gridded_index) < window_start_time
         gridded_index = gridded_index + 1;
         if gridded_index > gridded_time_length
            gridded_index = gridded_time_length;
            break;
         end
      end
      gridded_start_index = gridded_index
      datestr(gridded_time(gridded_start_index))
      while gridded_time(gridded_index) < window_end_time
         gridded_index = gridded_index + 1;
         if gridded_index > gridded_time_length
            gridded_index = gridded_time_length;
            break;
         end
      end
      gridded_end_index = gridded_index
      datestr(gridded_time(gridded_end_index))
   end
   time_end = time_end - 1;
   if time_end > window_start_index
      %
      %  Plot the data
      %
      total_plots_done = 0;
      for plot_counter=1:window_count
         window_index = window_index + 1;
         plot_handles(window_index) = figure;
         orient(plot_handles(window_index), orientation);
         plot_number = 1;
         window_start_index
         time_end
         if WHICH_AIRCRAFT ~= 0
%            the_title = AIRCRAFT(WHICH_AIRCRAFT).name;
            the_title = strcat(inputname(1),',',AIRCRAFT(WHICH_AIRCRAFT).name);
         else
            the_title = strcat('Unknown Aircraft,', inputname(1));
         end
         xlabel(sprintf('start_index;%d, end_index:%d',window_start_index,time_end));
         plot_count;
         for plot_index=1:plot_count
            the_plot_index = plot_components(plot_index + total_plots_done);
            subsubplot(plot_index,plot_count,the_plot_index,plot_names(the_plot_index,:),plot_units(the_plot_index,:),g_data_matrix, the_title);
            if plot_index == 1
               xlabel(sprintf('start index;%d, end index:%d',window_start_index,time_end));
            end
         end
         set(gca, 'xticklabel', date_strings);
         time_ticks = get(gca, 'xtick');
         xlabel(datestr(time(window_start_index),0));
         total_plots_done = total_plots_done + plot_count;
      end
      %
      %   Now plot aircraft location data
      %
      window_index = window_index + 1;
      plot_handles(window_index) = figure;
      axes('position',[0.1 0.1 0.7 0.7]);
      %
      %  Load the world coastline map
      %
      load machcoast llat llong;
      if gridded_time_length > 0
         %
         %  Plot gridded data in lat/lon window
         %
         if isfield(gridded_structure,'gridded_lat_lon_data')
            %
            %  Set color scale limits
            %
            if isfield(scale_structure,'gridded_data_limits')
               caxis(scale_structure.gridded_data_limits);
            else
               caxis('auto');
            end
            %
            %  Reformat the data to fit the routine
            %
            first_dim = length([gridded_start_index:gridded_end_index]);
            second_dim = length([gridded_structure(gridded_start_index).gridded_lat_lon_data(2,:)]);
            lon = NaN*zeros(first_dim,second_dim);
            lat = NaN*zeros(first_dim,second_dim);
            dat = NaN*zeros(first_dim,second_dim);
            for pcolor_index = gridded_start_index:gridded_end_index
               data_index = pcolor_index-gridded_start_index+1;
               lon(data_index,:) = [gridded_structure(pcolor_index).gridded_lat_lon_data(2,:)];
               lat(data_index,:) = [gridded_structure(pcolor_index).gridded_lat_lon_data(1,:)];
               dat(data_index,:) = [gridded_structure(pcolor_index).gridded_lat_lon_data(3,:)];
            end
            pcolor(lon,lat,dat);
            hold on;
            if isfield(scale_structure,'gridded_colormap')
               colormap(squeeze(scale_structure.gridded_colormap));
            else
               colormap(hsv);
            end
            shading interp;
            if isfield(scale_structure,'gridded_alphamap')
               alpha('color');
               alphamap(scale_structure.gridded_alphamap');
            end
            if isfield(scale_structure,'gridded_data_limits')
               caxis(scale_structure.gridded_data_limits);
            else
               caxis('auto');
            end
         end
      end
      %
      %  Plot aircraft location data
      %
      plot(longitude(window_start_index:time_end),latitude(window_start_index:time_end));
      hold on;
      %
      %  Put start/end of plot on window
      %
      text(longitude(window_start_index),latitude(window_start_index),'s','HorizontalAlignment','Center');
      text(longitude(time_end),latitude(time_end),'e','HorizontalAlignment','Center');
      %
      %  See if the user wanted a fixed scale for the plot
      %
      if isfield(scale_structure,'map_data')
         the_axis(1) = scale_structure.map_data(3);
         the_axis(2) = scale_structure.map_data(4);
         the_axis(3) = scale_structure.map_data(1);
         the_axis(4) = scale_structure.map_data(2);
         axis(the_axis);
         V = axis;
      else
         %
         %  Make the window a bit wider than the data
         %
         V = axis;
         delta_lon = 0.1*(V(2)-V(1));
         if delta_lon < 0.025
            delta_lon = 0.025;
         end
         delta_lat = 0.1*(V(4)-V(3));
         if delta_lat < 0.025
            delta_lat = 0.025;
         end
         V(1) = V(1) - delta_lon;
         V(2) = V(2) + delta_lon;
         V(3) = V(3) - delta_lat;
         V(4) = V(4) + delta_lat;
         if V(1) > V(2)
            Vx = V(1);
            V(1) = V(2);
            V(2) = Vx;
         end
         if V(3) > V(4)
            Vx = V(3);
            V(3) = V(4);
            V(4) = Vx;
         end
      end
      %
      %  Plot the world
      %
      plot(llong,llat,'g');
      %
      %  Now we need to undistort the lat/lon plot
      %  so that 1 km north or south = 1 km east or west
      %
      globe_ratio = cos(pi*(V(3)+V(4))/360);
      current_ratio = (V(4)-V(3))/(V(2)-V(1));
      if current_ratio > globe_ratio
         %
         %  Increase the Lon dimension to undistort the plot
         %
         new_delta_lon = (V(2)-V(1))*current_ratio/globe_ratio;
         delta_lon = (new_delta_lon - V(2) + V(1))*0.5;
         V(1) = V(1) - delta_lon;
         V(2) = V(2) + delta_lon;
      else
         %
         %  Increase the Lat dimension to undistort the plot
         %
         new_delta_lat = (V(4)-V(3))*globe_ratio/current_ratio;
         delta_lat = (new_delta_lat - V(4) + V(3))*0.5;
         V(3) = V(3) - delta_lat;
         V(4) = V(4) + delta_lat;
      end         
      axis(V);
      ylabel('Latitude ');
      xlabel('Longitude ');
      box on;
      V = axis;
      grid on;
      %
      %  Put time ticks or field vectors on window
      %
      if v_skip ~= 0 | scale_E(1) ~= 0
         v_values = window_start_index:v_skip:time_end;
         %
         %  scale the vector
         %
         the_scale = axis;
         delta_x = 1000*scale_E(1)/(0.1*(the_scale(2)-the_scale(1)));
         delta_y = 1000*scale_E(1)/(0.1*(the_scale(4)-the_scale(3)));
         quiver(longitude(v_values),latitude(v_values), -field_vector(2,v_values)/delta_x,field_vector(1,v_values)/delta_y,0);
         %
         %  Put scale on plot
         %
         start_x = [the_scale(2)-0.02*(the_scale(2)-the_scale(1)); the_scale(2)-0.02*(the_scale(2)-the_scale(1))];
         start_y = [the_scale(3)+0.02*(the_scale(4)-the_scale(3)); the_scale(3)+0.02*(the_scale(4)-the_scale(3))];
         end_x = [0; -1000*scale_E(1)/delta_x];
         end_y = [1000*scale_E(1)/delta_y; 0];
         %
         %  If you want the field scale on the plots, uncomment these 2 lines
         %
         quiver(start_x,start_y,end_x,end_y,0);
         text(start_x,start_y,strcat(num2str(scale_E(1)),' kV/m'),'FontSize',7,'Rotation',0,'VerticalAlignment','Bottom','HorizontalAlignment','Right');
      end
      for tick_index=2:length(time_ticks)-1
         [alphaa,beta] = min(abs(g_time(window_start_index:time_end) - time_ticks(tick_index)));
         text(longitude(window_start_index+beta-1),latitude(window_start_index+beta-1),datestr(time_ticks(tick_index),15),'HorizontalAlignment','Center','FontSize',6);
      end
      if gridded_time_length > 0
         if isfield(gridded_structure,'gridded_lat_lon_data')
            %
            %  Put on the scale of the gridded data
            %
            cb = colorbar('horiz');
            %
            %  Since the colorbar rescales the data plot, put it back
            %
            set(gca,'position',[0.1 0.1 0.7 0.7]);
            %
            %  Now move the colorbar to the top left of the gridded plot
            %
            set(cb,'position',[0.1 0.75 0.5 0.05]);
         end
      end
      %
      %  Do the height/lat plot
      %
      axes('position',[0.8 0.1 0.2 0.7]);
      if gridded_time_length > 0
         %
         %  Plot gridded data in lat/alt window
         %
         if isfield(gridded_structure,'gridded_lat_alt_data')
            %
            %  Set color scale limits
            %
            if isfield(scale_structure,'gridded_data_limits')
               caxis(scale_structure.gridded_data_limits);
            else
               caxis('auto');
            end
            %
            %  Reformat the data to fit the routine
            %
            first_dim = length([gridded_start_index:gridded_end_index]);
            second_dim = length([gridded_structure(gridded_start_index).gridded_lat_alt_data(2,:)]);
            alt = NaN*zeros(first_dim,second_dim);
            lat = NaN*zeros(first_dim,second_dim);
            dat = NaN*zeros(first_dim,second_dim);
            for pcolor_index = gridded_start_index:gridded_end_index
               data_index = pcolor_index-gridded_start_index+1;
               alt(data_index,:) = [gridded_structure(pcolor_index).gridded_lat_alt_data(2,:)];
               lat(data_index,:) = [gridded_structure(pcolor_index).gridded_lat_alt_data(1,:)];
               dat(data_index,:) = [gridded_structure(pcolor_index).gridded_lat_alt_data(3,:)];
            end
            pcolor(alt,lat,dat);
            hold on;
            if isfield(scale_structure,'gridded_colormap')
               colormap(squeeze(scale_structure.gridded_colormap));
            else
               colormap(hsv);
            end
            shading interp;
            if isfield(scale_structure,'gridded_data_limits')
               caxis(scale_structure.gridded_data_limits);
            else
               caxis('auto');
            end
         end
      end
      %
      %  Plot kilometers
      %
      plot(0.001*altitude(window_start_index:time_end),latitude(window_start_index:time_end));
      text(0.001*altitude(window_start_index),latitude(window_start_index),'s','HorizontalAlignment','Center');
      text(0.001*altitude(time_end),latitude(time_end),'e','HorizontalAlignment','Center');
      hold on;
      axis tight;
      box on;
      %
      %  See if the user wanted a fixed map scale
      %
      if isfield(scale_structure,'map_data')
         the_axis(1) = scale_structure.map_data(5);
         the_axis(2) = scale_structure.map_data(6);
         the_axis(3) = scale_structure.map_data(1);
         the_axis(4) = scale_structure.map_data(2);
         axis(the_axis);
         V2 = axis;
      else
         V2 = axis;
         %
         %  Note, if you need to expand the scale to fit the barbs, put in 0.1 - 0.3 for the
         %  'a_scale' below
         %
         a_scale = 0.3
         V2(1) = V2(1) - a_scale*(V2(2)-V2(1));
         V2(2) = V2(2) + a_scale*(V2(2)-V2(1));
      end
      axis([V2(1) V2(2) V(3) V(4)]);
      xlabel('Altitude (km)');
      set(gca,'yticklabel',[]);
      %
      %  Put time ticks or vectors on window
      %
      if v_skip ~= 0 & scale_E(2) ~= 0
         the_scale = axis;
         v_values = window_start_index:v_skip:time_end;
         delta_y = 1000*scale_E(2)/(0.1*(the_scale(4)-the_scale(3)));
         delta_z = 1000*scale_E(2)/((0.7/0.2)*0.1*(the_scale(2)-the_scale(1)));
         quiver(0.001*altitude(v_values),latitude(v_values), field_vector(3,v_values)/delta_z,field_vector(1,v_values)/delta_y,0);
         %
         %  Put scale on plot
         %
         start_x = [the_scale(2)-0.07*(the_scale(2)-the_scale(1)); the_scale(2)-0.07*(the_scale(2)-the_scale(1))];
         start_y = [the_scale(3)+0.02*(the_scale(4)-the_scale(3)); the_scale(3)+0.02*(the_scale(4)-the_scale(3))];
         end_x = [0; -1000*scale_E(2)/delta_z];
         end_y = [1000*scale_E(2)/delta_y; 0];
         %
         %  If you want the field scale on the plots, uncomment these 2 lines
         %
         quiver(start_x,start_y,end_x,end_y,0);
         text(start_x,start_y,strcat(num2str(scale_E(2)),' kV/m'),'FontSize',7,'Rotation',0,'VerticalAlignment','Bottom','HorizontalAlignment','Right');
      end
      for tick_index=2:length(time_ticks)-1
         [alphaa,beta] = min(abs(g_time(window_start_index:time_end) - time_ticks(tick_index)));
         text(0.001*altitude(window_start_index+beta-1),latitude(window_start_index+beta-1),'+','HorizontalAlignment','Center');
      end
      grid on;
      %
      %  Now Do lon/alt plot
      %
      axes('position',[0.1 0.8 0.7 0.2]);
      if gridded_time_length > 0
         %
         %  Plot gridded data in lon/alt window
         %
         if isfield(gridded_structure,'gridded_lon_alt_data')
            %
            %  Set color scale limits
            %
            if isfield(scale_structure,'gridded_data_limits')
               caxis(scale_structure.gridded_data_limits);
            else
               caxis('auto');
            end
            %
            %  Reformat the data to fit the routine
            %
            first_dim = length([gridded_start_index:gridded_end_index]);
            second_dim = length([gridded_structure(gridded_start_index).gridded_lon_alt_data(2,:)]);
            alt = NaN*zeros(first_dim,second_dim);
            lon = NaN*zeros(first_dim,second_dim);
            dat = NaN*zeros(first_dim,second_dim);
            for pcolor_index = gridded_start_index:gridded_end_index
               data_index = pcolor_index-gridded_start_index+1;
               alt(data_index,:) = [gridded_structure(pcolor_index).gridded_lon_alt_data(2,:)];
               lon(data_index,:) = [gridded_structure(pcolor_index).gridded_lon_alt_data(1,:)];
               dat(data_index,:) = [gridded_structure(pcolor_index).gridded_lon_alt_data(3,:)];
            end
            pcolor(lon,alt,dat);
            hold on;
            if isfield(scale_structure,'gridded_colormap')
               colormap(squeeze(scale_structure.gridded_colormap));
            else
               colormap(hsv);
            end
            shading interp;
            if isfield(scale_structure,'gridded_data_limits')
               caxis(scale_structure.gridded_data_limits);
            else
               caxis('auto');
            end
         end
      end
      plot(longitude(window_start_index:time_end),0.001*altitude(window_start_index:time_end));
      text(longitude(window_start_index),0.001*altitude(window_start_index),'s','HorizontalAlignment','Center');
      text(longitude(time_end),0.001*altitude(time_end),'e','HorizontalAlignment','Center');
      hold on;
      axis tight;
      %
      %  See if the user wanted a fixed map scale
      %
      if isfield(scale_structure,'map_data')
         the_axis(1) = scale_structure.map_data(3);
         the_axis(2) = scale_structure.map_data(4);
         the_axis(3) = scale_structure.map_data(5);
         the_axis(4) = scale_structure.map_data(6);
         axis(the_axis);
         V3 = axis;
      else
         V3 = axis;
         %
         %  Note, if you need to expand the scale to fit the barbs, put in 0.1 - 0.3 for the
         %  a_scale below
         %
         a_scale = 0.3;
         V3(3) = V3(3) - a_scale*(V3(4)-V3(3));
         V3(4) = V3(4) + a_scale*(V3(4)-V3(3));
      end
      axis([V(1) V(2) V3(3) V3(4)]);
      box on;
      ylabel('Altitude (km)');
      %
      %  Put time ticks or vectors on window
      %
      if v_skip ~= 0
         the_scale = axis
         v_values = window_start_index:v_skip:time_end;
         delta_x = 1000*scale_E(3)/(0.1*(the_scale(2)-the_scale(1)));
         delta_z = 1000*scale_E(3)/((0.7/0.2)*0.1*(the_scale(4)-the_scale(3)));
         quiver(longitude(v_values),0.001*altitude(v_values), -field_vector(2,v_values)/delta_x, field_vector(3,v_values)/delta_z,0);
         %
         %  Put scale on plot
         %
         start_x = [the_scale(2)-0.02*(the_scale(2)-the_scale(1)); the_scale(2)-0.02*(the_scale(2)-the_scale(1))];
         start_y = [the_scale(3)+0.07*(the_scale(4)-the_scale(3)); the_scale(3)+0.07*(the_scale(4)-the_scale(3))];
         end_x = [0; -1000*scale_E(3)/delta_x];
         end_y = [1000*scale_E(3)/delta_z; 0];
         %
         %  If you want the field scale on the plots, uncomment these 2 lines
         %
         quiver(start_x,start_y,end_x,end_y,0);
         text(start_x,start_y,strcat(num2str(scale_E(3)),' kV/m'),'FontSize',7,'Rotation',0,'VerticalAlignment','Bottom','HorizontalAlignment','Right');
      end
      for tick_index=2:length(time_ticks)-1
         [alphaa,beta] = min(abs(g_time(window_start_index:time_end) - time_ticks(tick_index)));
         text(longitude(window_start_index+beta-1),0.001*altitude(window_start_index+beta-1),'+','HorizontalAlignment','Center');
      end
      set(gca,'xticklabel',[]);
      text(V(2),V3(3)+(V3(4)-V3(3))*0.1667, datestr(time(time_end),13));
      text(V(2),V3(3)+(V3(4)-V3(3))*0.333, datestr(time(time_end),1));
      text(V(2),V3(3)+(V3(4)-V3(3))*0.5,sprintf('v_skip:%d',v_skip),'Interpreter','none');
      text(V(2),V3(4)-(V3(4)-V3(3))*0.1667, datestr(time(window_start_index),1));
      text(V(2),V3(4)-(V3(4)-V3(3))*0.333, datestr(time(window_start_index),13));
      grid on;
      %
      %  Now we need to make sure the figure is square on the page (for
      %  printing)
      %
      set(gcf,'PaperPosition',[0.2500    1.5000    8.0000    8.0000]);
   end
   %
   %   Prepare for next group
   %
   window_start_index = time_end + 1;
   window_start_time = window_end_time;
end

function subsubplot(the_index, total_components,the_component,text_label,y_label,data_matrix,the_title)
global g_time g_data_matrix window_start_index time_end plot_count plot_number plot_count_2 plot_number_2 window_start_time window_end_time g_plot_components date_strings dateform
%
if the_component ==9
   subplot(total_components,1,the_index),plot(g_time(window_start_index:time_end),0.001*data_matrix(the_component,window_start_index:time_end));
else
   subplot(total_components,1,the_index),plot(g_time(window_start_index:time_end),data_matrix(the_component,window_start_index:time_end));
end
if the_index == 1
   title(the_title,'Interpreter','none');
end
axis tight;
YY = axis;
YY(1) = window_start_time;
YY(2) = window_end_time;
axis(YY);
%datetick('x',dateform);
dateChoice = 'yqmwdHMS';
ax = 'x';
[ticks,dateform] = bestscale(ax,window_start_time,window_end_time,dateform,dateChoice);
%ticks = bestscale(ax,window_start_time,window_end_time,dateform,dateChoice);
% Set axis tick labels
labels = datestr(ticks,dateform);
set(gca,[ax,'tick'],ticks,[ax,'ticklabel'],labels, ...
        [ax,'lim'],[min(ticks) max(ticks)])
date_strings = get(gca,'xticklabel');
axis(YY);
set(gca,'xticklabel',[]);
ylabel(y_label);
text(1.01,0.95,text_label,'Units','normalized','FontSize',8,'Rotation',-90);
plot_number = plot_number + 1;
grid on;
return

