function [efm_block] = read_efm_block(fid, efm_block);
%        [ efm_block ] = read_efm_block(fid, efm_block);
%
% Reads one efm block from the file fid and
% writes it to the structure efm_block.
%
% efm structure:
%  .version
%  .ProcessPriorityClass(ignored)
%  .CommandThreadPriority(ignored)
%  .AcquisitionThreadPriority(ignored)
%  .WndProcEvent[52](ignored)
%  .filesequence(ignored)
%  .recordnumber(ignored)
%  .archivestatus(ignored)
%  .pcUTC (PC estimate of the UTC time)
%     .tm_sec
%     .tm_min
%     .tm_hour
%     .tm_mday
%     .tm_mon
%     .tm_year
%     .tm_wday
%     .tm_yday
%     .tm_isdst
%  .GPSTimerActive
%  .GPSfailed
%  .MissingInterrupts(ignored)
%  .deltat(ignored)
%  .GPSIOStatus
%  .majtime
%  .mintime
%  .lockmajtime
%  .LLAgpspkt[20]
%  .VELgpspkt[20]
%  .GPSTime
%     .tm_sec
%     .tm_min
%     .tm_hour
%     .tm_mday
%     .tm_mon
%     .tm_year
%     .tm_wday
%     .tm_yday
%     .tm_isdst
%  .StartHighResPerfCounter(ignored)
%  .PerformanceFrequency(ignored)
%  .HighResPerfCounter(ignored)
%  .CPUtime
%  .CMDcputime(ignored)
%  .RCVDcputime(ignored)
%  .DataAcqtime(ignored)
%  .stinger[28](ignored)
%  .PortStatus[168](ignored)
%  .efmrecord[6]
%     .header[12]
%     .sensitive[50]
%     .insensitive[50]
%     .crc
%  .timeGPS
%  .timePC
%  .datetime
%  .subseconds
%
   
   
%
% Start the reading process (we will skip a lot of junk in the block)
% (We will assume the structure has already been set up)
%
   [efm_block.version, count] = fread(fid, 1, 'uint32');
   %
   % Check if okay
   %
   if efm_block.version ~= 808594993  %  This is for ABFM
%   if efm_block.version ~= 115278090   % ER-2 ?
      efm_block.version = 0;
      return;
   end
   %
   % Now read the first block of junk
   %
   junk1 = fread(fid, 76, 'int8');
   %
   % Read PC time
   %
   [efm_block.pcUTC.tm_sec, count] = fread(fid, 1, 'int32');
   [efm_block.pcUTC.tm_min, count] = fread(fid, 1, 'int32');
   [efm_block.pcUTC.tm_hour, count] = fread(fid, 1, 'int32');
   [efm_block.pcUTC.tm_mday, count] = fread(fid, 1, 'int32');
   [efm_block.pcUTC.tm_mon, count] = fread(fid, 1, 'int32');
   [efm_block.pcUTC.tm_year, count] = fread(fid, 1, 'int32');
   [efm_block.pcUTC.tm_wday, count] = fread(fid, 1, 'int32');
   [efm_block.pcUTC.tm_yday, count] = fread(fid, 1, 'int32');
   [efm_block.pcUTC.tm_isdst, count] = fread(fid, 1, 'int32');
   %
   % Read GPS status
   %
   [efm_block.GPSTimerActive, count] = fread(fid, 1, 'int32');
   [efm_block.GPSfailed, count] = fread(fid, 1, 'int32');
   %
   % Now read the second block of junk
   %
   junk2 = fread(fid, 8, 'int8');
   %
   % Read GPS status & times in int format
   %
   [efm_block.GPSIOStatus, count] = fread(fid, 1, 'int32');
   [efm_block.majtime, count] = fread(fid, 1, 'int32');
   [efm_block.mintime, count] = fread(fid, 1, 'int32');
   [efm_block.lockmajtime, count] = fread(fid, 1, 'int32');
   %
   % Read gps stuff (char)
   %
   [efm_block.LLAgpspkt, count] = fread(fid, 20, 'uchar');
   [efm_block.VELgpspkt, count] = fread(fid, 20, 'uchar');
   %
   % Read system time
   %
   [efm_block.GPSTime.tm_sec, count] = fread(fid, 1, 'int32');
   [efm_block.GPSTime.tm_min, count] = fread(fid, 1, 'int32');
   [efm_block.GPSTime.tm_hour, count] = fread(fid, 1, 'int32');
   [efm_block.GPSTime.tm_mday, count] = fread(fid, 1, 'int32');
   [efm_block.GPSTime.tm_mon, count] = fread(fid, 1, 'int32');
   [efm_block.GPSTime.tm_year, count] = fread(fid, 1, 'int32');
   [efm_block.GPSTime.tm_wday, count] = fread(fid, 1, 'int32');
   [efm_block.GPSTime.tm_yday, count] = fread(fid, 1, 'int32');
   [efm_block.GPSTime.tm_isdst, count] = fread(fid, 1, 'int32');
   %
   % Note that for now, we are going read but ignore the subseconds because they
   % seem to drift around a lot and I am not sure why
   %
   efm_block.subseconds = 0.000001*bitand(efm_block.mintime, 1048575);
   %
   % Convert the time to a number
   %
   efm_block.timeGPS = datenum(efm_block.GPSTime.tm_year+1900, efm_block.GPSTime.tm_mon+1, efm_block.GPSTime.tm_mday,  efm_block.GPSTime.tm_hour, efm_block.GPSTime.tm_min, efm_block.GPSTime.tm_sec);
   efm_block.timePC = datenum(efm_block.pcUTC.tm_year+1900, efm_block.pcUTC.tm_mon+1, efm_block.pcUTC.tm_mday,  efm_block.pcUTC.tm_hour, efm_block.pcUTC.tm_min, efm_block.pcUTC.tm_sec);
   %
   % Now read the third block of junk
   %
   junk3 = fread(fid, 24, 'int8');
   %
   % Read CPU int time
   %
   [efm_block.CPUtime, count] = fread(fid, 1, 'int32');
   %
   % Now read the fourth block of junk
   %
   junk4 = fread(fid, 208, 'int8');
   %
   % Now get to the real stuff, the FM data
   %
   for i=1:6
      [efm_block.efmrecord(i).header, count] = fread(fid, 12, 'uchar');
      [efm_block.efmrecord(i).sensitive, count] = fread(fid, 50, 'int16');
      if count ~= 50
         efm_block.version = 0;
         'blank data'
         return;
      end
      [efm_block.efmrecord(i).insensitive, count] = fread(fid, 50, 'int16');
      if count ~= 50
         efm_block.version = 0;
         return;
      end
      [efm_block.efmrecord(i).crc, count] = fread(fid, 1, 'int16');
   end
   %
   % That should be all!
   %
   return;
