function [efm_data_matrix, time_array, N, slow_data_structure, raw_data] = read_old_abfm_data(variable_name_structure, directory, file_name, pps);
%
%  [efm_data_matrix, time_array, N, slow_data_structure, raw_data] = read_old_abfm_data(variable_name_structure, directory, file_name, pps);
%
%  This routine will read the old ABFM data files and produce three arrays, one for the fast data, one
%  for the slow data, and one for the raw data.
%
%  Input:
%     variable_name_structure = the variable list (and properties) for the dataset being loaded
%        (note: this should be the appropriate summer91, winter92,etc. list)
%        we are only going to pull out time, raw E, calibrated E, aircraft position, and
%        aircraft orientation for now, i.e.:
%           slow_list = [41 42 43 58 59 60 68 69 70 71 73 74 75 76];)
%     directory = string of the directory (with the last \) of the data file
%     file_name = the file that has the old ABFM data
%     pps = points per second of data you want
%        (note: the output data will have ALL variables at the rate of pps, not just the
%        fast ones)
%
%  Output:
%     efm_data_matrix = the 4 x 5 x N (depending on the skip & seconds values) array of efm data
%     time = time array for the points (in dateform format)
%     slow_data_structure = the structure of the slow data at nominal 2 Hz rate 
%     raw_data = the raw data in int16 48xn form (optional)
%     

%
%  Setup which variables to get
%  Note that the + 2 is so the VarTable array matches with the data
%
time_list = [3 4 5 6 7] + 2;
fm_gain_list = [9 10 11 12 13; 15 16 17 18 19; 21 22 23 24 25; 27 28 29 30 31];
slow_list = [41 42 43 58 59 60 68 69 70 71 73 74 75 76 183];
C4 = 5.109158E-10;
C3 = -5.856328E-6; 
C2 = 2.566773E-2;
C1 = -60.44023;
C0 = 74894.69;
%
%  First open file and raw read data
%
fid = fopen(strcat(directory,file_name),'r');
if fid < 0
   error(sprintf('Unable to open file:%s\n',strcat(directory,file_name)));
end
raw_data = fread(fid,[48,inf],'int16=>int16');
disp('Read raw data');
fclose all;
%
%  first construct the slow structure based on the names
%
%for i=1:length(slow_list)
%   stringer = sprintf('slow_data_structure.%s = 0;',char(variable_name_structure.name(slow_list(i)+1,:)));
%   eval(stringer);
%end
%eval('slow_data_structure.time = 0;');
%disp('Contructed slow structure');
%
%  Now parse into fast data
%
full_efm_data_matrix = raw_data(fm_gain_list+2,:);
full_efm_data_matrix = double(reshape(full_efm_data_matrix,4,5,length(raw_data)));
for gain=1:4
   for mill=1:5
      full_efm_data_matrix(gain,mill,:) = (full_efm_data_matrix(gain,mill,:) - variable_name_structure.offset(fm_gain_list(gain,mill)+1))*variable_name_structure.scale(fm_gain_list(gain,mill)+1);
   end
end
disp('mills now voltage');
time_matrix = double(raw_data(time_list,:));
time_matrix = from_bcd(time_matrix);
time_array(length(raw_data)) = 0;
%
%  Decode the flight infomration from the file name
%
flight_data = sscanf(file_name,' AC%3d%3d.%2d%c')
day_of_year = flight_data(1);
flight = flight_data(2);
year = flight_data(3);
the_julian = year*1000 + day_of_year;
date_string = julian(the_julian)
base_date_num = datenum(date_string);
[Y,M,D,H,MI,S] = datevec(base_date_num);
for index=1:length(raw_data)
   time_array(index) = datenum(Y,M,D,time_matrix(2,index)+(time_matrix(1,index)-day_of_year)*24,time_matrix(3,index),time_matrix(4,index)+time_matrix(5,index)*0.001);
end
disp('Time converted');
%
%  Now fix any bad times and data
%
index = 1;
bad_count = 0;
while index < length(time_array)
   if (time_array(index) > base_date_num + 2) || (time_array(index) < base_date_num - 5)
      disp(sprintf('Bad Time:%s, index:%d\n',datestr(time_array(index)),index));
      bad_count = bad_count + 1;
      bad_ones(bad_count) = index;
   end
   index = index + 1;
end
disp('Marked bad times');
if bad_count > 0
   time_array(bad_ones) = [];
   full_efm_data_matrix(:,:,bad_ones) = [];
end
disp('Time fixed');
%
%  Now resample data
%
d = gcd(pps,50);
p = pps/d;
q = 50/d;
time_array = resample(time_array,p,q,0);
for gain=1:4
   for mill=1:5
      efm_data_matrix(gain,mill,:) = resample(squeeze(full_efm_data_matrix(gain,mill,:)),p,q,0);
   end
end
N = length(efm_data_matrix);
disp('Resampled efm data');
%
%  Now convert the slow data
%
slow_index = 1;
fast_index = 1;
   %
   %  First get to the start of a frame 
   %  (we hope we find one before the end of the data)
   %
while raw_data(3,fast_index) ~= 0
   fast_index = fast_index + 1;
   if fast_index > length(raw_data)
      break;
   end
end
while fast_index < length(raw_data)
   sub_index = raw_data(3,fast_index);
   %
   %  Build time for slow data
   %
   slow_time = from_bcd(double(raw_data(time_list,fast_index)));
   slow_data_structure(slow_index).time = datenum(Y,M,D,slow_time(2)+(slow_time(1)-day_of_year)*24,slow_time(3),slow_time(4)+slow_time(5)*0.001);
   %
   %  Hard wire the variables we need (roll, pitch, heading, Lat, Lon, Altitude)
   %
   slow_data_structure(slow_index).pitch = (double(raw_data(38,fast_index+1)) - variable_name_structure.offset(41+1))*variable_name_structure.scale(41+1);
   slow_data_structure(slow_index).roll = (double(raw_data(39,fast_index+1)) - variable_name_structure.offset(42+1))*variable_name_structure.scale(42+1);
   slow_data_structure(slow_index).mheading = (double(raw_data(35,fast_index+2)) - variable_name_structure.offset(43+1))*variable_name_structure.scale(43+1);
   slow_data_structure(slow_index).lat = double(raw_data(35,fast_index+5)) + (double(raw_data(36,fast_index+5)) + double(raw_data(37,fast_index+5))*0.01)*0.0167;
   slow_data_structure(slow_index).lon = double(raw_data(36,fast_index+7)) + (double(raw_data(37,fast_index+7)) + double(raw_data(38,fast_index+7))*0.01)*0.0167;
   %
   %  Now determine pressure altitude from pressure
   %
   precount = double(raw_data(35,fast_index));
   %
   %  Calc the various powers of the counts
   %
	count2 = precount*precount;
	count3 = count2*precount;
	count4 = count3*precount;
   %
   %  Determine the altitude in kilofeet
   %
	height = C4*count4 + C3*count3 + C2*count2 + C1*precount + C0;
	height = height*.001;
	slow_data_structure(slow_index).palt = height;
   %
   %  Next datapoint
   %
   fast_index = fast_index + 1;
   slow_index = slow_index + 1;
   %
   %  Get to next frame
   %
   while raw_data(3,fast_index) ~= 0
      fast_index = fast_index + 1;
      if fast_index > length(raw_data)
         break;
      end
   end
end
disp('Slow data loaded');
%
%  Now fix slow time
%
index = 1;
bad_count = 0;
bad_ones = [];
while index < length(slow_data_structure)
   if (slow_data_structure(index).time > base_date_num + 2) || (slow_data_structure(index).time < base_date_num - 5)
      disp(sprintf('Bad Time:%s, index:%d\n',datestr(slow_data_structure(index).time),index));
      bad_count = bad_count + 1;
      bad_ones(bad_count) = index;
   end
   index = index + 1;
end
disp('Marked bad slow times');
if bad_count > 0
   slow_data_structure(bad_ones) = [];
end
disp('Slow time fixed');
