function [efm_data_matrix, efm_status_matrix, time_array, mill_array, N, summary_data, summary_count, time_gaps,nav_data] = sload_dc8_data(the_file_list, base_directory, pps, cut_off, order);
%  [efm_data_matrix, efm_status_matrix, time_array, mill_array, N, summary_data, summary_count, time_gaps] =
%  sload_dc8_data(file_list, directory, pps, cut_off, order);
%
%  This routine loads a boatload of efm data into two arrays, one for the data
%  and one for time.  It will use "resample" to take the data from 25 samples per second to the
%  value set in pps.  Note that "resample" is set to NOT filter the data.
%
%  Inputs:
%     file_list = array or structure (DIR format structure) of input file names
%     directory = char of base directory to find files (default: current directory)
%     pps = how many points per second in the output (default: all 50)
%     cut_off = cut off frequency for filtering (default: no filtering)
%     order = filter order (default: 2)
%  Outputs:
%     efm_data_matrix = the 4 x 6 x N (depending on the skip & seconds values) array of efm data
%     efm_status_matrix = the 8 x N (depending on the skip & seconds values) array of mill status data
%     time = time array for the points (in dateform format)
%     mill_array = array of mill ID's
%     N = # of points in the array of efm & time
%     summary_data = struct of summary data (once per block/second of data, optional)
%        .mill_ID = [6] array of mill ID#'s
%        .mill_time = [6] array of actual sec of mill data
%        .mill_state = [6] array of mill cal status
%        .mill_freq = [6] array of mill modulator frequecies
%        .timeGPS = nominal GPS time of data block
%        .timePC = nominal PC time of data block
%        .file_time = nominal file name derived time of data block
%        .subseconds = subsecond value from data request
%        .latitude
%        .longitude
%        .roll
%        .pitch
%        .heading
%     summary_count = # of the summary data structures (optional)
%     string listing of any wholesale (all mills) time gaps found in the data
%
%  There are a max of 25 points per second
%
   
%
%  Set any defaults
%
%
%    Determine the file count and file names
%
   if isstruct(the_file_list)
      disp('the_file_list is a structure');
      file_count_array = size(the_file_list);
      file_count = file_count_array(1)
      for i=1:file_count
         file_list(i,:) = the_file_list(i).name;
      end
   else
      disp('the_file_list is an array');
      file_count_array = size(the_file_list);
      file_count = file_count_array(1)
      file_list = the_file_list;
   end
   the_year = 2001;
   T0 = clock;
   format compact;
   disp('Setting defaults');
   if file_count <= 0
      file_count = 1;
   end
   default_size = 46000*file_count
   if ~exist('pps','var')
      pps = 25;
   end
   if ~exist('cut_off','var')
      cut_off = 0;
   end
   if ~exist('order','var')
      order = 2;
   end
   %
   % Init the data
   %
   T1 = clock;
   disp('Init data');
   summary_count = 0;
   T0 = clock;
   Ntot = 0;
   time_base = 'XXX';
   efm_data(4,6,default_size) = 0;
%   last_block = init_dc8_struct;
%   efm_block_current = init_dc8_struct;
%   nav_block_current = init_icats_struct;
%   nav_data(1840*file_count) = nav_block_current;
%   efm_block_next = init_dc8_struct;
   %
   % 5 volts / 65,536 bits
   %
   counts_2_volts = 20.0/4096.0; 
   for i=1:6
      mill_array(i) = 0;
      new_mill_array(i) = 0;
   end
   etime(clock,T1)
   %
   % Open file
   %
   N=0;
   block_index = 1;
   last_time = 0;
   T1 = clock;
   for i=1:file_count
      %
      % Open next file
      %
      disp('Opening next file');
      disp(strcat(base_directory,'\',file_list(i,:)));
      fid1 = fopen(strcat(base_directory,'\',file_list(i,:)),'r');
      file_block_count = 0;
      %
      % Determine the nominal time of the data
      %
      file_stuff = sscanf(file_list(i,:),'%1d%3d%2d%2d')
      file_stuff2 = datevec(yearday(the_year,file_stuff(2)));
      file_stuff2(4) = file_stuff(3);
      file_stuff2(5) = file_stuff(4);
      file_date = datenum(file_stuff2(1),file_stuff2(2),file_stuff2(3),file_stuff2(4),file_stuff2(5),file_stuff2(6));
      %
      % Read first block of data
      %
%      [efm_block_current,nav_block_current] = read_dc8_block(fid1, efm_block_current, nav_block_current);
      [efm_block_current,nav_block_current] = read_dc8_block(fid1);
      efm_block_current.efmrecord.sync;
      disp('Load Data');
      while efm_block_current.version ~= 0
         %
         %  File looks okay, read summary
         %
         summary_count = summary_count + 1;
         nav_data(summary_count) = nav_block_current;
         summary_data(summary_count).lat = nav_block_current.latitude;
         summary_data(summary_count).lon = nav_block_current.longitude;
         summary_data(summary_count).alt = nav_block_current.radar_alt;
         summary_data(summary_count).roll = nav_block_current.roll;
         summary_data(summary_count).pitch = nav_block_current.pitch;
         summary_data(summary_count).heading = nav_block_current.true_head;
         summary_data(summary_count).timeGPS = efm_block_current.timeGPS;
         datestr(efm_block_current.timeGPS);
         summary_data(summary_count).timePC = efm_block_current.timePC;
         file_stuff2 = datevec(yearday(nav_block_current.year,nav_block_current.day));
         summary_data(summary_count).timeNAV = datenum(nav_block_current.year,file_stuff2(2),file_stuff2(3),nav_block_current.hour,nav_block_current.min,nav_block_current.sec);
         summary_data(summary_count).file_time = file_date + file_block_count*1.157e-5;
         summary_data(summary_count).subseconds = efm_block_current.subseconds;
         datestr(summary_data(summary_count).file_time);
         abs(efm_block_current.timeGPS-summary_data(summary_count).file_time);
         %
         %  Determine the "best" time of the block
         %
         if abs(efm_block_current.timeGPS-summary_data(summary_count).file_time) > 3e-2
            %
            %  GPS Time is off, try the navtime
            %
            if abs(summary_data(summary_count).timeNAV-summary_data(summary_count).file_time) > 3e-2
               if abs(efm_block_current.timePC-summary_data(summary_count).file_time) > 3e-2
                  %
                  %  Even the PC time is off, we are wild a@# guessing the time
                  %
                  summary_data(summary_count).best_time = summary_data(summary_count).file_time;
                  if time_base ~= 'FIL'
                     warning('Both PC and GPS time are more than 45 minutes off of the file estimated time');
                     warning('Will estimate time from data file name');
                     disp(strcat('file_time:',datestr(summary_data(summary_count).file_time),' timeGPS:',datestr(summary_data(summary_count).timeGPS),' timePC:',datestr(summary_data(summary_count).timePC),' timeNAV:',datestr(summary_data(summary_count).timeNAV)));
                     time_base = 'FIL';
                  end
               else
                  %
                  %  Use PC time
                  %
                  summary_data(summary_count).best_time = summary_data(summary_count).timePC;
                  if time_base ~= 'PC '
                     disp('Using PC time');
                     disp(strcat('file_time:',datestr(summary_data(summary_count).file_time),' timeGPS:',datestr(summary_data(summary_count).timeGPS),' timePC:',datestr(summary_data(summary_count).timePC),' timeNAV:',datestr(summary_data(summary_count).timeNAV)));
                     time_base = 'PC ';
                  end
               end
            else
               %
               %  Use NAVtime
               %
               summary_data(summary_count).best_time = summary_data(summary_count).timeNAV;
               if time_base ~= 'NAV'
                  disp('Using NAV time');
                  disp(strcat('file_time:',datestr(summary_data(summary_count).file_time),' timeGPS:',datestr(summary_data(summary_count).timeGPS),' timePC:',datestr(summary_data(summary_count).timePC),' timeNAV:',datestr(summary_data(summary_count).timeNAV)));
                  time_base = 'NAV';
               end
            end
         else
            %
            %  Use GPS time
            %
            summary_data(summary_count).best_time = summary_data(summary_count).timeGPS;
            if time_base ~= 'GPS'
               disp('Using GPS time');
               disp(strcat('file_time:',datestr(summary_data(summary_count).file_time),' timeGPS:',datestr(summary_data(summary_count).timeGPS),' timePC:',datestr(summary_data(summary_count).timePC),' timeNAV:',datestr(summary_data(summary_count).timeNAV)));
               time_base = 'GPS';
            end
         end
         C = datevec(summary_data(summary_count).best_time);
         the_seconds = C(6);
         for mill_count=1:6
            summary_data(summary_count).mill_header(mill_count,1:10) = efm_block_current.efmrecord(mill_count).header;
            summary_data(summary_count).mill_ID(mill_count) = uint8(bitshift(bitand(efm_block_current.efmrecord(mill_count).header(1),248),-3));
            delta_time = the_seconds - efm_block_current.efmrecord(mill_count).header(4);
            if delta_time < 0
               summary_data(summary_count).mill_delta_time(mill_count) = delta_time + 60;
            else
               summary_data(summary_count).mill_delta_time(mill_count) = delta_time;
            end
            summary_data(summary_count).mill_delta_time(mill_count) = 0;
            summary_data(summary_count).mill_state(mill_count) = uint8(bitand(efm_block_current.efmrecord(mill_count).header(5),15));
            summary_data(summary_count).mill_freq(mill_count) = uint8(bitand(efm_block_current.efmrecord(mill_count).header(6),63));
         end
         % 
         % Read in the data
         %
         for block_index=1:25
            N = N + 1;
            if N > default_size
               disp('Increasing default size');
               default_size = default_size*2;
               disp(default_size);
               efm_data(4,6,default_size) = 0;
            end
            for mill_index=1:6
               efm_data(1,mill_index,N) = efm_block_current.efmrecord(mill_index).one(block_index);
               efm_data(2,mill_index,N) = efm_block_current.efmrecord(mill_index).two(block_index);
               efm_data(3,mill_index,N) = efm_block_current.efmrecord(mill_index).three(block_index);
               efm_data(4,mill_index,N) = efm_block_current.efmrecord(mill_index).four(block_index);
            end
         end
         %
         % Get the nex block
         %
         last_block = efm_block_current;
         file_block_count = file_block_count + 1;
%         [efm_block_current,nav_block_current] = read_dc8_block(fid1, efm_block_current, nav_block_current);
         [efm_block_current,nav_block_current] = read_dc8_block(fid1);
      end
      %
      % Get the next file
      %
      etime(clock,T1)
      fclose(fid1);
      T1 = clock;
   end
   summary_count
   nav_2 = nav_data(1:summary_count);
   nav_data = nav_2;
   %
   % Now we have fallen off the end of the data, filter it
   %  remembering to halve the order since the filtfilt
   % doubles the order of the filter
   %
   if cut_off ~= 0
      disp('Filter Data');
      [b,a] = butter(ceil(order*.5),cut_off/25);
      for mill_index=1:6
         for gain_index=1:4
            efm_data(gain_index,mill_index,1:N) = filtfilt(b,a,efm_data(gain_index,mill_index,1:N));
         end
      end
   else
      disp('Not Filtering Data');
   end
   T1 = clock;
   disp('Identify Mills');
   %
   % We will make a radical assumption: that the mills
   %  will not change in mid-flight.
   %
   for block_index = 1:summary_count
      for mill_index=1:6
         new_mill_array(mill_index) = summary_data(block_index).mill_ID(mill_index);
      end
      if block_index ~= 1
         for mill_index=1:6
            if new_mill_array(mill_index) ~= mill_array(mill_index)
               beep;
               disp('New:');
               disp(new_mill_array);
               disp('Old:');
               disp(mill_array);
%               what_now = [];
%               while isempty(what_now)
%                  what_now = input('Mills Changed in Mid-Flight, keep (o)ld or (n)ew?','s');
%               end 
               what_now = 'n'
               if what_now(1) == 'n'
                  mill_array = new_mill_array;
                  disp('Using new values');
                  disp(mill_array);
               else
                  disp('Using old values');
                  disp(mill_array);
               end
               break;
            end
         end
      else
         for mill_index=1:6
            mill_array(mill_index) = new_mill_array(mill_index);
         end
      end
   end
   etime(clock,T1)
   T1 = clock;
   disp('Time Tag Data');
   %
   %  We will first find all of the mill times
   %
   disp('Find Times');
   base_time = round((summary_data(1).best_time)*60*60*24);
   block_times(1) = round((summary_data(1).best_time)*60*60*24 - summary_data(1).mill_delta_time(1) - base_time);
   time_index = 1;
   %
   %  For intial processing, we will not attempt to rearrange the times, but just assume the
   %  block times are correct
   %
   for block_index=2:summary_count
      block_times(block_index) = round((summary_data(block_index).best_time)*60*60*24 - base_time);
%      for mill_index=1:6
%         test_time = round((summary_data(block_index).best_time)*60*60*24 - summary_data(block_index).mill_delta_time(mill_index) - base_time);
%         if test_time ~= block_times(time_index)
%            time_index = time_index + 1;
%            block_times(time_index) = test_time;
%         end
%      end
   end
%   max_times = time_index
   max_times = summary_count
%
%  Will not sort or eliminate duplicate times in the DC8 data (for now)
%
%  disp('Sort Times');
%   [block_times, sort_index] = sort(block_times);
%   disp('Eliminate Duplicate Times');
%   time_index = 2;
%   while time_index <= max_times
%      if block_times(time_index) == block_times(time_index-1)
%         block_times(time_index) = [];
%         sort_index(time_index) = [];
%         max_times = max_times - 1;
%      else
%         time_index = time_index + 1;
%      end
%   end
%   max_times
   %
   %  Now that we have the list of valid times, make the time array
   %
   disp('Make Time Array');
   Ntot = 25*max_times;
   time(Ntot) = 0;
   for time_index=1:max_times
      for sub_time_index=1:25
         time((time_index-1)*25+sub_time_index) = block_times(time_index) + (sub_time_index-1)*0.04;
      end
   end
   %
   %  Now we can pre-size and pre-set the values for the time sorted mill data
   %
%   etime(clock,T1)
%   T1 = clock;
%   disp('Pre-allocating new efm data');
%   time_sort_efm_data(4,6,Ntot) = 0;
%   etime(clock,T1)
%   T1 = clock;
%   disp('Make all data NaN');
%   time_sort_efm_data = NaN;
   %
   %  Now dump the mill data into the time ordered and alighned array
   %
   etime(clock,T1)
   T1 = clock;
   disp('Put Alighned Data Into Array');
   time_index = 1;
   tom_index = 1;
   time_sort_efm_data = efm_data;
%   for block_index=1:max_times
%      in_block_start = (block_index-1)*25 + 1;
%      in_block_end = (block_index-1)*25 + 25;
%      out_block_start = (sort_index(block_index)-1)*25 + 1;
%      out_block_end = (sort_index(block_index)-1)*25 + 25;
%      for mill_index=1:6
         %
         %  Determine time block for this mill's data
         %
%         time_of_mill = round((summary_data(block_index).best_time)*60*60*24 - summary_data(block_index).mill_delta_time(mill_index) - base_time);
%         tom(mill_index,block_index) = time_of_mill;
%         while time_of_mill > block_times(time_index)
%            time_index = time_index+1;
%         end
%         while time_of_mill < block_times(time_index)
%            time_index = time_index-1;
%         end
         %
         %  Now we have found the correct block to put in the data
         %
 %        out_block = (time_index-1)*25;
 %        Ntot;
 %        for data_index=in_block_start:in_block_end
 %           out_block = out_block + 1;
 %           for gain_index=1:4
 %              time_sort_efm_data(gain_index,mill_index,out_block) = efm_data(gain_index,mill_index,data_index);
 %           end
 %        end
 %     end
 %     time_sort_efm_data(:,:,in_block_start:in_block_end) = efm_data(:,:,out_block_start:out_block_end);
      %   end
   %
   %  Now resample data
   %
   etime(clock,T1)
   T1 = clock;
   disp('Resampling Data');
   Ntot
   d = gcd(pps,25);
   p = pps/d;
   q = 25/d;
   N = ceil(Ntot*p/q)
   if pps ~= 25
      efm_data_matrix(4,6,N) = 0;
      for mill_index=1:6
         dummy_array_1 = resample(squeeze(time_sort_efm_data(1,mill_index,1:Ntot)),p,q,0);
         dummy_array_2 = resample(squeeze(time_sort_efm_data(2,mill_index,1:Ntot)),p,q,0);
         dummy_array_3 = resample(squeeze(time_sort_efm_data(3,mill_index,1:Ntot)),p,q,0);
         dummy_array_4 = resample(squeeze(time_sort_efm_data(4,mill_index,1:Ntot)),p,q,0);
         efm_data_matrix(1,mill_index,:) = dummy_array_1;
         efm_data_matrix(2,mill_index,:) = dummy_array_2;
         efm_data_matrix(3,mill_index,:) = dummy_array_3;
         efm_data_matrix(4,mill_index,:) = dummy_array_4;
      end
      time_array = resample(time(1:Ntot),p,q,0);
   else
      efm_data_matrix = time_sort_efm_data(:,:,1:Ntot);
      time_array = time(1:Ntot);
   end
   etime(clock,T1)
   T1 = clock;
   disp('Convert to Matlab time and log time gaps');
   %
   %  Change time array back to Matlab format
   %
   time_array = (time_array + base_time)/86400;
   %
   %  Convert counts to volts
   %
   efm_data_matrix = efm_data_matrix*counts_2_volts;
   %
   %  Now determine the efm_status_matrix
   %  On the DC-8 (CAMEX4?), the calibration indicator
   %  is in the header, byte #2
   %
   cal_status(6,summary_count) = 0;
   for i=1:summary_count
      for j=1:6
         cal_status(j,i) = summary_data(i).mill_header(j,2);
      end
   end
   %
   %  Find the times of the cal data
   %
   cal_time = [summary_data.timeGPS];
   %
   %  Resample to data rate, first getting rid of any bad data
   %  (zeros or non-increasing data)
   %
   the_zeros = find(cal_time == 0);
   cal_time(the_zeros) = [];
   cal_status(:,the_zeros) = [];
   %
   %  Now the non-increasing data
   %
   the_bad_points = find(diff(cal_time) == 0);
   cal_time(the_bad_points) = [];
   cal_status(:,the_bad_points) = [];
   %
   %  Now we should be able to resample the data
   %  Note, since we are using the nearest neighbor resample, we need to
   %  shift the data by 0.5 seconds so the pulses line up
   %
   efm_status_matrix(6,N) = 0;
   for i=1:6
      efm_status_matrix(i,:) = interp1(cal_time+(0.5/86400),cal_status(i,:),time_array,'nearest');
   end
   %
   %  Log all time gaps
   %
   delta_time = q/(25*p)
   gap_count = 0;
   for time_index=2:N
      delt = (time_array(time_index)-time_array(time_index-1))*86400;
      delta_time;
      if abs(delt-delta_time)/delta_time > 0.4
         gap_count = gap_count + 1;
         time_gap_string = sprintf('%8.2f gap starting at %s',delt,datestr(time_array(time_index-1)));
         time_gaps(gap_count,1:45) = time_gap_string(1:45);
         disp(time_gaps(gap_count,:));
      end
   end
   %
   %  Fix time gaps
   %
   time_array = jitter_fix(time_array,time_array(1),delta_time,50*delta_time,5*delta_time);
   %
   %  Show gaps again...
   %
   gap_count = 0;
   for time_index=2:N
      delt = (time_array(time_index)-time_array(time_index-1))*86400;
      delta_time;
      if abs(delt-delta_time)/delta_time > 0.4
         gap_count = gap_count + 1;
         time_gap_string = sprintf('%8.2f gap starting at %s',delt,datestr(time_array(time_index-1)));
         time_gaps(gap_count,1:45) = time_gap_string(1:45);
         disp(time_gaps(gap_count,:));
      end
   end
   etime(clock,T1)
   etime(clock,T0)
   
   
         
         

