function [efm_data_matrix, efm_status_matrix, time_array, mill_array, N, summary_data, summary_count, time_gaps] = sload_efm_data(the_file_list, base_directory, pps, cut_off, order);
%  [efm_data_matrix, efm_status_matrix, time_array, mill_array, N, summary_data, summary_count, time_gaps] =
%  sload_efm_data(the_file_list, directory, pps, cut_off, order);
%
%  This routine loads a boatload of efm data into two arrays, one for the data
%  and one for time.  It will use "resample" to take the data from 50 samples per second to the
%  value set in pps.  Note that "resample" is set to NOT filter the data.  It will also produce a
%  matrix of the mill status (like in CAL+ or CAL-) so that the user can subtract the cal values.
%
%  Inputs:
%     the_file_list(file_count,?) = char string or structure array of input files
%     directory = char of base directory to find files (default: current directory)
%     pps = how many points per second in the output (default: all 50)
%     cut_off = cut off frequency for filtering (default: no filtering)
%     order = filter order (default: 2)
%  Outputs:
%     efm_data_matrix = the 2 x 6 x N (depending on the skip & seconds values) array of efm data
%     efm_status_matrix = the 6 x N (depending on the skip & seconds values) array of mill status data
%     time = time array for the points (in dateform format)
%     mill_array = array of mill ID's
%     N = # of points in the array of efm & time
%     summary_data = struct of summary data (once per block/second of data, optional)
%        .mill_ID = [6] array of mill ID#'s
%        .mill_time = [6] array of actual sec of mill data
%        .mill_state = [6] array of mill cal status
%        .mill_freq = [6] array of mill modulator frequecies
%        .timeGPS = nominal GPS time of data block
%        .timePC = nominal PC time of data block
%        .file_time = nominal file name derived time of data block
%        .subseconds = subsecond value from data request
%     summary_count = # of the summary data structures (optional)
%     string listing of any wholesale (all mills) time gaps found in the data
%
%  There are a max of 50 points per second
%

%
%  Set any defaults
%
   T0 = clock;
   format compact;
   disp('Setting defaults');
   %
   %    Determine the file count and file names
   %
   if isstruct(the_file_list)
       disp('the_file_list is a structure');
       file_count_array = size(the_file_list);
       file_count = file_count_array(1);
       for i=1:file_count
           file_list(i,:) = the_file_list(i).name;
       end
   else
       disp('the_file_list is an array');
       file_count_array = size(the_file_list);
       file_count = file_count_array(1);
       file_list = the_file_list;
   end
   default_size = 91000*file_count;
   if ~exist('pps','var')
      pps = 50;
   end
   if ~exist('cut_off','var')
      cut_off = 0;
   end
   if ~exist('order','var')
      order = 2;
   end
   %
   % Init the data
   %
   disp('Init data');
   summary_count = 0;
   T0 = clock;
   Ntot = 0;
   time_base = 'XXX';
   efm_data(2,6,default_size) = 0;
   efm_status(6,default_size) = 0;
   last_block = init_efm_struct;
   efm_block_current = init_efm_struct;
   efm_block_next = init_efm_struct;
   %
   % 5 volts / 65,536 bits
   %
   counts_2_volts = 5.0/65536.0; 
   for i=1:6
      mill_array(i) = 0;
      new_mill_array(i) = 0;
   end
   %
   % Open file
   %
   N=0;
   block_index = 1;
   last_time = 0;
   for i=1:file_count
      %
      % Open next file
      %
      disp('Opening next file');
      disp(strcat(base_directory,'\',file_list(i,:)));
      fid1 = fopen(strcat(base_directory,'\',file_list(i,:)),'r');
      if fid1 == -1
          warning('Could not open file');
      end
      file_block_count = 0;
      %
      % Determine the nominal time of the data
      %
      file_stuff = sscanf(file_list(i,:),'EFM_LZ_V%f_%d-%d-%dT%d-%d-%d');
      file_date = datenum(file_stuff(2),file_stuff(3),file_stuff(4),file_stuff(5),file_stuff(6),file_stuff(7));
      %
      % Read first block of data
      %
      efm_block_current = read_efm_block(fid1, efm_block_current);
      disp('Load Data');
      while efm_block_current.version ~= 0
         %
         %  File looks okay, read summary
         %
         summary_count = summary_count + 1;
         summary_data(summary_count).timeGPS = efm_block_current.timeGPS;
         summary_data(summary_count).timePC = efm_block_current.timePC;
         summary_data(summary_count).file_time = file_date + file_block_count*1.157e-5;
         summary_data(summary_count).subseconds = efm_block_current.subseconds;
         %
         %  Determine the "best" time of the block
         %
         if abs(efm_block_current.timeGPS-summary_data(summary_count).file_time) > 3e-2
            %
            %  GPS Time is off, try the pctime
            %
            if abs(efm_block_current.timePC-summary_data(summary_count).file_time) > 3e-2
               %
               %  Even the PC time is off, we are wild a@# guessing the time
               %
               summary_data(summary_count).best_time = summary_data(summary_count).file_time;
               if time_base ~= 'FIL'
                  warning('Both PC and GPS time are more than 45 minutes off of the file estimated time');
                  warning('Will estimate time from data file name');
                  disp(strcat('file_time:',datestr(summary_data(summary_count).file_time),' timeGPS:',datestr(summary_data(summary_count).timeGPS),' timePC:',datestr(summary_data(summary_count).timePC)));
                  time_base = 'FIL';
               end
            else
               %
               %  Use PC time
               %
               summary_data(summary_count).best_time = summary_data(summary_count).timePC;
               if time_base ~= 'PC '
                  disp('Using PC time');
                  disp(strcat('file_time:',datestr(summary_data(summary_count).file_time),' timeGPS:',datestr(summary_data(summary_count).timeGPS),' timePC:',datestr(summary_data(summary_count).timePC)));
                  time_base = 'PC ';
               end
            end
         else
            %
            %  Use GPS time
            %
            summary_data(summary_count).best_time = summary_data(summary_count).timeGPS;
            if time_base ~= 'GPS'
               disp('Using GPS time');
               disp(strcat('file_time:',datestr(summary_data(summary_count).file_time),' timeGPS:',datestr(summary_data(summary_count).timeGPS),' timePC:',datestr(summary_data(summary_count).timePC)));
               time_base = 'GPS';
            end
         end
         C = datevec(summary_data(summary_count).best_time);
         the_seconds = C(6);
         for mill_count=1:6
            summary_data(summary_count).mill_ID(mill_count) = uint8(bitshift(bitand(efm_block_current.efmrecord(mill_count).header(3),248),-3));
            delta_time = the_seconds - efm_block_current.efmrecord(mill_count).header(6);
            if delta_time < 0
               summary_data(summary_count).mill_delta_time(mill_count) = delta_time + 60;
            else
               summary_data(summary_count).mill_delta_time(mill_count) = delta_time;
            end
            summary_data(summary_count).mill_state(mill_count) = uint8(bitand(efm_block_current.efmrecord(mill_count).header(7),15));
            summary_data(summary_count).mill_freq(mill_count) = uint8(bitand(efm_block_current.efmrecord(mill_count).header(8),63));
         end
         %
         % Read in the data
         %
         for block_index=1:50
            N = N + 1;
            if N > default_size
               disp('Increasing default size');
               default_size = default_size*2;
               disp(default_size);
               efm_data(6,2,default_size) = 0;
               efm_status(6,default_size) = 0;
            end
            for mill_index=1:6
               efm_data(1,mill_index,N) = efm_block_current.efmrecord(mill_index).sensitive(block_index);
               efm_data(2,mill_index,N) = efm_block_current.efmrecord(mill_index).insensitive(block_index);
               efm_status(mill_index,N) = uint8(bitand(efm_block_current.efmrecord(mill_index).header(7),15));
            end
         end
         %
         % Get the nex block
         %
         last_block = efm_block_current;
         file_block_count = file_block_count + 1;
         efm_block_current = read_efm_block(fid1, efm_block_current);
      end
      %
      % Get the next file
      %
      fclose(fid1);
   end
   summary_count
   %
   % Now we have fallen off the end of the data, remembering to halve the order since the filtfilt
   % doubles the order of the filter
   %
   if cut_off ~= 0
      disp('Filter Data');
      [b,a] = butter(ceil(order*.5),cut_off/25);
      for mill_index=1:6
         efm_data(1,mill_index,1:N) = filtfilt(b,a,efm_data(1,mill_index,1:N));
         efm_data(2,mill_index,1:N) = filtfilt(b,a,efm_data(2,mill_index,1:N));
      end
   else
      disp('Not Filtering Data');
   end
   disp('Identify Mills');
   %
   % We will make a radical assumption: that the mills
   %  will not change in mid-flight.
   %
   for block_index = 1:summary_count
      for mill_index=1:6
         new_mill_array(mill_index) = summary_data(block_index).mill_ID(mill_index);
      end
      if block_index ~= 1
         for mill_index=1:6
            if new_mill_array(mill_index) ~= mill_array(mill_index)
               %
               %  If the old one is bad, try new one (it can't be any worse)
               %
               if (mill_array(mill_index) > 28) | (mill_array(mill_index) < 20)
                  mill_array(mill_index) = new_mill_array(mill_index);
               end
            end
         end
         %
         %  Now see if the new values are different than the old values
         %
         for mill_index=1:6
            if new_mill_array(mill_index) ~= mill_array(mill_index)
               if (new_mill_array(mill_index) > 28) | (new_mill_array(mill_index) < 20)
                  continue;
               else
                  beep;
                  disp('New:');
                  disp(new_mill_array(mill_index));
                  disp('Old:');
                  disp(mill_array(mill_index));
%                  what_now = input('Mill Changed in Mid-Flight, keep (o)ld or (n)ew?','s');
                  what_now(1) = 'o';
                  if what_now(1) == 'n'
                     mill_array(mill_index) = new_mill_array(mill_index);
                     disp('Using new value');
                     disp(mill_array);
                  else
                     disp('Using old values');
                     disp(mill_array);
                  end
               end
            end
         end
      else
         for mill_index=1:6
            mill_array(mill_index) = new_mill_array(mill_index);
         end
      end
   end
   disp('Time Tag Data');
   %
   %  We will first find all of the mill times
   %
   disp('Find Times');
   base_time = round((summary_data(1).best_time)*60*60*24);
   block_times(1) = round((summary_data(1).best_time)*60*60*24 - summary_data(1).mill_delta_time(1) - base_time);
   time_index = 1;
   for block_index=2:summary_count
      for mill_index=1:6
         test_time = round((summary_data(block_index).best_time)*60*60*24 - summary_data(block_index).mill_delta_time(mill_index) - base_time);
         if test_time ~= block_times(time_index)
            time_index = time_index + 1;
            block_times(time_index) = test_time;
         end
      end
   end
   max_times = time_index
   disp('Sort Times');
   block_times = sort(block_times);
   disp('Eliminate Duplicate Times');
   time_index = 2;
   while time_index <= max_times
      if block_times(time_index) == block_times(time_index-1)
         block_times(time_index) = [];
         max_times = max_times - 1;
      else
         time_index = time_index + 1;
      end
   end
   max_times
   %
   %  Now that we have the list of valid times, make the time array
   %
   disp('Make Time Array');
   Ntot = 50*max_times;
   time(Ntot) = 0;
   for time_index=1:max_times
      for sub_time_index=1:50
         time((time_index-1)*50+sub_time_index) = block_times(time_index) + (sub_time_index-1)*0.02;
      end
   end
   %
   %  Now we can pre-size and pre-set the values for the time sorted mill data
   %
   disp('Pre-allocating new efm data');
   time_sort_efm_data(2,6,Ntot) = 0;
   time_sort_efm_status(6,Ntot) = 0;
   disp('Make all data NaN');
   for j=1:6
      for k=1:Ntot
         time_sort_efm_status(j,k) = NaN;
         for i=1:2
            time_sort_efm_data(i,j,k) = NaN;
         end
      end
   end
   %
   %  Now dump the mill data into the time ordered and alighned array
   %
   disp('Put Alighned Data Into Array');
   time_index = 1;
   tom_index = 1;
   for block_index=1:summary_count
      in_block_start = (block_index-1)*50 + 1;
      in_block_end = (block_index-1)*50 + 50;
      for mill_index=1:6
         %
         %  Determine time block for this mill's data
         %
         time_of_mill = round((summary_data(block_index).best_time)*60*60*24 - summary_data(block_index).mill_delta_time(mill_index) - base_time);
         tom(mill_index,block_index) = time_of_mill;
         while time_of_mill > block_times(time_index)
            time_index = time_index+1;
         end
         while time_of_mill < block_times(time_index)
            time_index = time_index-1;
         end
         %
         %  Now we have found the correct block to put in the data
         %
         out_block = (time_index-1)*50;
         Ntot;
         for data_index=in_block_start:in_block_end
            out_block = out_block + 1;
            time_sort_efm_data(1,mill_index,out_block) = efm_data(1,mill_index,data_index);
            time_sort_efm_data(2,mill_index,out_block) = efm_data(2,mill_index,data_index);
            time_sort_efm_status(mill_index,out_block) = efm_status(mill_index,data_index);
         end
      end
   end
   %
   %  Now resample data
   %
   disp('Resampling Data');
   Ntot
   d = gcd(pps,50);
   p = pps/d;
   q = 50/d;
   N = ceil(Ntot*p/q)
   if pps ~= 50
      efm_data_matrix(2,6,N) = 0;
      efm_status_matrix(6,N) = 0;
      for mill_index=1:6
         dummy_array_1 = resample(squeeze(time_sort_efm_data(1,mill_index,:)),p,q,0);
         dummy_array_2 = resample(squeeze(time_sort_efm_data(2,mill_index,:)),p,q,0);
         dummy_array_3 = resample(squeeze(time_sort_efm_status(mill_index,:)),p,q,0);
         disp('Resampled mill');
         for data_index=1:N
            efm_data_matrix(1,mill_index,data_index) = dummy_array_1(data_index);
            efm_data_matrix(2,mill_index,data_index) = dummy_array_2(data_index);
            efm_status_matrix(mill_index,data_index) = dummy_array_3(data_index);
         end
      end
      time_array = resample(time,p,q,0);
   else
      efm_data_matrix = time_sort_efm_data;
      efm_status_matrix = time_sort_efm_status;
      time_array = time;
   end
   %
   %  Change time array back to Matlab format
   %
   time_array = (time_array + base_time)/86400;
   %
   %  Convert counts to volts
   %
   efm_data_matrix = efm_data_matrix*counts_2_volts;
   %
   %  Log all time gaps
   %
   delta_time = q/(50*p)
   gap_count = 0;
   for time_index=2:N
      delt = (time_array(time_index)-time_array(time_index-1))*86400;
      if abs(delt-delta_time)/delta_time > 0.2
         gap_count = gap_count + 1;
         time_gaps(gap_count,:) = sprintf('%8.2f gap starting at %s',delt,datestr(time_array(time_index-1)));
         disp(time_gaps(gap_count,:));
      end
   end
   etime(clock,T0)
   
   
         
         

