function [efm_data_matrix, efm_status_matrix, time_array, mill_array, N, summary_data, summary_count, time_gaps,nav_data, CP_data] = sload_er2_data(the_file_list, base_directory, pps, cut_off, order);
%  [efm_data_matrix, efm_status_matrix, time_array, mill_array, N, summary_data, summary_count, time_gaps,nav_data, CP_data] = 
%  sload_er2_data(file_list, base_directory, pps, cut_off, order);
%
%  This routine loads a boatload of efm data into two arrays, one for the data
%  and one for time.  It will use "resample" to take the data from 50 samples per second to the
%  value set in pps.  Note that "resample" is set to NOT filter the data.
%  It will also load the navigation data and the CP data.
%
%  Inputs:
%     file_list = array or structure (DIR format structure) of input file names
%     directory = char of base directory to find files (default: current directory)
%     pps = how many points per second in the output (default: all 50)
%     cut_off = cut off frequency for filtering (default: no filtering)
%     order = filter order (default: 2)
%  Outputs:
%     efm_data_matrix = the 2 x 8 x N (depending on the skip & seconds values) array of efm data
%     efm_status_matrix = the 8 x N (depending on the skip & seconds values) array of mill status data
%     time = time array for the points (in dateform format)
%     mill_array = array of mill ID's
%     N = # of points in the array of efm & time
%     summary_data = struct of summary data (once per block/second of data, optional)
%        .mill_ID = [6] array of mill ID#'s
%        .mill_time = [6] array of actual sec of mill data
%        .mill_state = [6] array of mill cal status
%        .mill_freq = [6] array of mill modulator frequecies
%        .timeGPS = nominal GPS time of data block
%        .timePC = nominal PC time of data block
%        .file_time = nominal file name derived time of data block
%        .subseconds = subsecond value from data request
%     summary_count = # of summary_data points
%     time_gaps = cell array of time gaps in the data
%     nav_data = struct of nav data
%        .latitude
%        .longitude
%        .roll
%        .pitch
%        .heading
%     CP_data = array of CP data
%
%  There are a max of 50 points per second
%
   
%
%  Time the process
%
T0 = clock;
%
%  Size of mill data for ER-2
%
Mill_Count = 8;
Gain_Count = 2;
%
%    Determine the file count and file names
%
if isstruct(the_file_list)
   disp('the_file_list is a structure');
   file_count_array = size(the_file_list);
   file_count = file_count_array(1);
   for i=1:file_count
      file_list(i,:) = the_file_list(i).name;
   end
else
   disp('the_file_list is an array');
   file_count_array = size(the_file_list);
   file_count = file_count_array(1);
   file_list = the_file_list;
end
if ~exist('pps','var')
   pps = 50;
end
if ~exist('cut_off','var')
   cut_off = 0;
end
if ~exist('order','var')
   order = 2;
end
%
%  Load the first one
%
disp('*******Loading First File');
[efm_data_matrix, efm_status_matrix, time_array, mill_array, N, summary_data, summary_count, nav_data, CP_data] = load_er2_data(file_list(1,:), base_directory, pps, cut_off, order);
if file_count > 1
   for file_index=2:file_count
      disp(sprintf('******Loading File #%d',file_index));
      [iefm_data_matrix, iefm_status_matrix, itime_array, mill_array, iN, isummary_data, isummary_count, inav_data, iCP_data] = load_er2_data(file_list(file_index,:), base_directory, pps, cut_off, order);
      %
      %  Now we have at least an hour of data, put them all together
      %
      disp('******Concatinating Data');
      efm_data_matrix(Gain_Count,Mill_Count,N+iN) = 0;
      for gain_index=1:Gain_Count
         for mill_index=1:Mill_Count
            for N_index=N+1:iN+N
               efm_data_matrix(gain_index,mill_index,N_index) = iefm_data_matrix(gain_index,mill_index,N_index-N);
            end
         end
      end
      time_array = [time_array itime_array];
      efm_status_matrix = [efm_status_matrix iefm_status_matrix];
      N = N + iN;
      summary_data = [summary_data isummary_data];
      nav_data = [nav_data inav_data];
      CP_data = [CP_data iCP_data];
      summary_count = summary_count + isummary_count;
   end
end
%
%  Display all time gaps
%
disp('*******Log Time Gaps');
d = gcd(pps,50);
p = pps/d;
q = 50/d;
delta_time = q/(50*p)
gap_count = 1;
time_array(1)
if (time_array(1) > datenum('1-jan-2020')) || (time_array(1) < 0)
   time_array(1) = 0;
end
if isnan(time_array(1))
   time_array(1) = 0;
end
%time_gaps(gap_count,:) = sprintf('%8.2f s gap starting at %s:%07d',0,datestr(time_array(1)),0);
for time_index=2:N
   delt = (time_array(time_index)-time_array(time_index-1))*86400;
   if abs(delt-delta_time)/delta_time > 0.2
      gap_count = gap_count + 1;
      if abs(delt) > 3600
         time_gaps{gap_count} = sprintf('%8.2f h gap starting at %s:%07d',delt/3600,datestr(time_array(time_index-1)),time_index-1);
         gap_index(gap_count) = time_index-1;
      else
%         sprintf('%8.2f s gap starting at %s',delt,datestr(time_array(time_index-1)))
         time_gaps{gap_count} = sprintf('%8.2f s gap starting at %s:%07d',delt,datestr(time_array(time_index-1)),time_index-1);
         gap_index(gap_count) = time_index-1;
      end
      disp(time_gaps{gap_count});
   end
end
%
%  Log all time gaps
%
clear time_gaps;
disp('*******Log Time Gaps');
d = gcd(pps,50);
p = pps/d;
q = 50/d;
delta_time = q/(50*p)
%
%  Fix time gaps
%
time_array = jitter_fix(time_array,time_array(1),delta_time,100*delta_time,5*delta_time);
gap_count = 1;
%time_gaps(gap_count,:) = sprintf('%8.2f s gap starting at %s:%07d',0,datestr(time_array(1)),0);
for time_index=2:N
   delt = (time_array(time_index)-time_array(time_index-1))*86400;
   if abs(delt-delta_time)/delta_time > 0.2
      gap_count = gap_count + 1;
      if abs(delt) > 3600
         time_gaps{gap_count} = sprintf('%8.2f h gap starting at %s:%07d',delt/3600,datestr(time_array(time_index-1)),time_index-1);
         gap_index(gap_count) = time_index-1;
      else
%         sprintf('%8.2f s gap starting at %s',delt,datestr(time_array(time_index-1)))
         time_gaps{gap_count} = sprintf('%8.2f s gap starting at %s:%07d',delt,datestr(time_array(time_index-1)),time_index-1);
         gap_index(gap_count) = time_index-1;
      end
      disp(time_gaps{gap_count});
   end
end
%
%  This routine 'fixes' the time gaps that look like jitter
%
etime(clock,T0)
%
%  Test for variables
%
if ~exist('efm_data_matrix','var')
   display('no efm_data_matrix');
end
if ~exist('efm_status_matrix', 'var')
   display('no efm_status_matrix');
end
if ~exist('time_array', 'var')
   display('no time_array');
end
if ~exist('mill_array', 'var')
   display('no mill_array');
end
if ~exist('N', 'var')
   display('no N');
end
if ~exist('summary_data', 'var')
   display('no summary_data');
end
if ~exist('summary_count', 'var')
   display('no summary_count');
end
if ~exist('time_gaps', 'var')
   display('no time_gaps');
   time_gaps = 0;
end
if ~exist('nav_data', 'var')
   display('no nav_data');
end
if ~exist('CP_data', 'var')
   display('no CP_data');
end
