function [fast_data, time_array, m_time_array, N, M, summary_data, summary_count] = sload_fast_data(the_file_list, kpps, trigger_list, base_directory);
%  [fast_data_matrix, trig_time, m_time_array, N, M, trigger_summary, trigger_count] = 
%     sload_fast_data(the_file_list, kpps, trigger_list, base_directory);
%
%  This routine loads a boatload of fast data into two arrays, one for the data
%  and one for time.  It will use "resample" to take the data from 200 Ksamples per second to the
%  value set in Kpps.  Note that "resample" is set to NOT filter the data.
%
%  Inputs:
%     the_file_list(file_count,?) = char string or structure array of input files
%     directory = char of base directory to find files (default: current directory)
%     kpps = how many kpoints (1000) per second in the output (default: all 200)
%     trigger_list = array of trigger #'s to download
%  Outputs:
%     fast_data_matrix = the N x 16 x M (M = 65536*kpps/200, N = # of triggers requested) array of fast data
%     time_array = N x M time array for the points (in seconds from triggered time)
%     m_time_array = N x M time array (in dateform format)
%     N = # of triggers
%     M = # of points per trigger
%
%  There are a max of 200,000 points per second
%

%
%  Set any defaults
%
   T0 = clock;
   format compact;
   year = 2002;
   disp('Setting defaults');
   %
   %    Determine the file count and file names
   %
   if isstruct(the_file_list)
       disp('the_file_list is a structure');
       file_count_array = size(the_file_list);
       file_count = file_count_array(1);
       for i=1:file_count
           file_list(i,:) = the_file_list(i).name;
       end
   else
       disp('the_file_list is an array');
       file_count_array = size(the_file_list);
       file_count = file_count_array(1);
       file_list = the_file_list;
   end
   if ~exist('trigger_list','var')
      trigger_list = 1:100;
   end
   if ~exist('kpps','var')
      kpps = 200;
   end
   if ~exist('base_directory','var')
      base_directory = pwd;
   end
   pps = kpps*1000;
   max_trigger = max(trigger_list);
   number_of_triggers = max(size(trigger_list))
   default_size = ceil(65536*kpps/200);
   M = default_size;
   N = number_of_triggers;
   cut_off = 0;
   order = 2;
   trigger_count = 0;
   %
   % Init the data
   %
   disp('Init data');
   summary_count = 0;
   T0 = clock;
   Ntot = 0;
   time_base = 'XXX';
   fast_data(number_of_triggers,16,default_size) = 0;
   m_time_array(number_of_triggers,default_size) = 0;
   time_array(number_of_triggers,default_size) = 0;
   block_data(16,65536) = 0;
   filtered_block_data(16,65536) = 0;
   block_time(65536) = 0;
   %
   % Open file
   %
   N=0;
   block_index = 1;
   last_time = 0;
   for i=1:file_count
      %
      % Open next file
      %
      disp('Opening next file');
      disp(strcat(base_directory,'\',file_list(i,:)));
      fid1 = fopen(strcat(base_directory,'\',file_list(i,:)),'r');
      if fid1 == -1
          warning('Could not open file');
      end
      file_block_count = 0;
      %
      % Read first block of data
      %
      [fast_block_1, count] = read_trig_block(fid1);
      [fast_block_2, count] = read_trig_block(fid1);
      [fast_block_3, count] = read_trig_block(fid1);
      [fast_block_4, count] = read_trig_block(fid1);
      fast_block_current = fast_block_1;
      count;
      disp('Load Data');
      while count == 16
         trigger_count = trigger_count + 1;
         if all(trigger_list - trigger_count) == 0
            %
            %  Trigger is in the list, read summary
            %
            disp(sprintf('Load %d %s', trigger_count,fast_block_current.trig_time));
            summary_count = summary_count + 1;
            summary_data(summary_count).s_time = fast_block_current.trig_time;
            summary_data(summary_count).trig_loc = fast_block_current.params.trig_loc;
            summary_data(summary_count).attenuation = fast_block_current.params.attenuation;
            summary_data(summary_count).atten_state = fast_block_current.params.atten_state;
            summary_data(summary_count).coupling = fast_block_current.params.coupling;
            summary_data(summary_count).filter = fast_block_current.params.filter;
            summary_data(summary_count).gain = fast_block_current.params.gain;
            summary_data(summary_count).input_state = fast_block_current.params.input_state;
            summary_data(summary_count).output_state = fast_block_current.params.output_state;
            summary_data(summary_count).voltage = fast_block_current.params.voltage;
            summary_data(summary_count).ch_range = fast_block_current.header.ch_range;
            summary_data(summary_count).scale = fast_block_current.header.scale;
%            summary_data(summary_count).group = fast_block_current.header.group;
            summary_data(summary_count).channel = fast_block_current.header.channel;
            summary_data(summary_count).threshold = fast_block_current.header.threshold;
            summary_data(summary_count).level = fast_block_current.header.level;
            summary_data(summary_count).numbytes = fast_block_current.header.numbytes;
            summary_data(summary_count).res_group = fast_block_current.header.res_group;
            %
            %  Decode the string time to a matlab time
            %
            time_val = sscanf(summary_data(summary_count).s_time, '%3d:%2d:%2d:%f');
            [month, day] = DOY_2_mon_day(time_val(1), year);
            hour = time_val(2);
            minute = time_val(3);
            data_second = time_val(4);
            summary_data(summary_count).m_time = datenum(year,month,day,hour,minute,data_second);
            datestr(summary_data(summary_count).m_time);
%            group = fast_block_current.header.group;
            %
            % Read in the data
            %
%            disp('Resampling/Storing Data');
            d = gcd(pps,200000);
            p = pps/d;
            q = 200000/d;
            block_data(1:4,:) = fast_block_1.data(1:4,:);
            block_data(5:8,:) = fast_block_2.data(1:4,:);
            block_data(9:12,:) = fast_block_3.data(1:4,:);
            block_data(13:16,:) = fast_block_4.data(1:4,:);
            if kpps ~= 200
               for channel_index=1:16
                  dummy_array_1 = squeeze(block_data(channel_index,:));
                  fast_data(summary_count,channel_index,:) = resample(dummy_array_1,p,q,0);
               end
            else
               fast_data(summary_count,:,:) = block_data(:,:);
            end
            %
            %  Set time
            %
%            disp('Make/Resample Time Array');
            scale_time = summary_data(summary_count).scale;
            for sub_time_index=1:65536
               block_time(sub_time_index) = (sub_time_index - scale_time)*5e-6;
            end
            if kpps ~= 200
               time_array(summary_count,:) = resample(block_time,p,q,0);
            else
               time_array(summary_count,:) = block_time;
            end
            %
            % Now convert summary time back to matlab (note the data will stay in non-matlab time as we need the resolution)
            %
            m_time_array(summary_count,:) = time_array(summary_count,:)/86400 + summary_data(summary_count).m_time;
            time_array(summary_count,:) = time_array(summary_count,:);
         else
            disp(sprintf('Skip %d %s', trigger_count,fast_block_current.trig_time));
         end
         %
         % Get the next trigger
         %
         last_block = fast_block_current;
         file_block_count = file_block_count + 1;
         [fast_block_1,count] = read_trig_block(fid1);
         [fast_block_2, count] = read_trig_block(fid1);
         [fast_block_3, count] = read_trig_block(fid1);
         [fast_block_4, count] = read_trig_block(fid1);
         fast_block_current = fast_block_1;
         if trigger_count > max_trigger
            break;
         end
      end
      %
      % Get the next file
      %
      fclose(fid1);
   end
   summary_count
   %
   %  Time the data processing
   %
   etime(clock,T0)
   
   
         
         

