function [slow_data_matrix, time_array, m_time_array, N, summary_data, summary_count] = sload_slow_data(the_file_list, base_directory, pps, cut_off, order);
%  [slow_data_matrix, time_array, m_time_array, N, summary_data, summary_count] 
%   = sload_slow_data(the_file_list, base_directory, pps, cut_off, order);
%
%  This routine loads a boatload of slow data into two arrays, one for the data
%  and one for time.  It will use "resample" to take the data from 50 samples per second to the
%  value set in pps.  Note that "resample" is set to NOT filter the data.
%
%  Inputs:
%     the_file_list(file_count,?) = char string or structure array of input files
%     directory = char of base directory to find files (default: current directory)
%     pps = how many points per second in the output (default: all 100)
%     cut_off = cut off frequency for filtering (default: no filtering)
%     order = filter order (default: 2)
%  Outputs:
%     slow_data_matrix = the 64 x N (depending on the skip & seconds values) array of slow data
%     time_array = time array for the points (in seconds from the first file name time)
%     m_time_array = time array for the points (in dateform format)
%     N = # of points in the array of data & time
%     summary_data = struct of summary data (once per block/second of data, optional)
%     summary_count = # of the summary data structures (optional)
%     string listing of any wholesale time gaps found in the data
%
%  There are a max of 100 points per second
%

%
%  Set any defaults
%
   T0 = clock;
   format compact;
   disp('Setting defaults');
   %
   %    Determine the file count and file names
   %
   if isstruct(the_file_list)
       disp('the_file_list is a structure');
       file_count_array = size(the_file_list);
       file_count = file_count_array(1);
       for i=1:file_count
           file_list(i,:) = the_file_list(i).name;
       end
   else
       disp('the_file_list is an array');
       file_count_array = size(the_file_list);
       file_count = file_count_array(1);
       file_list = the_file_list;
   end
   if ~exist('pps','var')
      pps = 100;
   end
   if ~exist('cut_off','var')
      cut_off = 0;
   end
   if ~exist('order','var')
      order = 2;
   end
   default_size = 1800*file_count*pps;
   buffer_size = 2048*90;
   %
   % Init the data
   %
   disp('Init data');
   summary_count = 0;
   T0 = clock;
   Ntot = 0;
   time_base = 'XXX';
   slow_data(64,buffer_size) = 0;
%   slow_filtered_data(64, buffer_size) = 0;
   buffer_time(buffer_size) = 0;
   %time(default_size) = 0;
   %slow_data_matrix(64,default_size) = 0;
   summary_count_start = 1;
   summary_count = 0;
   %
   % Open file
   %
   N=2048;
   old_Ntot_dec = 1;
   new_start = ceil(2048*pps/100);
   final_base = 1-ceil(1024*pps/100);
   block_index = 1;
   last_time = 0;
   old_summary_time = 0;
   for i=1:file_count
      N= 2048;
      %
      % Open next file
      %
      disp('Opening next file');
      disp(strcat(base_directory,'\',file_list(i,:)));
      fid1 = fopen(strcat(base_directory,'\',file_list(i,:)),'r');
      if fid1 == -1
          warning('Could not open file');
      end
      file_block_count = 0;
      %
      %  Determine the year from the file name
      %
      the_base_time = sscanf(file_list(i,:),'ACES_CONT_V2.50_%d-%dT%d-%d-%d');
      year = the_base_time(1);
      [month, day] = DOY_2_mon_day(the_base_time(2), year);
      if i == 1
         base_time = datenum(year,month,day,the_base_time(3),the_base_time(4),the_base_time(5));
      end
      %
      % Read first block of data
      %
      [slow_block_current, count] = read_cont_block(fid1);
      count;
      disp('Load Data');
      while count == 16
         %
         %  File looks okay, read summary
         %
         summary_count = summary_count + 1;
         summary_data(summary_count).scan_ram = slow_block_current.params.scan_ram;
         summary_data(summary_count).gain_1 = slow_block_current.params.gain_1;
         summary_data(summary_count).filter = slow_block_current.params.filter;
         summary_data(summary_count).gain_2 = slow_block_current.params.gain_2;
         %
         %  Determine the "best" time of the block
         %
         summary_data(summary_count).s_time = slow_block_current.trig_time;
         %
         %  Decode the string time to a matlab time
         %
         time_val = sscanf(summary_data(summary_count).s_time, '%3d:%2d:%2d:%f');
         [month, day] = DOY_2_mon_day(time_val(1), year);
         hour = time_val(2);
         minute = time_val(3);
         second = time_val(4);
         summary_data(summary_count).m_time = (datenum(year,month,day,hour,minute,second) - base_time)*86400;
%         datestr(datenum(year,month,day,hour,minute,second))
         if round((summary_data(summary_count).m_time - old_summary_time)*100) ~= 2047
            %
            %  See if this is an end of data collection
            %
            k = find(slow_block_current.data(:,2048) == -10.24);
%            k=0;
%            for end_test=1:64
%               if slow_block_current.data(end_test,2048) == -10.24
%                  k = k+1;
%               end
%            end
            %
            %  It is end of data, so "fix" the end time
            %
            if length(k) == 64
               summary_data(summary_count).m_time = old_summary_time + 20.47;
               disp(sprintf('Data collection end at summary_count %d',summary_count));
            else
               disp(sprintf('Time flow problem, %f, should be 20.47',summary_data(summary_count).m_time - old_summary_time));
            end
         end
         old_summary_time = summary_data(summary_count).m_time;
         %
         % Read in the data
         %
%         N+2048
%         for block_index=1:2048
%            N = N + 1;
%            Ntot = Ntot + 1;
%            slow_data(:,N) = slow_block_current.data(:,block_index);
%            buffer_time(N) = summary_data(summary_count).m_time - (2048 - block_index)*0.01;
%         end
         slow_data(:,N+1:N+2048) = slow_block_current.data(:,1:2048);
         buffer_time(N+1:N+2048) = summary_data(summary_count).m_time - (2048 - [1:2048])*0.01;
         N = N + 2048;
         Ntot = Ntot + 2048;
         %
         % Get the nex block
         %
         last_block = slow_block_current;
         file_block_count = file_block_count + 1;
         [slow_block_current,count] = read_cont_block(fid1);
      end
      %
      %  Now we have enough data to time fix, remove redundant data, filter, and decimate the data, do so
      %
      %  first, fix time errors and correct the time base
      %  Note since we change the size of slow_data (eliminate redundant data), we need to
      %  reset N & Ntot
      %
      [corrected_slow_data, corrected_buffer_time, corrected_m_buffer_time, corrected_data_rate] = correct_slow_time_base(slow_data(:,1:N), buffer_time(1:N), buffer_time(1:N)/86400 + base_time, 0.01);
      old_N = N;
      N = length(corrected_buffer_time);
      delta_N = old_N - N;
      Ntot = Ntot - delta_N;
      corrected_data_rate;
      corrected_delta_time = 1/corrected_data_rate;
      %
      %  Now filter data
      %  remembering to halve the filter order since the filtfilt
      %  doubles the order of the filter
      %
      if cut_off ~= 0
         disp('Filter Data');
         [b,a] = butter(ceil(order*.5),cut_off/50);
         for data_index=1:6
            slow_filtered_data(mill_index,1:N) = filtfilt(b,a,corrected_slow_data(data_index,:));
         end
      else
         disp('Not Filtering Data');
         slow_filtered_data = corrected_slow_data;
      end
      %
      %  Now resample data
      %
      if pps ~= 100
         disp('Resampling Data');
         d = gcd(pps,100);
         p = pps/d;
         q = 100/d;
         N_dec = ceil(N*pps/100);
         Ntot_dec = ceil(Ntot*pps/100);
         old_Ntot_dec;
         new_start = N_dec - (Ntot_dec-old_Ntot_dec);
         for data_index=1:64
            dummy_array_1 = resample(squeeze(slow_filtered_data(data_index,1:N)),p,q,0);
            slow_data_matrix(data_index,old_Ntot_dec:Ntot_dec) = dummy_array_1(new_start:N_dec);
         end
         dummy_array_1 = resample(corrected_buffer_time(1:N),p,q,0);
         time(old_Ntot_dec:Ntot_dec) = dummy_array_1(new_start:N_dec);
      else
         disp('Not Resampling Data');
         N_dec = N;
         Ntot_dec = Ntot;
         new_start = N_dec - (Ntot_dec-old_Ntot_dec); 
         slow_data_matrix(64,Ntot_dec) = 0;
         time(Ntot_dec) = 0;
         for data_index=1:64
            dummy_array_1 = squeeze(slow_filtered_data(data_index,1:N));
            slow_data_matrix(data_index,old_Ntot_dec:Ntot_dec) = dummy_array_1(new_start:N_dec);
         end
         dummy_array_1 = corrected_buffer_time(1:N);
         time(old_Ntot_dec:Ntot_dec) = dummy_array_1(new_start:N_dec);
      end
      %
      %  Now shuffle the data
      %
      buffer_time(1:2048) = corrected_buffer_time(N-2047:N);
      slow_data(:,1:2048) = corrected_slow_data(:,N-2047:N);
      old_Ntot_dec = Ntot_dec - ceil(1024*pps/100);
      %
      % Get the next file
      %
      fclose(fid1);
   end
   summary_count;
   N;
   %
   % Now convert summary time back to matlab
   %
   for time_index=1:summary_count
      summary_data(time_index).m_time = summary_data(time_index).m_time/86400 + base_time;
   end
   %
   %  Change one set of times back to Matlab format
   %
   m_time_array = time/86400 + base_time;
   time_array = time;      
   etime(clock,T0)
         

